package androidx.camera.extensions;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import androidx.camera.core.CameraSelector;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.Logger;
import androidx.camera.core.Preview;
import androidx.camera.core.impl.utils.executor.CameraXExecutors;
import androidx.camera.core.impl.utils.futures.Futures;
import androidx.camera.extensions.ExtensionsErrorListener;
import androidx.camera.extensions.impl.InitializerImpl;
import androidx.concurrent.futures.CallbackToFutureAdapter;
import com.google.common.util.concurrent.ListenableFuture;
import java.util.concurrent.ExecutionException;

public final class ExtensionsManager {
    private static final Handler DEFAULT_HANDLER = new Handler(Looper.getMainLooper());
    private static final Object ERROR_LOCK = new Object();
    private static final Object EXTENSIONS_LOCK = new Object();
    private static final String TAG = "ExtensionsManager";
    private static ListenableFuture<ExtensionsAvailability> sAvailabilityFuture;
    private static ListenableFuture<Void> sDeinitFuture;
    private static volatile ExtensionsErrorListener sExtensionsErrorListener = null;
    static boolean sInitialized = false;

    public enum EffectMode {
        NORMAL,
        BOKEH,
        HDR,
        NIGHT,
        BEAUTY,
        AUTO
    }

    public enum ExtensionsAvailability {
        LIBRARY_AVAILABLE,
        LIBRARY_UNAVAILABLE_ERROR_LOADING,
        LIBRARY_UNAVAILABLE_MISSING_IMPLEMENTATION,
        NONE
    }

    public static ListenableFuture<ExtensionsAvailability> init(Context context) {
        synchronized (EXTENSIONS_LOCK) {
            if (sDeinitFuture != null) {
                if (!sDeinitFuture.isDone()) {
                    throw new IllegalStateException("Not yet done deinitializing extensions");
                }
            }
            sDeinitFuture = null;
            if (ExtensionVersion.getRuntimeVersion() == null) {
                setInitialized(true);
                return Futures.immediateFuture(ExtensionsAvailability.NONE);
            } else if (ExtensionVersion.getRuntimeVersion().compareTo(Version.VERSION_1_1) < 0) {
                setInitialized(true);
                return Futures.immediateFuture(ExtensionsAvailability.LIBRARY_AVAILABLE);
            } else {
                if (sAvailabilityFuture == null) {
                    sAvailabilityFuture = CallbackToFutureAdapter.getFuture(new CallbackToFutureAdapter.Resolver(context) {
                        /* class androidx.camera.extensions.$$Lambda$ExtensionsManager$C9z7sTuP6en2VIcuXe5QI_gJs4 */
                        private final /* synthetic */ Context f$0;

                        {
                            this.f$0 = r1;
                        }

                        @Override // androidx.concurrent.futures.CallbackToFutureAdapter.Resolver
                        public final Object attachCompleter(CallbackToFutureAdapter.Completer completer) {
                            return ExtensionsManager.lambda$init$0(this.f$0, completer);
                        }
                    });
                }
                return sAvailabilityFuture;
            }
        }
    }

    static /* synthetic */ Object lambda$init$0(Context context, final CallbackToFutureAdapter.Completer completer) throws Exception {
        try {
            InitializerImpl.init(VersionName.getCurrentVersion().toVersionString(), context, new InitializerImpl.OnExtensionsInitializedCallback() {
                /* class androidx.camera.extensions.ExtensionsManager.AnonymousClass1 */

                public void onSuccess() {
                    Logger.d(ExtensionsManager.TAG, "Successfully initialized extensions");
                    ExtensionsManager.setInitialized(true);
                    CallbackToFutureAdapter.Completer.this.set(ExtensionsAvailability.LIBRARY_AVAILABLE);
                }

                public void onFailure(int i) {
                    Logger.d(ExtensionsManager.TAG, "Failed to initialize extensions");
                    CallbackToFutureAdapter.Completer.this.set(ExtensionsAvailability.LIBRARY_UNAVAILABLE_ERROR_LOADING);
                }
            }, CameraXExecutors.mainThreadExecutor());
            return "Initialize extensions";
        } catch (NoClassDefFoundError | NoSuchMethodError unused) {
            completer.set(ExtensionsAvailability.LIBRARY_UNAVAILABLE_MISSING_IMPLEMENTATION);
            return "Initialize extensions";
        }
    }

    static void setInitialized(boolean z) {
        synchronized (EXTENSIONS_LOCK) {
            sInitialized = z;
        }
    }

    public static ListenableFuture<Void> deinit() {
        synchronized (EXTENSIONS_LOCK) {
            setInitialized(false);
            if (ExtensionVersion.getRuntimeVersion() == null) {
                return Futures.immediateFuture(null);
            } else if (sAvailabilityFuture == null) {
                return Futures.immediateFuture(null);
            } else if (sDeinitFuture != null) {
                return sDeinitFuture;
            } else {
                try {
                    ExtensionsAvailability extensionsAvailability = sAvailabilityFuture.get();
                    sAvailabilityFuture = null;
                    if (extensionsAvailability == ExtensionsAvailability.LIBRARY_AVAILABLE) {
                        sDeinitFuture = CallbackToFutureAdapter.getFuture($$Lambda$ExtensionsManager$duJyyzd_C6K_P3oylCp4vrcHviM.INSTANCE);
                    } else {
                        sDeinitFuture = Futures.immediateFuture(null);
                    }
                    return sDeinitFuture;
                } catch (InterruptedException | ExecutionException e) {
                    sDeinitFuture = Futures.immediateFailedFuture(e);
                    return sDeinitFuture;
                }
            }
        }
    }

    static /* synthetic */ Object lambda$deinit$1(final CallbackToFutureAdapter.Completer completer) throws Exception {
        try {
            InitializerImpl.deinit(new InitializerImpl.OnExtensionsDeinitializedCallback() {
                /* class androidx.camera.extensions.ExtensionsManager.AnonymousClass2 */

                public void onSuccess() {
                    CallbackToFutureAdapter.Completer.this.set(null);
                }

                public void onFailure(int i) {
                    CallbackToFutureAdapter.Completer.this.setException(new Exception("Failed to deinitialize extensions."));
                }
            }, CameraXExecutors.mainThreadExecutor());
            return null;
        } catch (NoClassDefFoundError | NoSuchMethodError e) {
            completer.setException(e);
            return null;
        }
    }

    public static Extensions getExtensions(Context context) {
        Extensions extensions;
        synchronized (EXTENSIONS_LOCK) {
            if (sInitialized) {
                extensions = new Extensions(context);
            } else {
                throw new IllegalStateException("Extensions not yet initialized");
            }
        }
        return extensions;
    }

    public static boolean isExtensionAvailable(EffectMode effectMode, int i) {
        boolean checkImageCaptureExtensionCapability = checkImageCaptureExtensionCapability(effectMode, i);
        boolean checkPreviewExtensionCapability = checkPreviewExtensionCapability(effectMode, i);
        if (checkImageCaptureExtensionCapability != checkPreviewExtensionCapability) {
            Logger.e(TAG, "ImageCapture and Preview are not available simultaneously for " + effectMode.name());
        }
        return checkImageCaptureExtensionCapability && checkPreviewExtensionCapability;
    }

    public static boolean isExtensionAvailable(Class<?> cls, EffectMode effectMode, int i) {
        if (cls == ImageCapture.class) {
            return checkImageCaptureExtensionCapability(effectMode, i);
        }
        if (cls.equals(Preview.class)) {
            return checkPreviewExtensionCapability(effectMode, i);
        }
        return false;
    }

    private static boolean checkImageCaptureExtensionCapability(EffectMode effectMode, int i) {
        ImageCaptureExtender imageCaptureExtender;
        ImageCapture.Builder builder = new ImageCapture.Builder();
        CameraSelector build = new CameraSelector.Builder().requireLensFacing(i).build();
        switch (effectMode) {
            case BOKEH:
                imageCaptureExtender = BokehImageCaptureExtender.create(builder);
                break;
            case HDR:
                imageCaptureExtender = HdrImageCaptureExtender.create(builder);
                break;
            case NIGHT:
                imageCaptureExtender = NightImageCaptureExtender.create(builder);
                break;
            case BEAUTY:
                imageCaptureExtender = BeautyImageCaptureExtender.create(builder);
                break;
            case AUTO:
                imageCaptureExtender = AutoImageCaptureExtender.create(builder);
                break;
            case NORMAL:
                return true;
            default:
                return false;
        }
        return imageCaptureExtender.isExtensionAvailable(build);
    }

    public static void setExtensionsErrorListener(ExtensionsErrorListener extensionsErrorListener) {
        synchronized (ERROR_LOCK) {
            sExtensionsErrorListener = extensionsErrorListener;
        }
    }

    static void postExtensionsError(final ExtensionsErrorListener.ExtensionsErrorCode extensionsErrorCode) {
        synchronized (ERROR_LOCK) {
            final ExtensionsErrorListener extensionsErrorListener = sExtensionsErrorListener;
            if (extensionsErrorListener != null) {
                DEFAULT_HANDLER.post(new Runnable() {
                    /* class androidx.camera.extensions.ExtensionsManager.AnonymousClass3 */

                    public void run() {
                        ExtensionsErrorListener.this.onError(extensionsErrorCode);
                    }
                });
            }
        }
    }

    private static boolean checkPreviewExtensionCapability(EffectMode effectMode, int i) {
        PreviewExtender previewExtender;
        Preview.Builder builder = new Preview.Builder();
        CameraSelector build = new CameraSelector.Builder().requireLensFacing(i).build();
        switch (effectMode) {
            case BOKEH:
                previewExtender = BokehPreviewExtender.create(builder);
                break;
            case HDR:
                previewExtender = HdrPreviewExtender.create(builder);
                break;
            case NIGHT:
                previewExtender = NightPreviewExtender.create(builder);
                break;
            case BEAUTY:
                previewExtender = BeautyPreviewExtender.create(builder);
                break;
            case AUTO:
                previewExtender = AutoPreviewExtender.create(builder);
                break;
            case NORMAL:
                return true;
            default:
                return false;
        }
        return previewExtender.isExtensionAvailable(build);
    }

    private ExtensionsManager() {
    }
}
