package androidx.camera.extensions;

import android.content.Context;
import android.util.Pair;
import android.util.Size;
import androidx.camera.camera2.impl.Camera2ImplConfig;
import androidx.camera.camera2.impl.CameraEventCallback;
import androidx.camera.camera2.impl.CameraEventCallbacks;
import androidx.camera.camera2.interop.Camera2CameraInfo;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.CameraSelector;
import androidx.camera.core.CameraX;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.Logger;
import androidx.camera.core.UseCase;
import androidx.camera.core.impl.CaptureBundle;
import androidx.camera.core.impl.CaptureConfig;
import androidx.camera.core.impl.CaptureStage;
import androidx.camera.core.impl.Config;
import androidx.camera.extensions.ExtensionsErrorListener;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.CaptureProcessorImpl;
import androidx.camera.extensions.impl.CaptureStageImpl;
import androidx.camera.extensions.impl.ImageCaptureExtenderImpl;
import androidx.camera.extensions.internal.AdaptingCaptureProcessor;
import androidx.camera.extensions.internal.AdaptingCaptureStage;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.concurrent.atomic.AtomicBoolean;

public abstract class ImageCaptureExtender {
    static final Config.Option<ExtensionsManager.EffectMode> OPTION_IMAGE_CAPTURE_EXTENDER_MODE = Config.Option.create("camerax.extensions.imageCaptureExtender.mode", ExtensionsManager.EffectMode.class);
    private static final String TAG = "ImageCaptureExtender";
    private ImageCapture.Builder mBuilder;
    private ExtensionsManager.EffectMode mEffectMode;
    private ExtensionCameraFilter mExtensionCameraFilter;
    private ImageCaptureExtenderImpl mImpl;

    /* access modifiers changed from: package-private */
    public void init(ImageCapture.Builder builder, ImageCaptureExtenderImpl imageCaptureExtenderImpl, ExtensionsManager.EffectMode effectMode) {
        this.mBuilder = builder;
        this.mImpl = imageCaptureExtenderImpl;
        this.mEffectMode = effectMode;
        this.mExtensionCameraFilter = new ExtensionCameraFilter(this.mImpl);
    }

    public boolean isExtensionAvailable(CameraSelector cameraSelector) {
        return getCameraWithExtension(cameraSelector) != null;
    }

    private String getCameraWithExtension(CameraSelector cameraSelector) {
        CameraSelector.Builder fromSelector = CameraSelector.Builder.fromSelector(cameraSelector);
        fromSelector.addCameraFilter(this.mExtensionCameraFilter);
        return CameraUtil.getCameraIdUnchecked(fromSelector.build());
    }

    public void enableExtension(CameraSelector cameraSelector) {
        String cameraWithExtension = getCameraWithExtension(cameraSelector);
        if (cameraWithExtension != null) {
            CameraSelector cameraSelector2 = this.mBuilder.getUseCaseConfig().getCameraSelector(null);
            if (cameraSelector2 == null) {
                this.mBuilder.setCameraSelector(new CameraSelector.Builder().addCameraFilter(this.mExtensionCameraFilter).build());
            } else {
                this.mBuilder.setCameraSelector(CameraSelector.Builder.fromSelector(cameraSelector2).addCameraFilter(this.mExtensionCameraFilter).build());
            }
            this.mImpl.init(cameraWithExtension, CameraUtil.getCameraCharacteristics(cameraWithExtension));
            CaptureProcessorImpl captureProcessor = this.mImpl.getCaptureProcessor();
            if (captureProcessor != null) {
                this.mBuilder.setCaptureProcessor(new AdaptingCaptureProcessor(captureProcessor));
            }
            if (this.mImpl.getMaxCaptureStage() > 0) {
                this.mBuilder.setMaxCaptureStages(this.mImpl.getMaxCaptureStage());
            }
            ImageCaptureAdapter imageCaptureAdapter = new ImageCaptureAdapter(this.mImpl, CameraX.getContext());
            new Camera2ImplConfig.Extender(this.mBuilder).setCameraEventCallback(new CameraEventCallbacks(imageCaptureAdapter));
            this.mBuilder.setUseCaseEventCallback((UseCase.EventCallback) imageCaptureAdapter);
            this.mBuilder.setCaptureBundle(imageCaptureAdapter);
            this.mBuilder.getMutableConfig().insertOption(OPTION_IMAGE_CAPTURE_EXTENDER_MODE, this.mEffectMode);
            List<Pair<Integer, Size[]>> supportedResolutions = getSupportedResolutions(this.mImpl);
            if (supportedResolutions != null) {
                this.mBuilder.setSupportedResolutions(supportedResolutions);
            }
        }
    }

    public static List<Pair<Integer, Size[]>> getSupportedResolutions(ImageCaptureExtenderImpl imageCaptureExtenderImpl) {
        if (ExtensionVersion.getRuntimeVersion().compareTo(Version.VERSION_1_1) < 0) {
            return null;
        }
        try {
            return imageCaptureExtenderImpl.getSupportedResolutions();
        } catch (NoSuchMethodError unused) {
            Logger.e(TAG, "getSupportedResolution interface is not implemented in vendor library.");
            return null;
        }
    }

    static void checkPreviewEnabled(ExtensionsManager.EffectMode effectMode, Collection<UseCase> collection) {
        if (collection != null && !collection.isEmpty()) {
            boolean z = false;
            boolean z2 = false;
            for (UseCase useCase : collection) {
                ExtensionsManager.EffectMode effectMode2 = (ExtensionsManager.EffectMode) useCase.getCurrentConfig().retrieveOption((Config.Option<ValueT>) PreviewExtender.OPTION_PREVIEW_EXTENDER_MODE, null);
                if (effectMode == effectMode2) {
                    z2 = true;
                } else if (effectMode2 != null) {
                    z = true;
                }
            }
            if (z) {
                ExtensionsManager.postExtensionsError(ExtensionsErrorListener.ExtensionsErrorCode.MISMATCHED_EXTENSIONS_ENABLED);
            } else if (!z2) {
                ExtensionsManager.postExtensionsError(ExtensionsErrorListener.ExtensionsErrorCode.PREVIEW_EXTENSION_REQUIRED);
            }
        }
    }

    public static class ImageCaptureAdapter extends CameraEventCallback implements UseCase.EventCallback, CaptureBundle {
        private final AtomicBoolean mActive = new AtomicBoolean(true);
        private final Context mContext;
        private volatile int mEnabledSessionCount = 0;
        private final ImageCaptureExtenderImpl mImpl;
        private final Object mLock = new Object();
        private volatile boolean mUnbind = false;

        public ImageCaptureAdapter(ImageCaptureExtenderImpl imageCaptureExtenderImpl, Context context) {
            this.mImpl = imageCaptureExtenderImpl;
            this.mContext = context;
        }

        @Override // androidx.camera.core.UseCase.EventCallback
        public void onAttach(CameraInfo cameraInfo) {
            if (this.mActive.get()) {
                this.mImpl.onInit(Camera2CameraInfo.fromCameraInfo(cameraInfo).getCameraId(), Camera2CameraInfo.extractCameraCharacteristics(cameraInfo), this.mContext);
            }
        }

        @Override // androidx.camera.core.UseCase.EventCallback
        public void onDetach() {
            synchronized (this.mLock) {
                this.mUnbind = true;
                if (this.mEnabledSessionCount == 0) {
                    callDeInit();
                }
            }
        }

        private void callDeInit() {
            if (this.mActive.get()) {
                this.mImpl.onDeInit();
                this.mActive.set(false);
            }
        }

        @Override // androidx.camera.camera2.impl.CameraEventCallback
        public CaptureConfig onPresetSession() {
            CaptureStageImpl onPresetSession;
            if (!this.mActive.get() || (onPresetSession = this.mImpl.onPresetSession()) == null) {
                return null;
            }
            return new AdaptingCaptureStage(onPresetSession).getCaptureConfig();
        }

        @Override // androidx.camera.camera2.impl.CameraEventCallback
        public CaptureConfig onEnableSession() {
            CaptureStageImpl onEnableSession;
            try {
                if (!this.mActive.get() || (onEnableSession = this.mImpl.onEnableSession()) == null) {
                    synchronized (this.mLock) {
                        this.mEnabledSessionCount++;
                    }
                    return null;
                }
                CaptureConfig captureConfig = new AdaptingCaptureStage(onEnableSession).getCaptureConfig();
                synchronized (this.mLock) {
                    this.mEnabledSessionCount++;
                }
                return captureConfig;
            } catch (Throwable th) {
                synchronized (this.mLock) {
                    this.mEnabledSessionCount++;
                    throw th;
                }
            }
        }

        @Override // androidx.camera.camera2.impl.CameraEventCallback
        public CaptureConfig onDisableSession() {
            CaptureStageImpl onDisableSession;
            try {
                if (!this.mActive.get() || (onDisableSession = this.mImpl.onDisableSession()) == null) {
                    synchronized (this.mLock) {
                        this.mEnabledSessionCount--;
                        if (this.mEnabledSessionCount == 0 && this.mUnbind) {
                            callDeInit();
                        }
                    }
                    return null;
                }
                CaptureConfig captureConfig = new AdaptingCaptureStage(onDisableSession).getCaptureConfig();
                synchronized (this.mLock) {
                    this.mEnabledSessionCount--;
                    if (this.mEnabledSessionCount == 0 && this.mUnbind) {
                        callDeInit();
                    }
                }
                return captureConfig;
            } catch (Throwable th) {
                synchronized (this.mLock) {
                    this.mEnabledSessionCount--;
                    if (this.mEnabledSessionCount == 0 && this.mUnbind) {
                        callDeInit();
                    }
                    throw th;
                }
            }
        }

        @Override // androidx.camera.core.impl.CaptureBundle
        public List<CaptureStage> getCaptureStages() {
            List<CaptureStageImpl> captureStages;
            if (!this.mActive.get() || (captureStages = this.mImpl.getCaptureStages()) == null || captureStages.isEmpty()) {
                return null;
            }
            ArrayList arrayList = new ArrayList();
            for (CaptureStageImpl captureStageImpl : captureStages) {
                arrayList.add(new AdaptingCaptureStage(captureStageImpl));
            }
            return arrayList;
        }
    }
}
