package androidx.camera.extensions;

import android.content.Context;
import android.util.Pair;
import android.util.Size;
import androidx.camera.camera2.impl.Camera2ImplConfig;
import androidx.camera.camera2.impl.CameraEventCallback;
import androidx.camera.camera2.impl.CameraEventCallbacks;
import androidx.camera.camera2.interop.Camera2CameraInfo;
import androidx.camera.core.CameraInfo;
import androidx.camera.core.CameraSelector;
import androidx.camera.core.CameraX;
import androidx.camera.core.Logger;
import androidx.camera.core.Preview;
import androidx.camera.core.UseCase;
import androidx.camera.core.impl.CaptureConfig;
import androidx.camera.core.impl.Config;
import androidx.camera.extensions.ExtensionsErrorListener;
import androidx.camera.extensions.ExtensionsManager;
import androidx.camera.extensions.impl.CaptureStageImpl;
import androidx.camera.extensions.impl.PreviewExtenderImpl;
import androidx.camera.extensions.internal.AdaptingCaptureStage;
import androidx.camera.extensions.internal.AdaptingPreviewProcessor;
import androidx.camera.extensions.internal.AdaptingRequestUpdateProcessor;
import java.util.Collection;
import java.util.List;

public abstract class PreviewExtender {
    static final Config.Option<ExtensionsManager.EffectMode> OPTION_PREVIEW_EXTENDER_MODE = Config.Option.create("camerax.extensions.previewExtender.mode", ExtensionsManager.EffectMode.class);
    private static final String TAG = "PreviewExtender";
    private Preview.Builder mBuilder;
    private ExtensionsManager.EffectMode mEffectMode;
    private ExtensionCameraFilter mExtensionCameraFilter;
    private PreviewExtenderImpl mImpl;

    public interface CloseableProcessor {
        void close();
    }

    /* access modifiers changed from: package-private */
    public void init(Preview.Builder builder, PreviewExtenderImpl previewExtenderImpl, ExtensionsManager.EffectMode effectMode) {
        this.mBuilder = builder;
        this.mImpl = previewExtenderImpl;
        this.mEffectMode = effectMode;
        this.mExtensionCameraFilter = new ExtensionCameraFilter(this.mImpl);
    }

    public boolean isExtensionAvailable(CameraSelector cameraSelector) {
        return getCameraWithExtension(cameraSelector) != null;
    }

    private String getCameraWithExtension(CameraSelector cameraSelector) {
        CameraSelector.Builder fromSelector = CameraSelector.Builder.fromSelector(cameraSelector);
        fromSelector.addCameraFilter(this.mExtensionCameraFilter);
        return CameraUtil.getCameraIdUnchecked(fromSelector.build());
    }

    public void enableExtension(CameraSelector cameraSelector) {
        PreviewExtenderAdapter previewExtenderAdapter;
        String cameraWithExtension = getCameraWithExtension(cameraSelector);
        if (cameraWithExtension != null) {
            CameraSelector cameraSelector2 = this.mBuilder.getUseCaseConfig().getCameraSelector(null);
            if (cameraSelector2 == null) {
                this.mBuilder.setCameraSelector(new CameraSelector.Builder().addCameraFilter(this.mExtensionCameraFilter).build());
            } else {
                this.mBuilder.setCameraSelector(CameraSelector.Builder.fromSelector(cameraSelector2).addCameraFilter(this.mExtensionCameraFilter).build());
            }
            this.mImpl.init(cameraWithExtension, CameraUtil.getCameraCharacteristics(cameraWithExtension));
            Context context = CameraX.getContext();
            int i = AnonymousClass1.$SwitchMap$androidx$camera$extensions$impl$PreviewExtenderImpl$ProcessorType[this.mImpl.getProcessorType().ordinal()];
            if (i == 1) {
                AdaptingRequestUpdateProcessor adaptingRequestUpdateProcessor = new AdaptingRequestUpdateProcessor(this.mImpl);
                this.mBuilder.setImageInfoProcessor(adaptingRequestUpdateProcessor);
                previewExtenderAdapter = new PreviewExtenderAdapter(this.mImpl, context, adaptingRequestUpdateProcessor);
            } else if (i != 2) {
                previewExtenderAdapter = new PreviewExtenderAdapter(this.mImpl, context, null);
            } else {
                AdaptingPreviewProcessor adaptingPreviewProcessor = new AdaptingPreviewProcessor(this.mImpl.getProcessor());
                this.mBuilder.setCaptureProcessor(adaptingPreviewProcessor);
                previewExtenderAdapter = new PreviewExtenderAdapter(this.mImpl, context, adaptingPreviewProcessor);
            }
            new Camera2ImplConfig.Extender(this.mBuilder).setCameraEventCallback(new CameraEventCallbacks(previewExtenderAdapter));
            this.mBuilder.setUseCaseEventCallback((UseCase.EventCallback) previewExtenderAdapter);
            this.mBuilder.getMutableConfig().insertOption(OPTION_PREVIEW_EXTENDER_MODE, this.mEffectMode);
            List<Pair<Integer, Size[]>> supportedResolutions = getSupportedResolutions(this.mImpl);
            if (supportedResolutions != null) {
                this.mBuilder.setSupportedResolutions(supportedResolutions);
            }
        }
    }

    /* renamed from: androidx.camera.extensions.PreviewExtender$1  reason: invalid class name */
    static /* synthetic */ class AnonymousClass1 {
        static final /* synthetic */ int[] $SwitchMap$androidx$camera$extensions$impl$PreviewExtenderImpl$ProcessorType = new int[PreviewExtenderImpl.ProcessorType.values().length];

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|6) */
        /* JADX WARNING: Code restructure failed: missing block: B:7:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0014 */
        static {
            $SwitchMap$androidx$camera$extensions$impl$PreviewExtenderImpl$ProcessorType[PreviewExtenderImpl.ProcessorType.PROCESSOR_TYPE_REQUEST_UPDATE_ONLY.ordinal()] = 1;
            $SwitchMap$androidx$camera$extensions$impl$PreviewExtenderImpl$ProcessorType[PreviewExtenderImpl.ProcessorType.PROCESSOR_TYPE_IMAGE_PROCESSOR.ordinal()] = 2;
        }
    }

    public static List<Pair<Integer, Size[]>> getSupportedResolutions(PreviewExtenderImpl previewExtenderImpl) {
        if (ExtensionVersion.getRuntimeVersion().compareTo(Version.VERSION_1_1) < 0) {
            return null;
        }
        try {
            return previewExtenderImpl.getSupportedResolutions();
        } catch (NoSuchMethodError unused) {
            Logger.e(TAG, "getSupportedResolution interface is not implemented in vendor library.");
            return null;
        }
    }

    static void checkImageCaptureEnabled(ExtensionsManager.EffectMode effectMode, Collection<UseCase> collection) {
        if (collection != null && !collection.isEmpty()) {
            boolean z = false;
            boolean z2 = false;
            for (UseCase useCase : collection) {
                ExtensionsManager.EffectMode effectMode2 = (ExtensionsManager.EffectMode) useCase.getCurrentConfig().retrieveOption((Config.Option<ValueT>) ImageCaptureExtender.OPTION_IMAGE_CAPTURE_EXTENDER_MODE, null);
                if (effectMode == effectMode2) {
                    z2 = true;
                } else if (effectMode2 != null) {
                    z = true;
                }
            }
            if (z) {
                ExtensionsManager.postExtensionsError(ExtensionsErrorListener.ExtensionsErrorCode.MISMATCHED_EXTENSIONS_ENABLED);
            } else if (!z2) {
                ExtensionsManager.postExtensionsError(ExtensionsErrorListener.ExtensionsErrorCode.IMAGE_CAPTURE_EXTENSION_REQUIRED);
            }
        }
    }

    public static class PreviewExtenderAdapter extends CameraEventCallback implements UseCase.EventCallback {
        volatile boolean mActive = true;
        final CloseableProcessor mCloseableProcessor;
        private final Context mContext;
        private volatile int mEnabledSessionCount = 0;
        final PreviewExtenderImpl mImpl;
        final Object mLock = new Object();
        private volatile boolean mUnbind = false;

        public PreviewExtenderAdapter(PreviewExtenderImpl previewExtenderImpl, Context context, CloseableProcessor closeableProcessor) {
            this.mImpl = previewExtenderImpl;
            this.mContext = context;
            this.mCloseableProcessor = closeableProcessor;
        }

        @Override // androidx.camera.core.UseCase.EventCallback
        public void onAttach(CameraInfo cameraInfo) {
            synchronized (this.mLock) {
                if (this.mActive) {
                    this.mImpl.onInit(Camera2CameraInfo.fromCameraInfo(cameraInfo).getCameraId(), Camera2CameraInfo.extractCameraCharacteristics(cameraInfo), this.mContext);
                }
            }
        }

        @Override // androidx.camera.core.UseCase.EventCallback
        public void onDetach() {
            synchronized (this.mLock) {
                this.mUnbind = true;
                if (this.mEnabledSessionCount == 0) {
                    callDeInit();
                }
            }
        }

        private void callDeInit() {
            synchronized (this.mLock) {
                if (this.mActive) {
                    if (this.mCloseableProcessor != null) {
                        this.mCloseableProcessor.close();
                    }
                    this.mImpl.onDeInit();
                    this.mActive = false;
                }
            }
        }

        @Override // androidx.camera.camera2.impl.CameraEventCallback
        public CaptureConfig onPresetSession() {
            synchronized (this.mLock) {
                CaptureStageImpl onPresetSession = this.mImpl.onPresetSession();
                if (onPresetSession == null) {
                    return null;
                }
                return new AdaptingCaptureStage(onPresetSession).getCaptureConfig();
            }
        }

        @Override // androidx.camera.camera2.impl.CameraEventCallback
        public CaptureConfig onEnableSession() {
            CaptureStageImpl onEnableSession;
            try {
                synchronized (this.mLock) {
                    if (!this.mActive || (onEnableSession = this.mImpl.onEnableSession()) == null) {
                        synchronized (this.mLock) {
                            this.mEnabledSessionCount++;
                        }
                        return null;
                    }
                    CaptureConfig captureConfig = new AdaptingCaptureStage(onEnableSession).getCaptureConfig();
                    synchronized (this.mLock) {
                        this.mEnabledSessionCount++;
                    }
                    return captureConfig;
                }
            } catch (Throwable th) {
                synchronized (this.mLock) {
                    this.mEnabledSessionCount++;
                    throw th;
                }
            }
        }

        /* JADX WARNING: Code restructure failed: missing block: B:10:0x0019, code lost:
            r2 = r3.mLock;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:11:0x001b, code lost:
            monitor-enter(r2);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:13:?, code lost:
            r3.mEnabledSessionCount--;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:14:0x0024, code lost:
            if (r3.mEnabledSessionCount != 0) goto L_0x002d;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:16:0x0028, code lost:
            if (r3.mUnbind == false) goto L_0x002d;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:17:0x002a, code lost:
            callDeInit();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:18:0x002d, code lost:
            monitor-exit(r2);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:19:0x002e, code lost:
            return r1;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:24:0x0033, code lost:
            r1 = r3.mLock;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:25:0x0036, code lost:
            monitor-enter(r1);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:27:?, code lost:
            r3.mEnabledSessionCount--;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:28:0x003f, code lost:
            if (r3.mEnabledSessionCount != 0) goto L_0x0048;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:30:0x0043, code lost:
            if (r3.mUnbind == false) goto L_0x0048;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:31:0x0045, code lost:
            callDeInit();
         */
        /* JADX WARNING: Code restructure failed: missing block: B:32:0x0048, code lost:
            monitor-exit(r1);
         */
        /* JADX WARNING: Code restructure failed: missing block: B:33:0x0049, code lost:
            return null;
         */
        @Override // androidx.camera.camera2.impl.CameraEventCallback
        public CaptureConfig onDisableSession() {
            CaptureStageImpl onDisableSession;
            try {
                synchronized (this.mLock) {
                    if (this.mActive && (onDisableSession = this.mImpl.onDisableSession()) != null) {
                        CaptureConfig captureConfig = new AdaptingCaptureStage(onDisableSession).getCaptureConfig();
                    }
                }
            } catch (Throwable th) {
                synchronized (this.mLock) {
                    this.mEnabledSessionCount--;
                    if (this.mEnabledSessionCount == 0 && this.mUnbind) {
                        callDeInit();
                    }
                    throw th;
                }
            }
        }

        @Override // androidx.camera.camera2.impl.CameraEventCallback
        public CaptureConfig onRepeating() {
            CaptureStageImpl captureStage;
            synchronized (this.mLock) {
                if (!this.mActive || (captureStage = this.mImpl.getCaptureStage()) == null) {
                    return null;
                }
                return new AdaptingCaptureStage(captureStage).getCaptureConfig();
            }
        }
    }
}
