package androidx.camera.view;

import android.content.Context;
import android.hardware.display.DisplayManager;
import android.os.Handler;
import android.os.Looper;
import android.view.Display;
import androidx.camera.core.Camera;
import androidx.camera.core.CameraSelector;
import androidx.camera.core.FocusMeteringAction;
import androidx.camera.core.ImageAnalysis;
import androidx.camera.core.ImageCapture;
import androidx.camera.core.Logger;
import androidx.camera.core.MeteringPoint;
import androidx.camera.core.MeteringPointFactory;
import androidx.camera.core.Preview;
import androidx.camera.core.UseCaseGroup;
import androidx.camera.core.VideoCapture;
import androidx.camera.core.ViewPort;
import androidx.camera.core.ZoomState;
import androidx.camera.core.impl.utils.Threads;
import androidx.camera.core.impl.utils.executor.CameraXExecutors;
import androidx.camera.core.impl.utils.futures.FutureCallback;
import androidx.camera.core.impl.utils.futures.Futures;
import androidx.camera.lifecycle.ProcessCameraProvider;
import androidx.core.content.ContextCompat;
import androidx.core.util.Preconditions;
import androidx.lifecycle.LiveData;
import com.google.common.util.concurrent.ListenableFuture;
import java.util.concurrent.Executor;
import java.util.concurrent.atomic.AtomicBoolean;

public abstract class CameraController {
    private static final float AE_SIZE;
    private static final float AF_SIZE;
    private static final String CAMERA_NOT_ATTACHED;
    private static final String CAMERA_NOT_INITIALIZED;
    private static final String IMAGE_CAPTURE_DISABLED;
    private static final String PREVIEW_VIEW_NOT_ATTACHED;
    private static final String TAG;
    private static final String VIDEO_CAPTURE_DISABLED;
    private ImageAnalysis.Analyzer mAnalysisAnalyzer;
    private Executor mAnalysisExecutor;
    private final Context mAppContext;
    Camera mCamera;
    ProcessCameraProvider mCameraProvider;
    CameraSelector mCameraSelector = CameraSelector.DEFAULT_BACK_CAMERA;
    private final DisplayRotationListener mDisplayRotationListener;
    private ImageAnalysis mImageAnalysis;
    private boolean mImageAnalysisEnabled = true;
    final ImageCapture mImageCapture;
    private boolean mImageCaptureEnabled = true;
    private boolean mPinchToZoomEnabled = true;
    final Preview mPreview;
    Display mPreviewDisplay;
    private final ListenableFuture<ProcessCameraProvider> mProcessCameraProviderListenableFuture;
    final SensorRotationListener mSensorRotationListener;
    Preview.SurfaceProvider mSurfaceProvider;
    private boolean mTapToFocusEnabled = true;
    private final ForwardingLiveData<Integer> mTorchState = new ForwardingLiveData<>();
    final VideoCapture mVideoCapture;
    private boolean mVideoCaptureEnabled = false;
    final AtomicBoolean mVideoIsRecording = new AtomicBoolean(false);
    ViewPort mViewPort;
    private final ForwardingLiveData<ZoomState> mZoomState = new ForwardingLiveData<>();

    static /* synthetic */ Void lambda$getInitializationFuture$0(ProcessCameraProvider processCameraProvider) {
        return null;
    }

    private float speedUpZoomBy2X(float f) {
        return f > 1.0f ? ((f - 1.0f) * 2.0f) + 1.0f : 1.0f - ((1.0f - f) * 2.0f);
    }

    /* access modifiers changed from: package-private */
    public abstract Camera startCamera();

    CameraController(Context context) {
        this.mAppContext = context.getApplicationContext();
        this.mPreview = new Preview.Builder().build();
        this.mImageCapture = new ImageCapture.Builder().build();
        this.mImageAnalysis = new ImageAnalysis.Builder().build();
        this.mVideoCapture = new VideoCapture.Builder().build();
        this.mProcessCameraProviderListenableFuture = ProcessCameraProvider.getInstance(this.mAppContext);
        Futures.addCallback(this.mProcessCameraProviderListenableFuture, new FutureCallback<ProcessCameraProvider>() {
            /* class androidx.camera.view.CameraController.AnonymousClass1 */

            public void onSuccess(ProcessCameraProvider processCameraProvider) {
                CameraController cameraController = CameraController.this;
                cameraController.mCameraProvider = processCameraProvider;
                cameraController.startCameraAndTrackStates();
            }

            @Override // androidx.camera.core.impl.utils.futures.FutureCallback
            public void onFailure(Throwable th) {
                throw new RuntimeException("CameraX failed to initialize.", th);
            }
        }, CameraXExecutors.mainThreadExecutor());
        this.mDisplayRotationListener = new DisplayRotationListener();
        this.mSensorRotationListener = new SensorRotationListener(this.mAppContext) {
            /* class androidx.camera.view.CameraController.AnonymousClass2 */

            @Override // androidx.camera.view.SensorRotationListener
            public void onRotationChanged(int i) {
                CameraController.this.mImageCapture.setTargetRotation(i);
                CameraController.this.mVideoCapture.setTargetRotation(i);
            }
        };
    }

    public ListenableFuture<Void> getInitializationFuture() {
        return Futures.transform(this.mProcessCameraProviderListenableFuture, $$Lambda$CameraController$0lVEKj0FxvcHgbUAqJRox0pc6MI.INSTANCE, ContextCompat.getMainExecutor(this.mAppContext));
    }

    private boolean isCameraInitialized() {
        return this.mCameraProvider != null;
    }

    private boolean isPreviewViewAttached() {
        return (this.mSurfaceProvider == null || this.mViewPort == null || this.mPreviewDisplay == null) ? false : true;
    }

    private boolean isCameraAttached() {
        return this.mCamera != null;
    }

    private void checkUseCasesAttachedToCamera() {
        Preconditions.checkState(isCameraInitialized(), CAMERA_NOT_INITIALIZED);
        Preconditions.checkState(isCameraAttached(), PREVIEW_VIEW_NOT_ATTACHED);
    }

    public void attachPreviewSurface(Preview.SurfaceProvider surfaceProvider, ViewPort viewPort, Display display) {
        Threads.checkMainThread();
        if (this.mSurfaceProvider != surfaceProvider) {
            this.mSurfaceProvider = surfaceProvider;
            this.mPreview.setSurfaceProvider(surfaceProvider);
        }
        this.mViewPort = viewPort;
        this.mPreviewDisplay = display;
        startListeningToRotationEvents();
        startCameraAndTrackStates();
    }

    public void clearPreviewSurface() {
        Threads.checkMainThread();
        ProcessCameraProvider processCameraProvider = this.mCameraProvider;
        if (processCameraProvider != null) {
            processCameraProvider.unbindAll();
        }
        this.mPreview.setSurfaceProvider(null);
        this.mCamera = null;
        this.mSurfaceProvider = null;
        this.mViewPort = null;
        this.mPreviewDisplay = null;
        stopListeningToRotationEvents();
    }

    private void startListeningToRotationEvents() {
        getDisplayManager().registerDisplayListener(this.mDisplayRotationListener, new Handler(Looper.getMainLooper()));
        if (this.mSensorRotationListener.canDetectOrientation()) {
            this.mSensorRotationListener.enable();
        }
    }

    private void stopListeningToRotationEvents() {
        getDisplayManager().unregisterDisplayListener(this.mDisplayRotationListener);
        this.mSensorRotationListener.disable();
    }

    private DisplayManager getDisplayManager() {
        return (DisplayManager) this.mAppContext.getSystemService("display");
    }

    public boolean isImageCaptureEnabled() {
        Threads.checkMainThread();
        return this.mImageCaptureEnabled;
    }

    public void setImageCaptureEnabled(boolean z) {
        Threads.checkMainThread();
        this.mImageCaptureEnabled = z;
        startCameraAndTrackStates();
    }

    public int getImageCaptureFlashMode() {
        Threads.checkMainThread();
        return this.mImageCapture.getFlashMode();
    }

    public void setImageCaptureFlashMode(int i) {
        Threads.checkMainThread();
        this.mImageCapture.setFlashMode(i);
        startCameraAndTrackStates();
    }

    public void takePicture(ImageCapture.OutputFileOptions outputFileOptions, Executor executor, ImageCapture.OnImageSavedCallback onImageSavedCallback) {
        Threads.checkMainThread();
        checkUseCasesAttachedToCamera();
        Preconditions.checkState(this.mImageCaptureEnabled, IMAGE_CAPTURE_DISABLED);
        if (this.mCameraSelector.getLensFacing() != null) {
            outputFileOptions.getMetadata().setReversedHorizontal(this.mCameraSelector.getLensFacing().intValue() == 0);
        }
        this.mImageCapture.lambda$takePicture$4$ImageCapture(outputFileOptions, executor, onImageSavedCallback);
    }

    public void takePicture(Executor executor, ImageCapture.OnImageCapturedCallback onImageCapturedCallback) {
        Threads.checkMainThread();
        checkUseCasesAttachedToCamera();
        Preconditions.checkState(this.mImageCaptureEnabled, IMAGE_CAPTURE_DISABLED);
        this.mImageCapture.lambda$takePicture$3$ImageCapture(executor, onImageCapturedCallback);
    }

    public boolean isImageAnalysisEnabled() {
        Threads.checkMainThread();
        return this.mImageAnalysisEnabled;
    }

    public void setImageAnalysisEnabled(boolean z) {
        Threads.checkMainThread();
        this.mImageAnalysisEnabled = z;
        startCameraAndTrackStates();
    }

    public void setImageAnalysisAnalyzer(Executor executor, ImageAnalysis.Analyzer analyzer) {
        Threads.checkMainThread();
        if (this.mAnalysisAnalyzer != analyzer || this.mAnalysisExecutor != executor) {
            this.mAnalysisExecutor = executor;
            this.mAnalysisAnalyzer = analyzer;
            this.mImageAnalysis.setAnalyzer(executor, analyzer);
        }
    }

    public void clearImageAnalysisAnalyzer() {
        Threads.checkMainThread();
        this.mAnalysisExecutor = null;
        this.mAnalysisAnalyzer = null;
        this.mImageAnalysis.clearAnalyzer();
    }

    public int getImageAnalysisBackpressureStrategy() {
        Threads.checkMainThread();
        return this.mImageAnalysis.getBackpressureStrategy();
    }

    public void setImageAnalysisBackpressureStrategy(int i) {
        Threads.checkMainThread();
        if (this.mImageAnalysis.getBackpressureStrategy() != i) {
            unbindImageAnalysisAndRecreate(i, this.mImageAnalysis.getImageQueueDepth());
            startCameraAndTrackStates();
        }
    }

    public void setImageAnalysisImageQueueDepth(int i) {
        Threads.checkMainThread();
        if (this.mImageAnalysis.getImageQueueDepth() != i) {
            unbindImageAnalysisAndRecreate(this.mImageAnalysis.getBackpressureStrategy(), i);
            startCameraAndTrackStates();
        }
    }

    public int getImageAnalysisImageQueueDepth() {
        Threads.checkMainThread();
        return this.mImageAnalysis.getImageQueueDepth();
    }

    private void unbindImageAnalysisAndRecreate(int i, int i2) {
        ImageAnalysis.Analyzer analyzer;
        if (isCameraInitialized()) {
            this.mCameraProvider.unbind(this.mImageAnalysis);
        }
        this.mImageAnalysis = new ImageAnalysis.Builder().setBackpressureStrategy(i).setImageQueueDepth(i2).build();
        Executor executor = this.mAnalysisExecutor;
        if (executor != null && (analyzer = this.mAnalysisAnalyzer) != null) {
            this.mImageAnalysis.setAnalyzer(executor, analyzer);
        }
    }

    public boolean isVideoCaptureEnabled() {
        Threads.checkMainThread();
        return this.mVideoCaptureEnabled;
    }

    public void setVideoCaptureEnabled(boolean z) {
        Threads.checkMainThread();
        if (this.mVideoCaptureEnabled && !z) {
            stopRecording();
        }
        this.mVideoCaptureEnabled = z;
        startCameraAndTrackStates();
    }

    public void startRecording(VideoCapture.OutputFileOptions outputFileOptions, Executor executor, final VideoCapture.OnVideoSavedCallback onVideoSavedCallback) {
        Threads.checkMainThread();
        checkUseCasesAttachedToCamera();
        Preconditions.checkState(this.mVideoCaptureEnabled, VIDEO_CAPTURE_DISABLED);
        this.mVideoCapture.lambda$startRecording$0$VideoCapture(outputFileOptions, executor, new VideoCapture.OnVideoSavedCallback() {
            /* class androidx.camera.view.CameraController.AnonymousClass3 */

            @Override // androidx.camera.core.VideoCapture.OnVideoSavedCallback
            public void onVideoSaved(VideoCapture.OutputFileResults outputFileResults) {
                CameraController.this.mVideoIsRecording.set(false);
                onVideoSavedCallback.onVideoSaved(outputFileResults);
            }

            @Override // androidx.camera.core.VideoCapture.OnVideoSavedCallback
            public void onError(int i, String str, Throwable th) {
                CameraController.this.mVideoIsRecording.set(false);
                onVideoSavedCallback.onError(i, str, th);
            }
        });
        this.mVideoIsRecording.set(true);
    }

    public void stopRecording() {
        Threads.checkMainThread();
        if (this.mVideoIsRecording.get()) {
            this.mVideoCapture.lambda$stopRecording$5$VideoCapture();
        }
    }

    public boolean isRecording() {
        Threads.checkMainThread();
        return this.mVideoIsRecording.get();
    }

    public void setCameraSelector(CameraSelector cameraSelector) {
        Threads.checkMainThread();
        ProcessCameraProvider processCameraProvider = this.mCameraProvider;
        if (!(processCameraProvider == null || this.mCameraSelector == cameraSelector)) {
            processCameraProvider.unbindAll();
        }
        this.mCameraSelector = cameraSelector;
        startCameraAndTrackStates();
    }

    public CameraSelector getCameraSelector() {
        Threads.checkMainThread();
        return this.mCameraSelector;
    }

    public boolean isPinchToZoomEnabled() {
        Threads.checkMainThread();
        return this.mPinchToZoomEnabled;
    }

    public void setPinchToZoomEnabled(boolean z) {
        Threads.checkMainThread();
        this.mPinchToZoomEnabled = z;
    }

    public void onPinchToZoom(float f) {
        if (!isCameraAttached()) {
            Logger.w(TAG, CAMERA_NOT_ATTACHED);
        } else if (!this.mPinchToZoomEnabled) {
            Logger.d(TAG, "Pinch to zoom disabled.");
        } else {
            Logger.d(TAG, "Pinch to zoom with scale: " + f);
            ZoomState value = getZoomState().getValue();
            if (value != null) {
                setZoomRatio(Math.min(Math.max(value.getZoomRatio() * speedUpZoomBy2X(f), value.getMinZoomRatio()), value.getMaxZoomRatio()));
            }
        }
    }

    public void onTapToFocus(MeteringPointFactory meteringPointFactory, float f, float f2) {
        if (!isCameraAttached()) {
            Logger.w(TAG, CAMERA_NOT_ATTACHED);
        } else if (!this.mTapToFocusEnabled) {
            Logger.d(TAG, "Tap to focus disabled. ");
        } else {
            Logger.d(TAG, "Tap to focus: " + f + ", " + f2);
            MeteringPoint createPoint = meteringPointFactory.createPoint(f, f2, AF_SIZE);
            this.mCamera.getCameraControl().startFocusAndMetering(new FocusMeteringAction.Builder(createPoint, 1).addPoint(meteringPointFactory.createPoint(f, f2, AE_SIZE), 2).build());
        }
    }

    public boolean isTapToFocusEnabled() {
        Threads.checkMainThread();
        return this.mTapToFocusEnabled;
    }

    public void setTapToFocusEnabled(boolean z) {
        Threads.checkMainThread();
        this.mTapToFocusEnabled = z;
    }

    public LiveData<ZoomState> getZoomState() {
        Threads.checkMainThread();
        return this.mZoomState;
    }

    public ListenableFuture<Void> setZoomRatio(float f) {
        Threads.checkMainThread();
        if (isCameraAttached()) {
            return this.mCamera.getCameraControl().setZoomRatio(f);
        }
        Logger.w(TAG, CAMERA_NOT_ATTACHED);
        return Futures.immediateFuture(null);
    }

    public ListenableFuture<Void> setLinearZoom(float f) {
        Threads.checkMainThread();
        if (isCameraAttached()) {
            return this.mCamera.getCameraControl().setLinearZoom(f);
        }
        Logger.w(TAG, CAMERA_NOT_ATTACHED);
        return Futures.immediateFuture(null);
    }

    public LiveData<Integer> getTorchState() {
        Threads.checkMainThread();
        return this.mTorchState;
    }

    public ListenableFuture<Void> enableTorch(boolean z) {
        Threads.checkMainThread();
        if (isCameraAttached()) {
            return this.mCamera.getCameraControl().enableTorch(z);
        }
        Logger.w(TAG, CAMERA_NOT_ATTACHED);
        return Futures.immediateFuture(null);
    }

    public void startCameraAndTrackStates() {
        this.mCamera = startCamera();
        if (!isCameraAttached()) {
            Logger.d(TAG, CAMERA_NOT_ATTACHED);
            return;
        }
        this.mZoomState.setSource(this.mCamera.getCameraInfo().getZoomState());
        this.mTorchState.setSource(this.mCamera.getCameraInfo().getTorchState());
    }

    public UseCaseGroup createUseCaseGroup() {
        if (!isCameraInitialized()) {
            Logger.d(TAG, CAMERA_NOT_INITIALIZED);
            return null;
        } else if (!isPreviewViewAttached()) {
            Logger.d(TAG, PREVIEW_VIEW_NOT_ATTACHED);
            return null;
        } else {
            UseCaseGroup.Builder addUseCase = new UseCaseGroup.Builder().addUseCase(this.mPreview);
            if (this.mImageCaptureEnabled) {
                addUseCase.addUseCase(this.mImageCapture);
            } else {
                this.mCameraProvider.unbind(this.mImageCapture);
            }
            if (this.mImageAnalysisEnabled) {
                addUseCase.addUseCase(this.mImageAnalysis);
            } else {
                this.mCameraProvider.unbind(this.mImageAnalysis);
            }
            if (this.mVideoCaptureEnabled) {
                addUseCase.addUseCase(this.mVideoCapture);
            } else {
                this.mCameraProvider.unbind(this.mVideoCapture);
            }
            addUseCase.setViewPort(this.mViewPort);
            return addUseCase.build();
        }
    }

    public class DisplayRotationListener implements DisplayManager.DisplayListener {
        public void onDisplayAdded(int i) {
        }

        public void onDisplayRemoved(int i) {
        }

        DisplayRotationListener() {
            CameraController.this = r1;
        }

        public void onDisplayChanged(int i) {
            if (CameraController.this.mPreviewDisplay != null && CameraController.this.mPreviewDisplay.getDisplayId() == i) {
                CameraController.this.mPreview.setTargetRotation(CameraController.this.mPreviewDisplay.getRotation());
            }
        }
    }
}
