package com.google.android.exoplayer2.upstream;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;
import android.os.Looper;
import android.support.v4.media.session.PlaybackStateCompat;
import com.google.android.exoplayer2.upstream.BandwidthMeter;
import com.google.android.exoplayer2.upstream.DefaultBandwidthMeter;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.Clock;
import com.google.android.exoplayer2.util.SlidingPercentile;
import com.google.android.exoplayer2.util.Util;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableListMultimap;
import com.google.common.collect.ImmutableMap;
import com.google.zxing.client.result.ExpandedProductParsedResult;
import io.flutter.plugins.connectivity.ConnectivityBroadcastReceiver;
import java.lang.ref.WeakReference;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map;

public final class DefaultBandwidthMeter implements BandwidthMeter, TransferListener {
    private static final int BYTES_TRANSFERRED_FOR_ESTIMATE = 524288;
    private static final int COUNTRY_GROUP_INDEX_2G = 1;
    private static final int COUNTRY_GROUP_INDEX_3G = 2;
    private static final int COUNTRY_GROUP_INDEX_4G = 3;
    private static final int COUNTRY_GROUP_INDEX_5G_NSA = 4;
    private static final int COUNTRY_GROUP_INDEX_WIFI = 0;
    public static final ImmutableListMultimap<String, Integer> DEFAULT_INITIAL_BITRATE_COUNTRY_GROUPS = createInitialBitrateCountryGroupAssignment();
    public static final long DEFAULT_INITIAL_BITRATE_ESTIMATE = 1000000;
    public static final ImmutableList<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_2G = ImmutableList.of(218000L, 159000L, 145000L, 130000L, 112000L);
    public static final ImmutableList<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_3G = ImmutableList.of(2200000L, 1300000L, 930000L, 730000L, 530000L);
    public static final ImmutableList<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_4G = ImmutableList.of(4800000L, 2700000L, 1800000L, 1200000L, 630000L);
    public static final ImmutableList<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_5G_NSA = ImmutableList.of(12000000L, 8800000L, 5900000L, 3500000L, 1800000L);
    public static final ImmutableList<Long> DEFAULT_INITIAL_BITRATE_ESTIMATES_WIFI = ImmutableList.of(6100000L, 3800000L, 2100000L, 1300000L, 590000L);
    public static final int DEFAULT_SLIDING_WINDOW_MAX_WEIGHT = 2000;
    private static final int ELAPSED_MILLIS_FOR_ESTIMATE = 2000;
    private static DefaultBandwidthMeter singletonInstance;
    private long bitrateEstimate;
    private final Clock clock;
    private final Context context;
    private final BandwidthMeter.EventListener.EventDispatcher eventDispatcher;
    private final ImmutableMap<Integer, Long> initialBitrateEstimates;
    private long lastReportedBitrateEstimate;
    private int networkType;
    private int networkTypeOverride;
    private boolean networkTypeOverrideSet;
    private long sampleBytesTransferred;
    private long sampleStartTimeMs;
    private final SlidingPercentile slidingPercentile;
    private int streamCount;
    private long totalBytesTransferred;
    private long totalElapsedTimeMs;

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public TransferListener getTransferListener() {
        return this;
    }

    @Override // com.google.android.exoplayer2.upstream.TransferListener
    public void onTransferInitializing(DataSource dataSource, DataSpec dataSpec, boolean z) {
    }

    public static final class Builder {
        private Clock clock;
        private final Context context;
        private Map<Integer, Long> initialBitrateEstimates;
        private boolean resetOnNetworkTypeChange;
        private int slidingWindowMaxWeight;

        public Builder(Context context2) {
            Context context3;
            if (context2 == null) {
                context3 = null;
            } else {
                context3 = context2.getApplicationContext();
            }
            this.context = context3;
            this.initialBitrateEstimates = getInitialBitrateEstimatesForCountry(Util.getCountryCode(context2));
            this.slidingWindowMaxWeight = 2000;
            this.clock = Clock.DEFAULT;
            this.resetOnNetworkTypeChange = true;
        }

        public Builder setSlidingWindowMaxWeight(int i) {
            this.slidingWindowMaxWeight = i;
            return this;
        }

        public Builder setInitialBitrateEstimate(long j) {
            for (Integer num : this.initialBitrateEstimates.keySet()) {
                setInitialBitrateEstimate(num.intValue(), j);
            }
            return this;
        }

        public Builder setInitialBitrateEstimate(int i, long j) {
            this.initialBitrateEstimates.put(Integer.valueOf(i), Long.valueOf(j));
            return this;
        }

        public Builder setInitialBitrateEstimate(String str) {
            this.initialBitrateEstimates = getInitialBitrateEstimatesForCountry(Util.toUpperInvariant(str));
            return this;
        }

        public Builder setClock(Clock clock2) {
            this.clock = clock2;
            return this;
        }

        public Builder setResetOnNetworkTypeChange(boolean z) {
            this.resetOnNetworkTypeChange = z;
            return this;
        }

        public DefaultBandwidthMeter build() {
            return new DefaultBandwidthMeter(this.context, this.initialBitrateEstimates, this.slidingWindowMaxWeight, this.clock, this.resetOnNetworkTypeChange);
        }

        private static Map<Integer, Long> getInitialBitrateEstimatesForCountry(String str) {
            ImmutableList<Integer> countryGroupIndices = getCountryGroupIndices(str);
            HashMap hashMap = new HashMap(6);
            hashMap.put(0, 1000000L);
            hashMap.put(2, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_WIFI.get(countryGroupIndices.get(0).intValue()));
            hashMap.put(3, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_2G.get(countryGroupIndices.get(1).intValue()));
            hashMap.put(4, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_3G.get(countryGroupIndices.get(2).intValue()));
            hashMap.put(5, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_4G.get(countryGroupIndices.get(3).intValue()));
            hashMap.put(9, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_5G_NSA.get(countryGroupIndices.get(4).intValue()));
            hashMap.put(7, DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_ESTIMATES_WIFI.get(countryGroupIndices.get(0).intValue()));
            return hashMap;
        }

        private static ImmutableList<Integer> getCountryGroupIndices(String str) {
            ImmutableList<Integer> immutableList = DefaultBandwidthMeter.DEFAULT_INITIAL_BITRATE_COUNTRY_GROUPS.get(str);
            return immutableList.isEmpty() ? ImmutableList.of(2, 2, 2, 2, 2) : immutableList;
        }
    }

    public static synchronized DefaultBandwidthMeter getSingletonInstance(Context context2) {
        DefaultBandwidthMeter defaultBandwidthMeter;
        synchronized (DefaultBandwidthMeter.class) {
            if (singletonInstance == null) {
                singletonInstance = new Builder(context2).build();
            }
            defaultBandwidthMeter = singletonInstance;
        }
        return defaultBandwidthMeter;
    }

    @Deprecated
    public DefaultBandwidthMeter() {
        this(null, ImmutableMap.of(), 2000, Clock.DEFAULT, false);
    }

    private DefaultBandwidthMeter(Context context2, Map<Integer, Long> map, int i, Clock clock2, boolean z) {
        Context context3;
        int i2;
        if (context2 == null) {
            context3 = null;
        } else {
            context3 = context2.getApplicationContext();
        }
        this.context = context3;
        this.initialBitrateEstimates = ImmutableMap.copyOf(map);
        this.eventDispatcher = new BandwidthMeter.EventListener.EventDispatcher();
        this.slidingPercentile = new SlidingPercentile(i);
        this.clock = clock2;
        if (context2 == null) {
            i2 = 0;
        } else {
            i2 = Util.getNetworkType(context2);
        }
        this.networkType = i2;
        this.bitrateEstimate = getInitialBitrateEstimateForNetworkType(this.networkType);
        if (context2 != null && z) {
            ConnectivityActionReceiver.getInstance(context2).register(this);
        }
    }

    public synchronized void setNetworkTypeOverride(int i) {
        this.networkTypeOverride = i;
        this.networkTypeOverrideSet = true;
        onConnectivityAction();
    }

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public synchronized long getBitrateEstimate() {
        return this.bitrateEstimate;
    }

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public void addEventListener(Handler handler, BandwidthMeter.EventListener eventListener) {
        Assertions.checkNotNull(handler);
        Assertions.checkNotNull(eventListener);
        this.eventDispatcher.addListener(handler, eventListener);
    }

    @Override // com.google.android.exoplayer2.upstream.BandwidthMeter
    public void removeEventListener(BandwidthMeter.EventListener eventListener) {
        this.eventDispatcher.removeListener(eventListener);
    }

    @Override // com.google.android.exoplayer2.upstream.TransferListener
    public synchronized void onTransferStart(DataSource dataSource, DataSpec dataSpec, boolean z) {
        if (isTransferAtFullNetworkSpeed(dataSpec, z)) {
            if (this.streamCount == 0) {
                this.sampleStartTimeMs = this.clock.elapsedRealtime();
            }
            this.streamCount++;
        }
    }

    @Override // com.google.android.exoplayer2.upstream.TransferListener
    public synchronized void onBytesTransferred(DataSource dataSource, DataSpec dataSpec, boolean z, int i) {
        if (isTransferAtFullNetworkSpeed(dataSpec, z)) {
            this.sampleBytesTransferred += (long) i;
        }
    }

    @Override // com.google.android.exoplayer2.upstream.TransferListener
    public synchronized void onTransferEnd(DataSource dataSource, DataSpec dataSpec, boolean z) {
        if (isTransferAtFullNetworkSpeed(dataSpec, z)) {
            Assertions.checkState(this.streamCount > 0);
            long elapsedRealtime = this.clock.elapsedRealtime();
            int i = (int) (elapsedRealtime - this.sampleStartTimeMs);
            this.totalElapsedTimeMs += (long) i;
            this.totalBytesTransferred += this.sampleBytesTransferred;
            if (i > 0) {
                this.slidingPercentile.addSample((int) Math.sqrt((double) this.sampleBytesTransferred), (((float) this.sampleBytesTransferred) * 8000.0f) / ((float) i));
                if (this.totalElapsedTimeMs >= 2000 || this.totalBytesTransferred >= PlaybackStateCompat.ACTION_SET_SHUFFLE_MODE_ENABLED) {
                    this.bitrateEstimate = (long) this.slidingPercentile.getPercentile(0.5f);
                }
                maybeNotifyBandwidthSample(i, this.sampleBytesTransferred, this.bitrateEstimate);
                this.sampleStartTimeMs = elapsedRealtime;
                this.sampleBytesTransferred = 0;
            }
            this.streamCount--;
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private synchronized void onConnectivityAction() {
        int i;
        if (this.networkTypeOverrideSet) {
            i = this.networkTypeOverride;
        } else {
            i = this.context == null ? 0 : Util.getNetworkType(this.context);
        }
        if (this.networkType != i) {
            this.networkType = i;
            if (i != 1 && i != 0 && i != 8) {
                this.bitrateEstimate = getInitialBitrateEstimateForNetworkType(i);
                long elapsedRealtime = this.clock.elapsedRealtime();
                maybeNotifyBandwidthSample(this.streamCount > 0 ? (int) (elapsedRealtime - this.sampleStartTimeMs) : 0, this.sampleBytesTransferred, this.bitrateEstimate);
                this.sampleStartTimeMs = elapsedRealtime;
                this.sampleBytesTransferred = 0;
                this.totalBytesTransferred = 0;
                this.totalElapsedTimeMs = 0;
                this.slidingPercentile.reset();
            }
        }
    }

    private void maybeNotifyBandwidthSample(int i, long j, long j2) {
        if (i != 0 || j != 0 || j2 != this.lastReportedBitrateEstimate) {
            this.lastReportedBitrateEstimate = j2;
            this.eventDispatcher.bandwidthSample(i, j, j2);
        }
    }

    private long getInitialBitrateEstimateForNetworkType(int i) {
        Long l = this.initialBitrateEstimates.get(Integer.valueOf(i));
        if (l == null) {
            l = this.initialBitrateEstimates.get(0);
        }
        if (l == null) {
            l = 1000000L;
        }
        return l.longValue();
    }

    private static boolean isTransferAtFullNetworkSpeed(DataSpec dataSpec, boolean z) {
        return z && !dataSpec.isFlagSet(8);
    }

    /* access modifiers changed from: private */
    public static class ConnectivityActionReceiver extends BroadcastReceiver {
        private static ConnectivityActionReceiver staticInstance;
        private final ArrayList<WeakReference<DefaultBandwidthMeter>> bandwidthMeters = new ArrayList<>();
        private final Handler mainHandler = new Handler(Looper.getMainLooper());

        public static synchronized ConnectivityActionReceiver getInstance(Context context) {
            ConnectivityActionReceiver connectivityActionReceiver;
            synchronized (ConnectivityActionReceiver.class) {
                if (staticInstance == null) {
                    staticInstance = new ConnectivityActionReceiver();
                    IntentFilter intentFilter = new IntentFilter();
                    intentFilter.addAction(ConnectivityBroadcastReceiver.CONNECTIVITY_ACTION);
                    context.registerReceiver(staticInstance, intentFilter);
                }
                connectivityActionReceiver = staticInstance;
            }
            return connectivityActionReceiver;
        }

        private ConnectivityActionReceiver() {
        }

        public synchronized void register(DefaultBandwidthMeter defaultBandwidthMeter) {
            removeClearedReferences();
            this.bandwidthMeters.add(new WeakReference<>(defaultBandwidthMeter));
            this.mainHandler.post(new Runnable(defaultBandwidthMeter) {
                /* class com.google.android.exoplayer2.upstream.$$Lambda$DefaultBandwidthMeter$ConnectivityActionReceiver$5orKCfoWtCCTqIpHqEoV8DMTWQ */
                private final /* synthetic */ DefaultBandwidthMeter f$1;

                {
                    this.f$1 = r2;
                }

                public final void run() {
                    DefaultBandwidthMeter.ConnectivityActionReceiver.this.lambda$register$0$DefaultBandwidthMeter$ConnectivityActionReceiver(this.f$1);
                }
            });
        }

        public synchronized void onReceive(Context context, Intent intent) {
            if (!isInitialStickyBroadcast()) {
                removeClearedReferences();
                for (int i = 0; i < this.bandwidthMeters.size(); i++) {
                    DefaultBandwidthMeter defaultBandwidthMeter = this.bandwidthMeters.get(i).get();
                    if (defaultBandwidthMeter != null) {
                        lambda$register$0$DefaultBandwidthMeter$ConnectivityActionReceiver(defaultBandwidthMeter);
                    }
                }
            }
        }

        /* access modifiers changed from: private */
        /* renamed from: updateBandwidthMeter */
        public void lambda$register$0$DefaultBandwidthMeter$ConnectivityActionReceiver(DefaultBandwidthMeter defaultBandwidthMeter) {
            defaultBandwidthMeter.onConnectivityAction();
        }

        private void removeClearedReferences() {
            for (int size = this.bandwidthMeters.size() - 1; size >= 0; size--) {
                if (this.bandwidthMeters.get(size).get() == null) {
                    this.bandwidthMeters.remove(size);
                }
            }
        }
    }

    private static ImmutableListMultimap<String, Integer> createInitialBitrateCountryGroupAssignment() {
        ImmutableListMultimap.Builder builder = ImmutableListMultimap.builder();
        builder.putAll((Object) "AD", (Object[]) new Integer[]{1, 2, 0, 0, 2});
        builder.putAll((Object) "AE", (Object[]) new Integer[]{1, 4, 4, 4, 1});
        builder.putAll((Object) "AF", (Object[]) new Integer[]{4, 4, 3, 4, 2});
        builder.putAll((Object) "AG", (Object[]) new Integer[]{2, 2, 1, 1, 2});
        builder.putAll((Object) "AI", (Object[]) new Integer[]{1, 2, 2, 2, 2});
        builder.putAll((Object) "AL", (Object[]) new Integer[]{1, 1, 0, 1, 2});
        builder.putAll((Object) "AM", (Object[]) new Integer[]{2, 2, 1, 2, 2});
        builder.putAll((Object) "AO", (Object[]) new Integer[]{3, 4, 4, 2, 2});
        builder.putAll((Object) "AR", (Object[]) new Integer[]{2, 4, 2, 2, 2});
        builder.putAll((Object) "AS", (Object[]) new Integer[]{2, 2, 4, 3, 2});
        builder.putAll((Object) "AT", (Object[]) new Integer[]{0, 3, 0, 0, 2});
        builder.putAll((Object) "AU", (Object[]) new Integer[]{0, 2, 0, 1, 1});
        builder.putAll((Object) "AW", (Object[]) new Integer[]{1, 2, 0, 4, 2});
        builder.putAll((Object) "AX", (Object[]) new Integer[]{0, 2, 2, 2, 2});
        builder.putAll((Object) "AZ", (Object[]) new Integer[]{3, 3, 3, 4, 2});
        builder.putAll((Object) "BA", (Object[]) new Integer[]{1, 1, 0, 1, 2});
        builder.putAll((Object) "BB", (Object[]) new Integer[]{0, 2, 0, 0, 2});
        builder.putAll((Object) "BD", (Object[]) new Integer[]{2, 0, 3, 3, 2});
        builder.putAll((Object) "BE", (Object[]) new Integer[]{0, 1, 2, 3, 2});
        builder.putAll((Object) "BF", (Object[]) new Integer[]{4, 4, 4, 2, 2});
        builder.putAll((Object) "BG", (Object[]) new Integer[]{0, 1, 0, 0, 2});
        builder.putAll((Object) "BH", (Object[]) new Integer[]{1, 0, 2, 4, 2});
        builder.putAll((Object) "BI", (Object[]) new Integer[]{4, 4, 4, 4, 2});
        builder.putAll((Object) "BJ", (Object[]) new Integer[]{4, 4, 3, 4, 2});
        builder.putAll((Object) "BL", (Object[]) new Integer[]{1, 2, 2, 2, 2});
        builder.putAll((Object) "BM", (Object[]) new Integer[]{1, 2, 0, 0, 2});
        builder.putAll((Object) "BN", (Object[]) new Integer[]{4, 0, 1, 1, 2});
        builder.putAll((Object) "BO", (Object[]) new Integer[]{2, 3, 3, 2, 2});
        builder.putAll((Object) "BQ", (Object[]) new Integer[]{1, 2, 1, 2, 2});
        builder.putAll((Object) "BR", (Object[]) new Integer[]{2, 4, 2, 1, 2});
        builder.putAll((Object) "BS", (Object[]) new Integer[]{3, 2, 2, 3, 2});
        builder.putAll((Object) "BT", (Object[]) new Integer[]{3, 0, 3, 2, 2});
        builder.putAll((Object) "BW", (Object[]) new Integer[]{3, 4, 2, 2, 2});
        builder.putAll((Object) "BY", (Object[]) new Integer[]{1, 0, 2, 1, 2});
        builder.putAll((Object) "BZ", (Object[]) new Integer[]{2, 2, 2, 1, 2});
        builder.putAll((Object) "CA", (Object[]) new Integer[]{0, 3, 1, 2, 3});
        builder.putAll((Object) "CD", (Object[]) new Integer[]{4, 3, 2, 2, 2});
        builder.putAll((Object) "CF", (Object[]) new Integer[]{4, 2, 2, 2, 2});
        builder.putAll((Object) "CG", (Object[]) new Integer[]{3, 4, 1, 1, 2});
        builder.putAll((Object) "CH", (Object[]) new Integer[]{0, 1, 0, 0, 0});
        builder.putAll((Object) "CI", (Object[]) new Integer[]{3, 3, 3, 3, 2});
        builder.putAll((Object) "CK", (Object[]) new Integer[]{3, 2, 1, 0, 2});
        builder.putAll((Object) "CL", (Object[]) new Integer[]{1, 1, 2, 3, 2});
        builder.putAll((Object) "CM", (Object[]) new Integer[]{3, 4, 3, 2, 2});
        builder.putAll((Object) "CN", (Object[]) new Integer[]{2, 2, 2, 1, 3});
        builder.putAll((Object) "CO", (Object[]) new Integer[]{2, 4, 3, 2, 2});
        builder.putAll((Object) "CR", (Object[]) new Integer[]{2, 3, 4, 4, 2});
        builder.putAll((Object) "CU", (Object[]) new Integer[]{4, 4, 2, 1, 2});
        builder.putAll((Object) "CV", (Object[]) new Integer[]{2, 3, 3, 3, 2});
        builder.putAll((Object) "CW", (Object[]) new Integer[]{1, 2, 0, 0, 2});
        builder.putAll((Object) "CY", (Object[]) new Integer[]{1, 2, 0, 0, 2});
        builder.putAll((Object) "CZ", (Object[]) new Integer[]{0, 1, 0, 0, 2});
        builder.putAll((Object) "DE", (Object[]) new Integer[]{0, 1, 1, 2, 0});
        builder.putAll((Object) "DJ", (Object[]) new Integer[]{4, 1, 4, 4, 2});
        builder.putAll((Object) "DK", (Object[]) new Integer[]{0, 0, 1, 0, 2});
        builder.putAll((Object) "DM", (Object[]) new Integer[]{1, 2, 2, 2, 2});
        builder.putAll((Object) "DO", (Object[]) new Integer[]{3, 4, 4, 4, 2});
        builder.putAll((Object) "DZ", (Object[]) new Integer[]{3, 2, 4, 4, 2});
        builder.putAll((Object) "EC", (Object[]) new Integer[]{2, 4, 3, 2, 2});
        builder.putAll((Object) "EE", (Object[]) new Integer[]{0, 0, 0, 0, 2});
        builder.putAll((Object) "EG", (Object[]) new Integer[]{3, 4, 2, 1, 2});
        builder.putAll((Object) "EH", (Object[]) new Integer[]{2, 2, 2, 2, 2});
        builder.putAll((Object) "ER", (Object[]) new Integer[]{4, 2, 2, 2, 2});
        builder.putAll((Object) "ES", (Object[]) new Integer[]{0, 1, 2, 1, 2});
        builder.putAll((Object) "ET", (Object[]) new Integer[]{4, 4, 4, 1, 2});
        builder.putAll((Object) "FI", (Object[]) new Integer[]{0, 0, 1, 0, 0});
        builder.putAll((Object) "FJ", (Object[]) new Integer[]{3, 0, 3, 3, 2});
        builder.putAll((Object) "FK", (Object[]) new Integer[]{2, 2, 2, 2, 2});
        builder.putAll((Object) "FM", (Object[]) new Integer[]{4, 2, 4, 3, 2});
        builder.putAll((Object) "FO", (Object[]) new Integer[]{0, 2, 0, 0, 2});
        builder.putAll((Object) "FR", (Object[]) new Integer[]{1, 0, 2, 1, 2});
        builder.putAll((Object) "GA", (Object[]) new Integer[]{3, 3, 1, 0, 2});
        builder.putAll((Object) "GB", (Object[]) new Integer[]{0, 0, 1, 2, 2});
        builder.putAll((Object) "GD", (Object[]) new Integer[]{1, 2, 2, 2, 2});
        builder.putAll((Object) "GE", (Object[]) new Integer[]{1, 0, 1, 3, 2});
        builder.putAll((Object) "GF", (Object[]) new Integer[]{2, 2, 2, 4, 2});
        builder.putAll((Object) "GG", (Object[]) new Integer[]{0, 2, 0, 0, 2});
        builder.putAll((Object) "GH", (Object[]) new Integer[]{3, 2, 3, 2, 2});
        builder.putAll((Object) "GI", (Object[]) new Integer[]{0, 2, 0, 0, 2});
        builder.putAll((Object) "GL", (Object[]) new Integer[]{1, 2, 2, 1, 2});
        builder.putAll((Object) "GM", (Object[]) new Integer[]{4, 3, 2, 4, 2});
        builder.putAll((Object) "GN", (Object[]) new Integer[]{4, 3, 4, 2, 2});
        builder.putAll((Object) "GP", (Object[]) new Integer[]{2, 2, 3, 4, 2});
        builder.putAll((Object) "GQ", (Object[]) new Integer[]{4, 2, 3, 4, 2});
        builder.putAll((Object) "GR", (Object[]) new Integer[]{1, 1, 0, 1, 2});
        builder.putAll((Object) "GT", (Object[]) new Integer[]{3, 2, 3, 2, 2});
        builder.putAll((Object) "GU", (Object[]) new Integer[]{1, 2, 4, 4, 2});
        builder.putAll((Object) "GW", (Object[]) new Integer[]{3, 4, 4, 3, 2});
        builder.putAll((Object) "GY", (Object[]) new Integer[]{3, 3, 1, 0, 2});
        builder.putAll((Object) "HK", (Object[]) new Integer[]{0, 2, 3, 4, 2});
        builder.putAll((Object) "HN", (Object[]) new Integer[]{3, 0, 3, 3, 2});
        builder.putAll((Object) "HR", (Object[]) new Integer[]{1, 1, 0, 1, 2});
        builder.putAll((Object) "HT", (Object[]) new Integer[]{4, 3, 4, 4, 2});
        builder.putAll((Object) "HU", (Object[]) new Integer[]{0, 1, 0, 0, 2});
        builder.putAll((Object) "ID", (Object[]) new Integer[]{3, 2, 2, 3, 2});
        builder.putAll((Object) "IE", (Object[]) new Integer[]{0, 0, 1, 1, 2});
        builder.putAll((Object) "IL", (Object[]) new Integer[]{1, 0, 2, 3, 2});
        builder.putAll((Object) "IM", (Object[]) new Integer[]{0, 2, 0, 1, 2});
        builder.putAll((Object) "IN", (Object[]) new Integer[]{2, 1, 3, 3, 2});
        builder.putAll((Object) "IO", (Object[]) new Integer[]{4, 2, 2, 4, 2});
        builder.putAll((Object) "IQ", (Object[]) new Integer[]{3, 2, 4, 3, 2});
        builder.putAll((Object) "IR", (Object[]) new Integer[]{4, 2, 3, 4, 2});
        builder.putAll((Object) "IS", (Object[]) new Integer[]{0, 2, 0, 0, 2});
        builder.putAll((Object) "IT", (Object[]) new Integer[]{0, 0, 1, 1, 2});
        builder.putAll((Object) "JE", (Object[]) new Integer[]{2, 2, 0, 2, 2});
        builder.putAll((Object) "JM", (Object[]) new Integer[]{3, 3, 4, 4, 2});
        builder.putAll((Object) "JO", (Object[]) new Integer[]{1, 2, 1, 1, 2});
        builder.putAll((Object) "JP", (Object[]) new Integer[]{0, 2, 0, 1, 3});
        builder.putAll((Object) "KE", (Object[]) new Integer[]{3, 4, 2, 2, 2});
        builder.putAll((Object) ExpandedProductParsedResult.KILOGRAM, (Object[]) new Integer[]{1, 0, 2, 2, 2});
        builder.putAll((Object) "KH", (Object[]) new Integer[]{2, 0, 4, 3, 2});
        builder.putAll((Object) "KI", (Object[]) new Integer[]{4, 2, 3, 1, 2});
        builder.putAll((Object) "KM", (Object[]) new Integer[]{4, 2, 2, 3, 2});
        builder.putAll((Object) "KN", (Object[]) new Integer[]{1, 2, 2, 2, 2});
        builder.putAll((Object) "KP", (Object[]) new Integer[]{4, 2, 2, 2, 2});
        builder.putAll((Object) "KR", (Object[]) new Integer[]{0, 2, 1, 1, 1});
        builder.putAll((Object) "KW", (Object[]) new Integer[]{2, 3, 1, 1, 1});
        builder.putAll((Object) "KY", (Object[]) new Integer[]{1, 2, 0, 0, 2});
        builder.putAll((Object) "KZ", (Object[]) new Integer[]{1, 2, 2, 3, 2});
        builder.putAll((Object) "LA", (Object[]) new Integer[]{2, 2, 1, 1, 2});
        builder.putAll((Object) ExpandedProductParsedResult.POUND, (Object[]) new Integer[]{3, 2, 0, 0, 2});
        builder.putAll((Object) "LC", (Object[]) new Integer[]{1, 1, 0, 0, 2});
        builder.putAll((Object) "LI", (Object[]) new Integer[]{0, 2, 2, 2, 2});
        builder.putAll((Object) "LK", (Object[]) new Integer[]{2, 0, 2, 3, 2});
        builder.putAll((Object) "LR", (Object[]) new Integer[]{3, 4, 3, 2, 2});
        builder.putAll((Object) "LS", (Object[]) new Integer[]{3, 3, 2, 3, 2});
        builder.putAll((Object) "LT", (Object[]) new Integer[]{0, 0, 0, 0, 2});
        builder.putAll((Object) "LU", (Object[]) new Integer[]{0, 0, 0, 0, 2});
        builder.putAll((Object) "LV", (Object[]) new Integer[]{0, 0, 0, 0, 2});
        builder.putAll((Object) "LY", (Object[]) new Integer[]{4, 2, 4, 3, 2});
        builder.putAll((Object) "MA", (Object[]) new Integer[]{2, 1, 2, 1, 2});
        builder.putAll((Object) "MC", (Object[]) new Integer[]{0, 2, 2, 2, 2});
        builder.putAll((Object) "MD", (Object[]) new Integer[]{1, 2, 0, 0, 2});
        builder.putAll((Object) "ME", (Object[]) new Integer[]{1, 2, 1, 2, 2});
        builder.putAll((Object) "MF", (Object[]) new Integer[]{1, 2, 1, 0, 2});
        builder.putAll((Object) "MG", (Object[]) new Integer[]{3, 4, 3, 3, 2});
        builder.putAll((Object) "MH", (Object[]) new Integer[]{4, 2, 2, 4, 2});
        builder.putAll((Object) "MK", (Object[]) new Integer[]{1, 0, 0, 0, 2});
        builder.putAll((Object) "ML", (Object[]) new Integer[]{4, 4, 1, 1, 2});
        builder.putAll((Object) "MM", (Object[]) new Integer[]{2, 3, 2, 2, 2});
        builder.putAll((Object) "MN", (Object[]) new Integer[]{2, 4, 1, 1, 2});
        builder.putAll((Object) "MO", (Object[]) new Integer[]{0, 2, 4, 4, 2});
        builder.putAll((Object) "MP", (Object[]) new Integer[]{0, 2, 2, 2, 2});
        builder.putAll((Object) "MQ", (Object[]) new Integer[]{2, 2, 2, 3, 2});
        builder.putAll((Object) "MR", (Object[]) new Integer[]{3, 0, 4, 2, 2});
        builder.putAll((Object) "MS", (Object[]) new Integer[]{1, 2, 2, 2, 2});
        builder.putAll((Object) "MT", (Object[]) new Integer[]{0, 2, 0, 1, 2});
        builder.putAll((Object) "MU", (Object[]) new Integer[]{3, 1, 2, 3, 2});
        builder.putAll((Object) "MV", (Object[]) new Integer[]{4, 3, 1, 4, 2});
        builder.putAll((Object) "MW", (Object[]) new Integer[]{4, 1, 1, 0, 2});
        builder.putAll((Object) "MX", (Object[]) new Integer[]{2, 4, 3, 3, 2});
        builder.putAll((Object) "MY", (Object[]) new Integer[]{2, 0, 3, 3, 2});
        builder.putAll((Object) "MZ", (Object[]) new Integer[]{3, 3, 2, 3, 2});
        builder.putAll((Object) "NA", (Object[]) new Integer[]{4, 3, 2, 2, 2});
        builder.putAll((Object) "NC", (Object[]) new Integer[]{2, 0, 4, 4, 2});
        builder.putAll((Object) "NE", (Object[]) new Integer[]{4, 4, 4, 4, 2});
        builder.putAll((Object) "NF", (Object[]) new Integer[]{2, 2, 2, 2, 2});
        builder.putAll((Object) "NG", (Object[]) new Integer[]{3, 3, 2, 2, 2});
        builder.putAll((Object) "NI", (Object[]) new Integer[]{3, 1, 4, 4, 2});
        builder.putAll((Object) "NL", (Object[]) new Integer[]{0, 2, 4, 2, 0});
        builder.putAll((Object) "NO", (Object[]) new Integer[]{0, 1, 1, 0, 2});
        builder.putAll((Object) "NP", (Object[]) new Integer[]{2, 0, 4, 3, 2});
        builder.putAll((Object) "NR", (Object[]) new Integer[]{4, 2, 3, 1, 2});
        builder.putAll((Object) "NU", (Object[]) new Integer[]{4, 2, 2, 2, 2});
        builder.putAll((Object) "NZ", (Object[]) new Integer[]{0, 2, 1, 2, 4});
        builder.putAll((Object) "OM", (Object[]) new Integer[]{2, 2, 0, 2, 2});
        builder.putAll((Object) "PA", (Object[]) new Integer[]{1, 3, 3, 4, 2});
        builder.putAll((Object) "PE", (Object[]) new Integer[]{2, 4, 4, 4, 2});
        builder.putAll((Object) "PF", (Object[]) new Integer[]{2, 2, 1, 1, 2});
        builder.putAll((Object) "PG", (Object[]) new Integer[]{4, 3, 3, 2, 2});
        builder.putAll((Object) "PH", (Object[]) new Integer[]{3, 0, 3, 4, 4});
        builder.putAll((Object) "PK", (Object[]) new Integer[]{3, 2, 3, 3, 2});
        builder.putAll((Object) "PL", (Object[]) new Integer[]{1, 0, 2, 2, 2});
        builder.putAll((Object) "PM", (Object[]) new Integer[]{0, 2, 2, 2, 2});
        builder.putAll((Object) "PR", (Object[]) new Integer[]{1, 2, 2, 3, 4});
        builder.putAll((Object) "PS", (Object[]) new Integer[]{3, 3, 2, 2, 2});
        builder.putAll((Object) "PT", (Object[]) new Integer[]{1, 1, 0, 0, 2});
        builder.putAll((Object) "PW", (Object[]) new Integer[]{1, 2, 3, 0, 2});
        builder.putAll((Object) "PY", (Object[]) new Integer[]{2, 0, 3, 3, 2});
        builder.putAll((Object) "QA", (Object[]) new Integer[]{2, 3, 1, 2, 2});
        builder.putAll((Object) "RE", (Object[]) new Integer[]{1, 0, 2, 1, 2});
        builder.putAll((Object) "RO", (Object[]) new Integer[]{1, 1, 1, 2, 2});
        builder.putAll((Object) "RS", (Object[]) new Integer[]{1, 2, 0, 0, 2});
        builder.putAll((Object) "RU", (Object[]) new Integer[]{0, 1, 0, 1, 2});
        builder.putAll((Object) "RW", (Object[]) new Integer[]{4, 3, 3, 4, 2});
        builder.putAll((Object) "SA", (Object[]) new Integer[]{2, 2, 2, 1, 2});
        builder.putAll((Object) "SB", (Object[]) new Integer[]{4, 2, 4, 2, 2});
        builder.putAll((Object) "SC", (Object[]) new Integer[]{4, 2, 0, 1, 2});
        builder.putAll((Object) "SD", (Object[]) new Integer[]{4, 4, 4, 3, 2});
        builder.putAll((Object) "SE", (Object[]) new Integer[]{0, 0, 0, 0, 2});
        builder.putAll((Object) "SG", (Object[]) new Integer[]{0, 0, 3, 3, 4});
        builder.putAll((Object) "SH", (Object[]) new Integer[]{4, 2, 2, 2, 2});
        builder.putAll((Object) "SI", (Object[]) new Integer[]{0, 1, 0, 0, 2});
        builder.putAll((Object) "SJ", (Object[]) new Integer[]{2, 2, 2, 2, 2});
        builder.putAll((Object) "SK", (Object[]) new Integer[]{0, 1, 0, 0, 2});
        builder.putAll((Object) "SL", (Object[]) new Integer[]{4, 3, 3, 1, 2});
        builder.putAll((Object) "SM", (Object[]) new Integer[]{0, 2, 2, 2, 2});
        builder.putAll((Object) "SN", (Object[]) new Integer[]{4, 4, 4, 3, 2});
        builder.putAll((Object) "SO", (Object[]) new Integer[]{3, 4, 4, 4, 2});
        builder.putAll((Object) "SR", (Object[]) new Integer[]{3, 2, 3, 1, 2});
        builder.putAll((Object) "SS", (Object[]) new Integer[]{4, 1, 4, 2, 2});
        builder.putAll((Object) "ST", (Object[]) new Integer[]{2, 2, 1, 2, 2});
        builder.putAll((Object) "SV", (Object[]) new Integer[]{2, 1, 4, 4, 2});
        builder.putAll((Object) "SX", (Object[]) new Integer[]{2, 2, 1, 0, 2});
        builder.putAll((Object) "SY", (Object[]) new Integer[]{4, 3, 2, 2, 2});
        builder.putAll((Object) "SZ", (Object[]) new Integer[]{3, 4, 3, 4, 2});
        builder.putAll((Object) "TC", (Object[]) new Integer[]{1, 2, 1, 0, 2});
        builder.putAll((Object) "TD", (Object[]) new Integer[]{4, 4, 4, 4, 2});
        builder.putAll((Object) "TG", (Object[]) new Integer[]{3, 2, 1, 0, 2});
        builder.putAll((Object) "TH", (Object[]) new Integer[]{1, 3, 4, 3, 0});
        builder.putAll((Object) "TJ", (Object[]) new Integer[]{4, 4, 4, 4, 2});
        builder.putAll((Object) "TL", (Object[]) new Integer[]{4, 1, 4, 4, 2});
        builder.putAll((Object) "TM", (Object[]) new Integer[]{4, 2, 1, 2, 2});
        builder.putAll((Object) "TN", (Object[]) new Integer[]{2, 1, 1, 1, 2});
        builder.putAll((Object) "TO", (Object[]) new Integer[]{3, 3, 4, 2, 2});
        builder.putAll((Object) "TR", (Object[]) new Integer[]{1, 2, 1, 1, 2});
        builder.putAll((Object) "TT", (Object[]) new Integer[]{1, 3, 1, 3, 2});
        builder.putAll((Object) "TV", (Object[]) new Integer[]{3, 2, 2, 4, 2});
        builder.putAll((Object) "TW", (Object[]) new Integer[]{0, 0, 0, 0, 1});
        builder.putAll((Object) "TZ", (Object[]) new Integer[]{3, 3, 3, 2, 2});
        builder.putAll((Object) "UA", (Object[]) new Integer[]{0, 3, 0, 0, 2});
        builder.putAll((Object) "UG", (Object[]) new Integer[]{3, 2, 2, 3, 2});
        builder.putAll((Object) "US", (Object[]) new Integer[]{0, 1, 3, 3, 3});
        builder.putAll((Object) "UY", (Object[]) new Integer[]{2, 1, 1, 1, 2});
        builder.putAll((Object) "UZ", (Object[]) new Integer[]{2, 0, 3, 2, 2});
        builder.putAll((Object) "VC", (Object[]) new Integer[]{2, 2, 2, 2, 2});
        builder.putAll((Object) "VE", (Object[]) new Integer[]{4, 4, 4, 4, 2});
        builder.putAll((Object) "VG", (Object[]) new Integer[]{2, 2, 1, 2, 2});
        builder.putAll((Object) "VI", (Object[]) new Integer[]{1, 2, 2, 4, 2});
        builder.putAll((Object) "VN", (Object[]) new Integer[]{0, 1, 4, 4, 2});
        builder.putAll((Object) "VU", (Object[]) new Integer[]{4, 1, 3, 1, 2});
        builder.putAll((Object) "WS", (Object[]) new Integer[]{3, 1, 4, 2, 2});
        builder.putAll((Object) "XK", (Object[]) new Integer[]{1, 1, 1, 0, 2});
        builder.putAll((Object) "YE", (Object[]) new Integer[]{4, 4, 4, 4, 2});
        builder.putAll((Object) "YT", (Object[]) new Integer[]{3, 2, 1, 3, 2});
        builder.putAll((Object) "ZA", (Object[]) new Integer[]{2, 3, 2, 2, 2});
        builder.putAll((Object) "ZM", (Object[]) new Integer[]{3, 2, 2, 3, 2});
        builder.putAll((Object) "ZW", (Object[]) new Integer[]{3, 3, 3, 3, 2});
        return builder.build();
    }
}
