package com.google.android.exoplayer2.util;

import java.lang.Exception;
import java.util.concurrent.CancellationException;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.RunnableFuture;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

public abstract class RunnableFutureTask<R, E extends Exception> implements RunnableFuture<R> {
    private final Object cancelLock = new Object();
    private boolean canceled;
    private Exception exception;
    private final ConditionVariable finished = new ConditionVariable();
    private R result;
    private final ConditionVariable started = new ConditionVariable();
    private Thread workThread;

    /* access modifiers changed from: protected */
    public void cancelWork() {
    }

    /* access modifiers changed from: protected */
    public abstract R doWork() throws Exception;

    protected RunnableFutureTask() {
    }

    public final void blockUntilStarted() {
        this.started.blockUninterruptible();
    }

    public final void blockUntilFinished() {
        this.finished.blockUninterruptible();
    }

    @Override // java.util.concurrent.Future
    public final R get() throws ExecutionException, InterruptedException {
        this.finished.block();
        return getResult();
    }

    @Override // java.util.concurrent.Future
    public final R get(long j, TimeUnit timeUnit) throws ExecutionException, InterruptedException, TimeoutException {
        if (this.finished.block(TimeUnit.MILLISECONDS.convert(j, timeUnit))) {
            return getResult();
        }
        throw new TimeoutException();
    }

    public final boolean cancel(boolean z) {
        synchronized (this.cancelLock) {
            if (!this.canceled) {
                if (!this.finished.isOpen()) {
                    this.canceled = true;
                    cancelWork();
                    Thread thread = this.workThread;
                    if (thread == null) {
                        this.started.open();
                        this.finished.open();
                    } else if (z) {
                        thread.interrupt();
                    }
                    return true;
                }
            }
            return false;
        }
    }

    public final boolean isDone() {
        return this.finished.isOpen();
    }

    public final boolean isCancelled() {
        return this.canceled;
    }

    public final void run() {
        synchronized (this.cancelLock) {
            if (!this.canceled) {
                this.workThread = Thread.currentThread();
                this.started.open();
                try {
                    this.result = doWork();
                    synchronized (this.cancelLock) {
                        this.finished.open();
                        this.workThread = null;
                        Thread.interrupted();
                    }
                } catch (Exception e) {
                    try {
                        this.exception = e;
                        synchronized (this.cancelLock) {
                            this.finished.open();
                            this.workThread = null;
                            Thread.interrupted();
                        }
                    } catch (Throwable th) {
                        synchronized (this.cancelLock) {
                            this.finished.open();
                            this.workThread = null;
                            Thread.interrupted();
                            throw th;
                        }
                    }
                }
            }
        }
    }

    private R getResult() throws ExecutionException {
        if (!this.canceled) {
            Exception exc = this.exception;
            if (exc == null) {
                return this.result;
            }
            throw new ExecutionException(exc);
        }
        throw new CancellationException();
    }
}
