package com.google.android.exoplayer2.video;

import android.content.Context;
import android.graphics.Point;
import android.media.MediaCodec;
import android.media.MediaCrypto;
import android.media.MediaFormat;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.os.SystemClock;
import android.util.Pair;
import android.view.Surface;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.ExoPlaybackException;
import com.google.android.exoplayer2.Format;
import com.google.android.exoplayer2.FormatHolder;
import com.google.android.exoplayer2.RendererCapabilities;
import com.google.android.exoplayer2.decoder.DecoderInputBuffer;
import com.google.android.exoplayer2.extractor.ts.TsExtractor;
import com.google.android.exoplayer2.mediacodec.MediaCodecAdapter;
import com.google.android.exoplayer2.mediacodec.MediaCodecDecoderException;
import com.google.android.exoplayer2.mediacodec.MediaCodecInfo;
import com.google.android.exoplayer2.mediacodec.MediaCodecRenderer;
import com.google.android.exoplayer2.mediacodec.MediaCodecSelector;
import com.google.android.exoplayer2.mediacodec.MediaCodecUtil;
import com.google.android.exoplayer2.mediacodec.MediaFormatUtil;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.Log;
import com.google.android.exoplayer2.util.MimeTypes;
import com.google.android.exoplayer2.util.TraceUtil;
import com.google.android.exoplayer2.util.Util;
import com.google.android.exoplayer2.video.VideoRendererEventListener;
import com.google.common.base.Ascii;
import io.flutter.plugin.platform.PlatformPlugin;
import java.lang.reflect.Method;
import java.nio.ByteBuffer;
import java.util.Collections;
import java.util.List;
import kotlin.text.Typography;
import tv.danmaku.ijk.media.player.IjkMediaPlayer;
import tv.danmaku.ijk.media.player.misc.IMediaFormat;

public class MediaCodecVideoRenderer extends MediaCodecRenderer {
    private static final float INITIAL_FORMAT_MAX_INPUT_SIZE_SCALE_FACTOR = 1.5f;
    private static final String KEY_CROP_BOTTOM = "crop-bottom";
    private static final String KEY_CROP_LEFT = "crop-left";
    private static final String KEY_CROP_RIGHT = "crop-right";
    private static final String KEY_CROP_TOP = "crop-top";
    private static final int[] STANDARD_LONG_EDGE_VIDEO_PX = {1920, 1600, 1440, PlatformPlugin.DEFAULT_SYSTEM_UI, 960, 854, 640, 540, IjkMediaPlayer.IJK_MSG_VIDEO_SNAP_SHOT};
    private static final int SURFACE_FRAME_RATE_COMPATIBILITY_DEFAULT = 0;
    private static final int SURFACE_FRAME_RATE_COMPATIBILITY_FIXED_SOURCE = 1;
    private static final String TAG = "MediaCodecVideoRenderer";
    private static final long TUNNELING_EOS_PRESENTATION_TIME_US = Long.MAX_VALUE;
    private static boolean deviceNeedsSetOutputSurfaceWorkaround;
    private static boolean evaluatedDeviceNeedsSetOutputSurfaceWorkaround;
    private static final Method surfaceSetFrameRateMethod;
    private final long allowedJoiningTimeMs;
    private int buffersInCodecCount;
    private boolean codecHandlesHdr10PlusOutOfBandMetadata;
    private CodecMaxValues codecMaxValues;
    private boolean codecNeedsSetOutputSurfaceWorkaround;
    private int consecutiveDroppedFrameCount;
    private final Context context;
    private float currentFrameRate;
    private int currentHeight;
    private float currentPixelWidthHeightRatio;
    private int currentUnappliedRotationDegrees;
    private int currentWidth;
    private final boolean deviceNeedsNoPostProcessWorkaround;
    private long droppedFrameAccumulationStartTimeMs;
    private int droppedFrames;
    private Surface dummySurface;
    private final VideoRendererEventListener.EventDispatcher eventDispatcher;
    private VideoFrameMetadataListener frameMetadataListener;
    private final VideoFrameReleaseTimeHelper frameReleaseTimeHelper;
    private boolean haveReportedFirstFrameRenderedForCurrentSurface;
    private long initialPositionUs;
    private long joiningDeadlineMs;
    private long lastRenderTimeUs;
    private final int maxDroppedFramesToNotify;
    private boolean mayRenderFirstFrameAfterEnableIfNotStarted;
    private boolean renderedFirstFrameAfterEnable;
    private boolean renderedFirstFrameAfterReset;
    private int reportedHeight;
    private float reportedPixelWidthHeightRatio;
    private int reportedUnappliedRotationDegrees;
    private int reportedWidth;
    private int scalingMode;
    private Surface surface;
    private float surfaceFrameRate;
    private long totalVideoFrameProcessingOffsetUs;
    private boolean tunneling;
    private int tunnelingAudioSessionId;
    OnFrameRenderedListenerV23 tunnelingOnFrameRenderedListener;
    private int videoFrameProcessingOffsetCount;

    private static boolean isBufferLate(long j) {
        return j < -30000;
    }

    private static boolean isBufferVeryLate(long j) {
        return j < -500000;
    }

    @Override // com.google.android.exoplayer2.RendererCapabilities, com.google.android.exoplayer2.Renderer
    public String getName() {
        return TAG;
    }

    static {
        Method method;
        if (Util.SDK_INT >= 30) {
            try {
                method = Surface.class.getMethod("setFrameRate", Float.TYPE, Integer.TYPE);
            } catch (NoSuchMethodException unused) {
            }
            surfaceSetFrameRateMethod = method;
        }
        method = null;
        surfaceSetFrameRateMethod = method;
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecSelector mediaCodecSelector) {
        this(context2, mediaCodecSelector, 0);
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecSelector mediaCodecSelector, long j) {
        this(context2, mediaCodecSelector, j, null, null, -1);
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecSelector mediaCodecSelector, long j, Handler handler, VideoRendererEventListener videoRendererEventListener, int i) {
        this(context2, mediaCodecSelector, j, false, handler, videoRendererEventListener, i);
    }

    public MediaCodecVideoRenderer(Context context2, MediaCodecSelector mediaCodecSelector, long j, boolean z, Handler handler, VideoRendererEventListener videoRendererEventListener, int i) {
        super(2, mediaCodecSelector, z, 30.0f);
        this.allowedJoiningTimeMs = j;
        this.maxDroppedFramesToNotify = i;
        this.context = context2.getApplicationContext();
        this.frameReleaseTimeHelper = new VideoFrameReleaseTimeHelper(this.context);
        this.eventDispatcher = new VideoRendererEventListener.EventDispatcher(handler, videoRendererEventListener);
        this.deviceNeedsNoPostProcessWorkaround = deviceNeedsNoPostProcessWorkaround();
        this.joiningDeadlineMs = C.TIME_UNSET;
        this.currentWidth = -1;
        this.currentHeight = -1;
        this.currentPixelWidthHeightRatio = -1.0f;
        this.scalingMode = 1;
        clearReportedVideoSize();
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public int supportsFormat(MediaCodecSelector mediaCodecSelector, Format format) throws MediaCodecUtil.DecoderQueryException {
        int i = 0;
        if (!MimeTypes.isVideo(format.sampleMimeType)) {
            return RendererCapabilities.CC.create(0);
        }
        boolean z = format.drmInitData != null;
        List<MediaCodecInfo> decoderInfos = getDecoderInfos(mediaCodecSelector, format, z, false);
        if (z && decoderInfos.isEmpty()) {
            decoderInfos = getDecoderInfos(mediaCodecSelector, format, false, false);
        }
        if (decoderInfos.isEmpty()) {
            return RendererCapabilities.CC.create(1);
        }
        if (!supportsFormatDrm(format)) {
            return RendererCapabilities.CC.create(2);
        }
        MediaCodecInfo mediaCodecInfo = decoderInfos.get(0);
        boolean isFormatSupported = mediaCodecInfo.isFormatSupported(format);
        int i2 = mediaCodecInfo.isSeamlessAdaptationSupported(format) ? 16 : 8;
        if (isFormatSupported) {
            List<MediaCodecInfo> decoderInfos2 = getDecoderInfos(mediaCodecSelector, format, z, true);
            if (!decoderInfos2.isEmpty()) {
                MediaCodecInfo mediaCodecInfo2 = decoderInfos2.get(0);
                if (mediaCodecInfo2.isFormatSupported(format) && mediaCodecInfo2.isSeamlessAdaptationSupported(format)) {
                    i = 32;
                }
            }
        }
        return RendererCapabilities.CC.create(isFormatSupported ? 4 : 3, i2, i);
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public List<MediaCodecInfo> getDecoderInfos(MediaCodecSelector mediaCodecSelector, Format format, boolean z) throws MediaCodecUtil.DecoderQueryException {
        return getDecoderInfos(mediaCodecSelector, format, z, this.tunneling);
    }

    private static List<MediaCodecInfo> getDecoderInfos(MediaCodecSelector mediaCodecSelector, Format format, boolean z, boolean z2) throws MediaCodecUtil.DecoderQueryException {
        Pair<Integer, Integer> codecProfileAndLevel;
        String str = format.sampleMimeType;
        if (str == null) {
            return Collections.emptyList();
        }
        List<MediaCodecInfo> decoderInfosSortedByFormatSupport = MediaCodecUtil.getDecoderInfosSortedByFormatSupport(mediaCodecSelector.getDecoderInfos(str, z, z2), format);
        if (MimeTypes.VIDEO_DOLBY_VISION.equals(str) && (codecProfileAndLevel = MediaCodecUtil.getCodecProfileAndLevel(format)) != null) {
            int intValue = ((Integer) codecProfileAndLevel.first).intValue();
            if (intValue == 16 || intValue == 256) {
                decoderInfosSortedByFormatSupport.addAll(mediaCodecSelector.getDecoderInfos(MimeTypes.VIDEO_H265, z, z2));
            } else if (intValue == 512) {
                decoderInfosSortedByFormatSupport.addAll(mediaCodecSelector.getDecoderInfos(MimeTypes.VIDEO_H264, z, z2));
            }
        }
        return Collections.unmodifiableList(decoderInfosSortedByFormatSupport);
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onEnabled(boolean z, boolean z2) throws ExoPlaybackException {
        super.onEnabled(z, z2);
        int i = this.tunnelingAudioSessionId;
        this.tunnelingAudioSessionId = getConfiguration().tunnelingAudioSessionId;
        this.tunneling = this.tunnelingAudioSessionId != 0;
        if (this.tunnelingAudioSessionId != i) {
            releaseCodec();
        }
        this.eventDispatcher.enabled(this.decoderCounters);
        this.frameReleaseTimeHelper.enable();
        this.mayRenderFirstFrameAfterEnableIfNotStarted = z2;
        this.renderedFirstFrameAfterEnable = false;
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onPositionReset(long j, boolean z) throws ExoPlaybackException {
        super.onPositionReset(j, z);
        clearRenderedFirstFrame();
        this.initialPositionUs = C.TIME_UNSET;
        this.consecutiveDroppedFrameCount = 0;
        if (z) {
            setJoiningDeadlineMs();
        } else {
            this.joiningDeadlineMs = C.TIME_UNSET;
        }
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.Renderer
    public boolean isReady() {
        Surface surface2;
        if (super.isReady() && (this.renderedFirstFrameAfterReset || (((surface2 = this.dummySurface) != null && this.surface == surface2) || getCodec() == null || this.tunneling))) {
            this.joiningDeadlineMs = C.TIME_UNSET;
            return true;
        } else if (this.joiningDeadlineMs == C.TIME_UNSET) {
            return false;
        } else {
            if (SystemClock.elapsedRealtime() < this.joiningDeadlineMs) {
                return true;
            }
            this.joiningDeadlineMs = C.TIME_UNSET;
            return false;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onStarted() {
        super.onStarted();
        this.droppedFrames = 0;
        this.droppedFrameAccumulationStartTimeMs = SystemClock.elapsedRealtime();
        this.lastRenderTimeUs = SystemClock.elapsedRealtime() * 1000;
        this.totalVideoFrameProcessingOffsetUs = 0;
        this.videoFrameProcessingOffsetCount = 0;
        updateSurfaceFrameRate(false);
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onStopped() {
        this.joiningDeadlineMs = C.TIME_UNSET;
        maybeNotifyDroppedFrames();
        maybeNotifyVideoFrameProcessingOffset();
        clearSurfaceFrameRate();
        super.onStopped();
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onDisabled() {
        clearReportedVideoSize();
        clearRenderedFirstFrame();
        this.haveReportedFirstFrameRenderedForCurrentSurface = false;
        this.frameReleaseTimeHelper.disable();
        this.tunnelingOnFrameRenderedListener = null;
        try {
            super.onDisabled();
        } finally {
            this.eventDispatcher.disabled(this.decoderCounters);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer
    public void onReset() {
        try {
            super.onReset();
        } finally {
            Surface surface2 = this.dummySurface;
            if (surface2 != null) {
                if (this.surface == surface2) {
                    this.surface = null;
                }
                this.dummySurface.release();
                this.dummySurface = null;
            }
        }
    }

    @Override // com.google.android.exoplayer2.BaseRenderer, com.google.android.exoplayer2.PlayerMessage.Target
    public void handleMessage(int i, Object obj) throws ExoPlaybackException {
        if (i == 1) {
            setSurface((Surface) obj);
        } else if (i == 4) {
            this.scalingMode = ((Integer) obj).intValue();
            MediaCodec codec = getCodec();
            if (codec != null) {
                codec.setVideoScalingMode(this.scalingMode);
            }
        } else if (i == 6) {
            this.frameMetadataListener = (VideoFrameMetadataListener) obj;
        } else {
            super.handleMessage(i, obj);
        }
    }

    private void setSurface(Surface surface2) throws ExoPlaybackException {
        if (surface2 == null) {
            Surface surface3 = this.dummySurface;
            if (surface3 != null) {
                surface2 = surface3;
            } else {
                MediaCodecInfo codecInfo = getCodecInfo();
                if (codecInfo != null && shouldUseDummySurface(codecInfo)) {
                    this.dummySurface = DummySurface.newInstanceV17(this.context, codecInfo.secure);
                    surface2 = this.dummySurface;
                }
            }
        }
        if (this.surface != surface2) {
            clearSurfaceFrameRate();
            this.surface = surface2;
            this.haveReportedFirstFrameRenderedForCurrentSurface = false;
            updateSurfaceFrameRate(true);
            int state = getState();
            MediaCodec codec = getCodec();
            if (codec != null) {
                if (Util.SDK_INT < 23 || surface2 == null || this.codecNeedsSetOutputSurfaceWorkaround) {
                    releaseCodec();
                    maybeInitCodecOrBypass();
                } else {
                    setOutputSurfaceV23(codec, surface2);
                }
            }
            if (surface2 == null || surface2 == this.dummySurface) {
                clearReportedVideoSize();
                clearRenderedFirstFrame();
                return;
            }
            maybeRenotifyVideoSizeChanged();
            clearRenderedFirstFrame();
            if (state == 2) {
                setJoiningDeadlineMs();
            }
        } else if (surface2 != null && surface2 != this.dummySurface) {
            maybeRenotifyVideoSizeChanged();
            maybeRenotifyRenderedFirstFrame();
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public boolean shouldInitCodec(MediaCodecInfo mediaCodecInfo) {
        return this.surface != null || shouldUseDummySurface(mediaCodecInfo);
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public boolean getCodecNeedsEosPropagation() {
        return this.tunneling && Util.SDK_INT < 23;
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void configureCodec(MediaCodecInfo mediaCodecInfo, MediaCodecAdapter mediaCodecAdapter, Format format, MediaCrypto mediaCrypto, float f) {
        String str = mediaCodecInfo.codecMimeType;
        this.codecMaxValues = getCodecMaxValues(mediaCodecInfo, format, getStreamFormats());
        MediaFormat mediaFormat = getMediaFormat(format, str, this.codecMaxValues, f, this.deviceNeedsNoPostProcessWorkaround, this.tunnelingAudioSessionId);
        if (this.surface == null) {
            if (shouldUseDummySurface(mediaCodecInfo)) {
                if (this.dummySurface == null) {
                    this.dummySurface = DummySurface.newInstanceV17(this.context, mediaCodecInfo.secure);
                }
                this.surface = this.dummySurface;
            } else {
                throw new IllegalStateException();
            }
        }
        mediaCodecAdapter.configure(mediaFormat, this.surface, mediaCrypto, 0);
        if (Util.SDK_INT >= 23 && this.tunneling) {
            this.tunnelingOnFrameRenderedListener = new OnFrameRenderedListenerV23(mediaCodecAdapter.getCodec());
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public int canKeepCodec(MediaCodec mediaCodec, MediaCodecInfo mediaCodecInfo, Format format, Format format2) {
        if (!mediaCodecInfo.isSeamlessAdaptationSupported(format, format2, true) || format2.width > this.codecMaxValues.width || format2.height > this.codecMaxValues.height || getMaxInputSize(mediaCodecInfo, format2) > this.codecMaxValues.inputSize) {
            return 0;
        }
        return format.initializationDataEquals(format2) ? 3 : 2;
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void resetCodecStateForFlush() {
        super.resetCodecStateForFlush();
        this.buffersInCodecCount = 0;
    }

    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer, com.google.android.exoplayer2.BaseRenderer, com.google.android.exoplayer2.Renderer
    public void setOperatingRate(float f) throws ExoPlaybackException {
        super.setOperatingRate(f);
        updateSurfaceFrameRate(false);
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public float getCodecOperatingRateV23(float f, Format format, Format[] formatArr) {
        float f2 = -1.0f;
        for (Format format2 : formatArr) {
            float f3 = format2.frameRate;
            if (f3 != -1.0f) {
                f2 = Math.max(f2, f3);
            }
        }
        if (f2 == -1.0f) {
            return -1.0f;
        }
        return f2 * f;
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onCodecInitialized(String str, long j, long j2) {
        this.eventDispatcher.decoderInitialized(str, j, j2);
        this.codecNeedsSetOutputSurfaceWorkaround = codecNeedsSetOutputSurfaceWorkaround(str);
        this.codecHandlesHdr10PlusOutOfBandMetadata = ((MediaCodecInfo) Assertions.checkNotNull(getCodecInfo())).isHdr10PlusOutOfBandMetadataSupported();
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onInputFormatChanged(FormatHolder formatHolder) throws ExoPlaybackException {
        super.onInputFormatChanged(formatHolder);
        this.eventDispatcher.inputFormatChanged(formatHolder.format);
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onQueueInputBuffer(DecoderInputBuffer decoderInputBuffer) throws ExoPlaybackException {
        if (!this.tunneling) {
            this.buffersInCodecCount++;
        }
        if (Util.SDK_INT < 23 && this.tunneling) {
            onProcessedTunneledBuffer(decoderInputBuffer.timeUs);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onOutputFormatChanged(Format format, MediaFormat mediaFormat) {
        int i;
        int i2;
        MediaCodec codec = getCodec();
        if (codec != null) {
            codec.setVideoScalingMode(this.scalingMode);
        }
        if (this.tunneling) {
            this.currentWidth = format.width;
            this.currentHeight = format.height;
        } else {
            Assertions.checkNotNull(mediaFormat);
            boolean z = mediaFormat.containsKey(KEY_CROP_RIGHT) && mediaFormat.containsKey(KEY_CROP_LEFT) && mediaFormat.containsKey(KEY_CROP_BOTTOM) && mediaFormat.containsKey(KEY_CROP_TOP);
            if (z) {
                i = (mediaFormat.getInteger(KEY_CROP_RIGHT) - mediaFormat.getInteger(KEY_CROP_LEFT)) + 1;
            } else {
                i = mediaFormat.getInteger("width");
            }
            this.currentWidth = i;
            if (z) {
                i2 = (mediaFormat.getInteger(KEY_CROP_BOTTOM) - mediaFormat.getInteger(KEY_CROP_TOP)) + 1;
            } else {
                i2 = mediaFormat.getInteger("height");
            }
            this.currentHeight = i2;
        }
        this.currentPixelWidthHeightRatio = format.pixelWidthHeightRatio;
        if (Util.SDK_INT < 21) {
            this.currentUnappliedRotationDegrees = format.rotationDegrees;
        } else if (format.rotationDegrees == 90 || format.rotationDegrees == 270) {
            int i3 = this.currentWidth;
            this.currentWidth = this.currentHeight;
            this.currentHeight = i3;
            this.currentPixelWidthHeightRatio = 1.0f / this.currentPixelWidthHeightRatio;
        }
        this.currentFrameRate = format.frameRate;
        updateSurfaceFrameRate(false);
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void handleInputBufferSupplementalData(DecoderInputBuffer decoderInputBuffer) throws ExoPlaybackException {
        if (this.codecHandlesHdr10PlusOutOfBandMetadata) {
            ByteBuffer byteBuffer = (ByteBuffer) Assertions.checkNotNull(decoderInputBuffer.supplementalData);
            if (byteBuffer.remaining() >= 7) {
                byte b = byteBuffer.get();
                short s = byteBuffer.getShort();
                short s2 = byteBuffer.getShort();
                byte b2 = byteBuffer.get();
                byte b3 = byteBuffer.get();
                byteBuffer.position(0);
                if (b == -75 && s == 60 && s2 == 1 && b2 == 4 && b3 == 0) {
                    byte[] bArr = new byte[byteBuffer.remaining()];
                    byteBuffer.get(bArr);
                    byteBuffer.position(0);
                    setHdr10PlusInfoV29(getCodec(), bArr);
                }
            }
        }
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Code restructure failed: missing block: B:35:0x0088, code lost:
        if (shouldForceRenderOutputBuffer(r1, r13) != false) goto L_0x008d;
     */
    /* JADX WARNING: Removed duplicated region for block: B:42:0x0096  */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x00bf A[ADDED_TO_REGION] */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public boolean processOutputBuffer(long j, long j2, MediaCodec mediaCodec, ByteBuffer byteBuffer, int i, int i2, int i3, long j3, boolean z, boolean z2, Format format) throws ExoPlaybackException {
        long j4;
        boolean z3;
        boolean z4;
        long j5;
        Assertions.checkNotNull(mediaCodec);
        if (this.initialPositionUs == C.TIME_UNSET) {
            this.initialPositionUs = j;
        }
        long outputStreamOffsetUs = getOutputStreamOffsetUs();
        long j6 = j3 - outputStreamOffsetUs;
        if (!z || z2) {
            long j7 = j3 - j;
            if (this.surface != this.dummySurface) {
                long elapsedRealtime = SystemClock.elapsedRealtime() * 1000;
                long j8 = elapsedRealtime - this.lastRenderTimeUs;
                boolean z5 = getState() == 2;
                if (this.renderedFirstFrameAfterEnable ? this.renderedFirstFrameAfterReset : !z5 && !this.mayRenderFirstFrameAfterEnableIfNotStarted) {
                    j4 = elapsedRealtime;
                    z3 = false;
                } else {
                    j4 = elapsedRealtime;
                    z3 = true;
                }
                if (this.joiningDeadlineMs == C.TIME_UNSET && j >= outputStreamOffsetUs) {
                    if (z3) {
                        j5 = j7;
                    } else if (z5) {
                        j5 = j7;
                    }
                    z4 = true;
                    if (!z4) {
                        long nanoTime = System.nanoTime();
                        notifyFrameMetadataListener(j6, nanoTime, format);
                        if (Util.SDK_INT >= 21) {
                            renderOutputBufferV21(mediaCodec, i, j6, nanoTime);
                        } else {
                            renderOutputBuffer(mediaCodec, i, j6);
                        }
                        updateVideoFrameProcessingOffsetCounters(j5);
                        return true;
                    }
                    if (z5 && j != this.initialPositionUs) {
                        long nanoTime2 = System.nanoTime();
                        long adjustReleaseTime = this.frameReleaseTimeHelper.adjustReleaseTime(j3, ((j5 - (j4 - j2)) * 1000) + nanoTime2);
                        long j9 = (adjustReleaseTime - nanoTime2) / 1000;
                        boolean z6 = this.joiningDeadlineMs != C.TIME_UNSET;
                        if (shouldDropBuffersToKeyframe(j9, j2, z2) && maybeDropBuffersToKeyframe(mediaCodec, i, j6, j, z6)) {
                            return false;
                        }
                        if (shouldDropOutputBuffer(j9, j2, z2)) {
                            if (z6) {
                                skipOutputBuffer(mediaCodec, i, j6);
                            } else {
                                dropOutputBuffer(mediaCodec, i, j6);
                            }
                            updateVideoFrameProcessingOffsetCounters(j9);
                            return true;
                        } else if (Util.SDK_INT >= 21) {
                            if (j9 < 50000) {
                                notifyFrameMetadataListener(j6, adjustReleaseTime, format);
                                renderOutputBufferV21(mediaCodec, i, j6, adjustReleaseTime);
                                updateVideoFrameProcessingOffsetCounters(j9);
                                return true;
                            }
                        } else if (j9 < 30000) {
                            if (j9 > 11000) {
                                try {
                                    Thread.sleep((j9 - 10000) / 1000);
                                } catch (InterruptedException unused) {
                                    Thread.currentThread().interrupt();
                                    return false;
                                }
                            }
                            notifyFrameMetadataListener(j6, adjustReleaseTime, format);
                            renderOutputBuffer(mediaCodec, i, j6);
                            updateVideoFrameProcessingOffsetCounters(j9);
                            return true;
                        }
                    }
                    return false;
                }
                j5 = j7;
                z4 = false;
                if (!z4) {
                }
            } else if (!isBufferLate(j7)) {
                return false;
            } else {
                skipOutputBuffer(mediaCodec, i, j6);
                updateVideoFrameProcessingOffsetCounters(j7);
                return true;
            }
        } else {
            skipOutputBuffer(mediaCodec, i, j6);
            return true;
        }
    }

    private void notifyFrameMetadataListener(long j, long j2, Format format) {
        VideoFrameMetadataListener videoFrameMetadataListener = this.frameMetadataListener;
        if (videoFrameMetadataListener != null) {
            videoFrameMetadataListener.onVideoFrameAboutToBeRendered(j, j2, format, getCodecOutputMediaFormat());
        }
    }

    /* access modifiers changed from: protected */
    public void onProcessedTunneledBuffer(long j) throws ExoPlaybackException {
        updateOutputFormatForTime(j);
        maybeNotifyVideoSizeChanged();
        this.decoderCounters.renderedOutputBufferCount++;
        maybeNotifyRenderedFirstFrame();
        onProcessedOutputBuffer(j);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void onProcessedTunneledEndOfStream() {
        setPendingOutputEndOfStream();
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onProcessedOutputBuffer(long j) {
        super.onProcessedOutputBuffer(j);
        if (!this.tunneling) {
            this.buffersInCodecCount--;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public void onProcessedStreamChange() {
        super.onProcessedStreamChange();
        clearRenderedFirstFrame();
    }

    /* access modifiers changed from: protected */
    public boolean shouldDropOutputBuffer(long j, long j2, boolean z) {
        return isBufferLate(j) && !z;
    }

    /* access modifiers changed from: protected */
    public boolean shouldDropBuffersToKeyframe(long j, long j2, boolean z) {
        return isBufferVeryLate(j) && !z;
    }

    /* access modifiers changed from: protected */
    public boolean shouldForceRenderOutputBuffer(long j, long j2) {
        return isBufferLate(j) && j2 > 100000;
    }

    /* access modifiers changed from: protected */
    public void skipOutputBuffer(MediaCodec mediaCodec, int i, long j) {
        TraceUtil.beginSection("skipVideoBuffer");
        mediaCodec.releaseOutputBuffer(i, false);
        TraceUtil.endSection();
        this.decoderCounters.skippedOutputBufferCount++;
    }

    /* access modifiers changed from: protected */
    public void dropOutputBuffer(MediaCodec mediaCodec, int i, long j) {
        TraceUtil.beginSection("dropVideoBuffer");
        mediaCodec.releaseOutputBuffer(i, false);
        TraceUtil.endSection();
        updateDroppedBufferCounters(1);
    }

    /* access modifiers changed from: protected */
    public boolean maybeDropBuffersToKeyframe(MediaCodec mediaCodec, int i, long j, long j2, boolean z) throws ExoPlaybackException {
        int skipSource = skipSource(j2);
        if (skipSource == 0) {
            return false;
        }
        this.decoderCounters.droppedToKeyframeCount++;
        int i2 = this.buffersInCodecCount + skipSource;
        if (z) {
            this.decoderCounters.skippedOutputBufferCount += i2;
        } else {
            updateDroppedBufferCounters(i2);
        }
        flushOrReinitializeCodec();
        return true;
    }

    /* access modifiers changed from: protected */
    public void updateDroppedBufferCounters(int i) {
        this.decoderCounters.droppedBufferCount += i;
        this.droppedFrames += i;
        this.consecutiveDroppedFrameCount += i;
        this.decoderCounters.maxConsecutiveDroppedBufferCount = Math.max(this.consecutiveDroppedFrameCount, this.decoderCounters.maxConsecutiveDroppedBufferCount);
        int i2 = this.maxDroppedFramesToNotify;
        if (i2 > 0 && this.droppedFrames >= i2) {
            maybeNotifyDroppedFrames();
        }
    }

    /* access modifiers changed from: protected */
    public void updateVideoFrameProcessingOffsetCounters(long j) {
        this.decoderCounters.addVideoFrameProcessingOffset(j);
        this.totalVideoFrameProcessingOffsetUs += j;
        this.videoFrameProcessingOffsetCount++;
    }

    /* access modifiers changed from: protected */
    public void renderOutputBuffer(MediaCodec mediaCodec, int i, long j) {
        maybeNotifyVideoSizeChanged();
        TraceUtil.beginSection("releaseOutputBuffer");
        mediaCodec.releaseOutputBuffer(i, true);
        TraceUtil.endSection();
        this.lastRenderTimeUs = SystemClock.elapsedRealtime() * 1000;
        this.decoderCounters.renderedOutputBufferCount++;
        this.consecutiveDroppedFrameCount = 0;
        maybeNotifyRenderedFirstFrame();
    }

    /* access modifiers changed from: protected */
    public void renderOutputBufferV21(MediaCodec mediaCodec, int i, long j, long j2) {
        maybeNotifyVideoSizeChanged();
        TraceUtil.beginSection("releaseOutputBuffer");
        mediaCodec.releaseOutputBuffer(i, j2);
        TraceUtil.endSection();
        this.lastRenderTimeUs = SystemClock.elapsedRealtime() * 1000;
        this.decoderCounters.renderedOutputBufferCount++;
        this.consecutiveDroppedFrameCount = 0;
        maybeNotifyRenderedFirstFrame();
    }

    private void updateSurfaceFrameRate(boolean z) {
        Surface surface2;
        if (Util.SDK_INT >= 30 && (surface2 = this.surface) != null && surface2 != this.dummySurface) {
            float operatingRate = getState() == 2 && (this.currentFrameRate > -1.0f ? 1 : (this.currentFrameRate == -1.0f ? 0 : -1)) != 0 ? this.currentFrameRate * getOperatingRate() : 0.0f;
            if (this.surfaceFrameRate != operatingRate || z) {
                this.surfaceFrameRate = operatingRate;
                setSurfaceFrameRateV30(this.surface, operatingRate);
            }
        }
    }

    private void clearSurfaceFrameRate() {
        Surface surface2;
        if (Util.SDK_INT >= 30 && (surface2 = this.surface) != null && surface2 != this.dummySurface && this.surfaceFrameRate != 0.0f) {
            this.surfaceFrameRate = 0.0f;
            setSurfaceFrameRateV30(surface2, 0.0f);
        }
    }

    private void setSurfaceFrameRateV30(Surface surface2, float f) {
        if (surfaceSetFrameRateMethod == null) {
            Log.e(TAG, "Failed to call Surface.setFrameRate (method does not exist)");
        }
        try {
            surfaceSetFrameRateMethod.invoke(surface2, Float.valueOf(f), Integer.valueOf(f == 0.0f ? 0 : 1));
        } catch (Exception e) {
            Log.e(TAG, "Failed to call Surface.setFrameRate", e);
        }
    }

    private boolean shouldUseDummySurface(MediaCodecInfo mediaCodecInfo) {
        return Util.SDK_INT >= 23 && !this.tunneling && !codecNeedsSetOutputSurfaceWorkaround(mediaCodecInfo.name) && (!mediaCodecInfo.secure || DummySurface.isSecureSupported(this.context));
    }

    private void setJoiningDeadlineMs() {
        this.joiningDeadlineMs = this.allowedJoiningTimeMs > 0 ? SystemClock.elapsedRealtime() + this.allowedJoiningTimeMs : C.TIME_UNSET;
    }

    private void clearRenderedFirstFrame() {
        MediaCodec codec;
        this.renderedFirstFrameAfterReset = false;
        if (Util.SDK_INT >= 23 && this.tunneling && (codec = getCodec()) != null) {
            this.tunnelingOnFrameRenderedListener = new OnFrameRenderedListenerV23(codec);
        }
    }

    /* access modifiers changed from: package-private */
    public void maybeNotifyRenderedFirstFrame() {
        this.renderedFirstFrameAfterEnable = true;
        if (!this.renderedFirstFrameAfterReset) {
            this.renderedFirstFrameAfterReset = true;
            this.eventDispatcher.renderedFirstFrame(this.surface);
            this.haveReportedFirstFrameRenderedForCurrentSurface = true;
        }
    }

    private void maybeRenotifyRenderedFirstFrame() {
        if (this.haveReportedFirstFrameRenderedForCurrentSurface) {
            this.eventDispatcher.renderedFirstFrame(this.surface);
        }
    }

    private void clearReportedVideoSize() {
        this.reportedWidth = -1;
        this.reportedHeight = -1;
        this.reportedPixelWidthHeightRatio = -1.0f;
        this.reportedUnappliedRotationDegrees = -1;
    }

    private void maybeNotifyVideoSizeChanged() {
        if (this.currentWidth != -1 || this.currentHeight != -1) {
            if (this.reportedWidth != this.currentWidth || this.reportedHeight != this.currentHeight || this.reportedUnappliedRotationDegrees != this.currentUnappliedRotationDegrees || this.reportedPixelWidthHeightRatio != this.currentPixelWidthHeightRatio) {
                this.eventDispatcher.videoSizeChanged(this.currentWidth, this.currentHeight, this.currentUnappliedRotationDegrees, this.currentPixelWidthHeightRatio);
                this.reportedWidth = this.currentWidth;
                this.reportedHeight = this.currentHeight;
                this.reportedUnappliedRotationDegrees = this.currentUnappliedRotationDegrees;
                this.reportedPixelWidthHeightRatio = this.currentPixelWidthHeightRatio;
            }
        }
    }

    private void maybeRenotifyVideoSizeChanged() {
        if (this.reportedWidth != -1 || this.reportedHeight != -1) {
            this.eventDispatcher.videoSizeChanged(this.reportedWidth, this.reportedHeight, this.reportedUnappliedRotationDegrees, this.reportedPixelWidthHeightRatio);
        }
    }

    private void maybeNotifyDroppedFrames() {
        if (this.droppedFrames > 0) {
            long elapsedRealtime = SystemClock.elapsedRealtime();
            this.eventDispatcher.droppedFrames(this.droppedFrames, elapsedRealtime - this.droppedFrameAccumulationStartTimeMs);
            this.droppedFrames = 0;
            this.droppedFrameAccumulationStartTimeMs = elapsedRealtime;
        }
    }

    private void maybeNotifyVideoFrameProcessingOffset() {
        int i = this.videoFrameProcessingOffsetCount;
        if (i != 0) {
            this.eventDispatcher.reportVideoFrameProcessingOffset(this.totalVideoFrameProcessingOffsetUs, i);
            this.totalVideoFrameProcessingOffsetUs = 0;
            this.videoFrameProcessingOffsetCount = 0;
        }
    }

    private static void setHdr10PlusInfoV29(MediaCodec mediaCodec, byte[] bArr) {
        Bundle bundle = new Bundle();
        bundle.putByteArray("hdr10-plus-info", bArr);
        mediaCodec.setParameters(bundle);
    }

    /* access modifiers changed from: protected */
    public void setOutputSurfaceV23(MediaCodec mediaCodec, Surface surface2) {
        mediaCodec.setOutputSurface(surface2);
    }

    private static void configureTunnelingV21(MediaFormat mediaFormat, int i) {
        mediaFormat.setFeatureEnabled("tunneled-playback", true);
        mediaFormat.setInteger("audio-session-id", i);
    }

    /* access modifiers changed from: protected */
    public MediaFormat getMediaFormat(Format format, String str, CodecMaxValues codecMaxValues2, float f, boolean z, int i) {
        Pair<Integer, Integer> codecProfileAndLevel;
        MediaFormat mediaFormat = new MediaFormat();
        mediaFormat.setString(IMediaFormat.KEY_MIME, str);
        mediaFormat.setInteger("width", format.width);
        mediaFormat.setInteger("height", format.height);
        MediaFormatUtil.setCsdBuffers(mediaFormat, format.initializationData);
        MediaFormatUtil.maybeSetFloat(mediaFormat, "frame-rate", format.frameRate);
        MediaFormatUtil.maybeSetInteger(mediaFormat, "rotation-degrees", format.rotationDegrees);
        MediaFormatUtil.maybeSetColorInfo(mediaFormat, format.colorInfo);
        if (MimeTypes.VIDEO_DOLBY_VISION.equals(format.sampleMimeType) && (codecProfileAndLevel = MediaCodecUtil.getCodecProfileAndLevel(format)) != null) {
            MediaFormatUtil.maybeSetInteger(mediaFormat, "profile", ((Integer) codecProfileAndLevel.first).intValue());
        }
        mediaFormat.setInteger("max-width", codecMaxValues2.width);
        mediaFormat.setInteger("max-height", codecMaxValues2.height);
        MediaFormatUtil.maybeSetInteger(mediaFormat, "max-input-size", codecMaxValues2.inputSize);
        if (Util.SDK_INT >= 23) {
            mediaFormat.setInteger("priority", 0);
            if (f != -1.0f) {
                mediaFormat.setFloat("operating-rate", f);
            }
        }
        if (z) {
            mediaFormat.setInteger("no-post-process", 1);
            mediaFormat.setInteger("auto-frc", 0);
        }
        if (i != 0) {
            configureTunnelingV21(mediaFormat, i);
        }
        return mediaFormat;
    }

    /* access modifiers changed from: protected */
    public CodecMaxValues getCodecMaxValues(MediaCodecInfo mediaCodecInfo, Format format, Format[] formatArr) {
        int codecMaxInputSize;
        int i = format.width;
        int i2 = format.height;
        int maxInputSize = getMaxInputSize(mediaCodecInfo, format);
        if (formatArr.length == 1) {
            if (!(maxInputSize == -1 || (codecMaxInputSize = getCodecMaxInputSize(mediaCodecInfo, format.sampleMimeType, format.width, format.height)) == -1)) {
                maxInputSize = Math.min((int) (((float) maxInputSize) * INITIAL_FORMAT_MAX_INPUT_SIZE_SCALE_FACTOR), codecMaxInputSize);
            }
            return new CodecMaxValues(i, i2, maxInputSize);
        }
        int i3 = i2;
        int i4 = maxInputSize;
        boolean z = false;
        int i5 = i;
        for (Format format2 : formatArr) {
            if (mediaCodecInfo.isSeamlessAdaptationSupported(format, format2, false)) {
                z |= format2.width == -1 || format2.height == -1;
                i5 = Math.max(i5, format2.width);
                i3 = Math.max(i3, format2.height);
                i4 = Math.max(i4, getMaxInputSize(mediaCodecInfo, format2));
            }
        }
        if (z) {
            StringBuilder sb = new StringBuilder(66);
            sb.append("Resolutions unknown. Codec max resolution: ");
            sb.append(i5);
            sb.append("x");
            sb.append(i3);
            Log.w(TAG, sb.toString());
            Point codecMaxSize = getCodecMaxSize(mediaCodecInfo, format);
            if (codecMaxSize != null) {
                i5 = Math.max(i5, codecMaxSize.x);
                i3 = Math.max(i3, codecMaxSize.y);
                i4 = Math.max(i4, getCodecMaxInputSize(mediaCodecInfo, format.sampleMimeType, i5, i3));
                StringBuilder sb2 = new StringBuilder(57);
                sb2.append("Codec max resolution adjusted to: ");
                sb2.append(i5);
                sb2.append("x");
                sb2.append(i3);
                Log.w(TAG, sb2.toString());
            }
        }
        return new CodecMaxValues(i5, i3, i4);
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.exoplayer2.mediacodec.MediaCodecRenderer
    public MediaCodecDecoderException createDecoderException(Throwable th, MediaCodecInfo mediaCodecInfo) {
        return new MediaCodecVideoDecoderException(th, mediaCodecInfo, this.surface);
    }

    private static Point getCodecMaxSize(MediaCodecInfo mediaCodecInfo, Format format) {
        boolean z = format.height > format.width;
        int i = z ? format.height : format.width;
        int i2 = z ? format.width : format.height;
        float f = ((float) i2) / ((float) i);
        int[] iArr = STANDARD_LONG_EDGE_VIDEO_PX;
        for (int i3 : iArr) {
            int i4 = (int) (((float) i3) * f);
            if (i3 <= i || i4 <= i2) {
                break;
            }
            if (Util.SDK_INT >= 21) {
                int i5 = z ? i4 : i3;
                if (!z) {
                    i3 = i4;
                }
                Point alignVideoSizeV21 = mediaCodecInfo.alignVideoSizeV21(i5, i3);
                if (mediaCodecInfo.isVideoSizeAndRateSupportedV21(alignVideoSizeV21.x, alignVideoSizeV21.y, (double) format.frameRate)) {
                    return alignVideoSizeV21;
                }
            } else {
                try {
                    int ceilDivide = Util.ceilDivide(i3, 16) * 16;
                    int ceilDivide2 = Util.ceilDivide(i4, 16) * 16;
                    if (ceilDivide * ceilDivide2 <= MediaCodecUtil.maxH264DecodableFrameSize()) {
                        int i6 = z ? ceilDivide2 : ceilDivide;
                        if (!z) {
                            ceilDivide = ceilDivide2;
                        }
                        return new Point(i6, ceilDivide);
                    }
                } catch (MediaCodecUtil.DecoderQueryException unused) {
                }
            }
        }
        return null;
    }

    protected static int getMaxInputSize(MediaCodecInfo mediaCodecInfo, Format format) {
        if (format.maxInputSize == -1) {
            return getCodecMaxInputSize(mediaCodecInfo, format.sampleMimeType, format.width, format.height);
        }
        int size = format.initializationData.size();
        int i = 0;
        for (int i2 = 0; i2 < size; i2++) {
            i += format.initializationData.get(i2).length;
        }
        return format.maxInputSize + i;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private static int getCodecMaxInputSize(MediaCodecInfo mediaCodecInfo, String str, int i, int i2) {
        char c;
        int i3;
        if (i == -1 || i2 == -1) {
            return -1;
        }
        int i4 = 4;
        switch (str.hashCode()) {
            case -1664118616:
                if (str.equals(MimeTypes.VIDEO_H263)) {
                    c = 0;
                    break;
                }
                c = 65535;
                break;
            case -1662541442:
                if (str.equals(MimeTypes.VIDEO_H265)) {
                    c = 4;
                    break;
                }
                c = 65535;
                break;
            case 1187890754:
                if (str.equals(MimeTypes.VIDEO_MP4V)) {
                    c = 1;
                    break;
                }
                c = 65535;
                break;
            case 1331836730:
                if (str.equals(MimeTypes.VIDEO_H264)) {
                    c = 2;
                    break;
                }
                c = 65535;
                break;
            case 1599127256:
                if (str.equals(MimeTypes.VIDEO_VP8)) {
                    c = 3;
                    break;
                }
                c = 65535;
                break;
            case 1599127257:
                if (str.equals(MimeTypes.VIDEO_VP9)) {
                    c = 5;
                    break;
                }
                c = 65535;
                break;
            default:
                c = 65535;
                break;
        }
        if (!(c == 0 || c == 1)) {
            if (c != 2) {
                if (c != 3) {
                    if (c != 4 && c != 5) {
                        return -1;
                    }
                    i3 = i * i2;
                    return (i3 * 3) / (i4 * 2);
                }
            } else if ("BRAVIA 4K 2015".equals(Util.MODEL) || ("Amazon".equals(Util.MANUFACTURER) && ("KFSOWI".equals(Util.MODEL) || ("AFTS".equals(Util.MODEL) && mediaCodecInfo.secure)))) {
                return -1;
            } else {
                i3 = Util.ceilDivide(i, 16) * Util.ceilDivide(i2, 16) * 16 * 16;
                i4 = 2;
                return (i3 * 3) / (i4 * 2);
            }
        }
        i3 = i * i2;
        i4 = 2;
        return (i3 * 3) / (i4 * 2);
    }

    private static boolean deviceNeedsNoPostProcessWorkaround() {
        return "NVIDIA".equals(Util.MANUFACTURER);
    }

    /* access modifiers changed from: protected */
    public boolean codecNeedsSetOutputSurfaceWorkaround(String str) {
        if (str.startsWith("OMX.google")) {
            return false;
        }
        synchronized (MediaCodecVideoRenderer.class) {
            if (!evaluatedDeviceNeedsSetOutputSurfaceWorkaround) {
                deviceNeedsSetOutputSurfaceWorkaround = evaluateDeviceNeedsSetOutputSurfaceWorkaround();
                evaluatedDeviceNeedsSetOutputSurfaceWorkaround = true;
            }
        }
        return deviceNeedsSetOutputSurfaceWorkaround;
    }

    /* access modifiers changed from: protected */
    public Surface getSurface() {
        return this.surface;
    }

    /* access modifiers changed from: protected */
    public static final class CodecMaxValues {
        public final int height;
        public final int inputSize;
        public final int width;

        public CodecMaxValues(int i, int i2, int i3) {
            this.width = i;
            this.height = i2;
            this.inputSize = i3;
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:273:0x042b, code lost:
        if (r0.equals("deb") != false) goto L_0x06f5;
     */
    private static boolean evaluateDeviceNeedsSetOutputSurfaceWorkaround() {
        char c;
        char c2 = 28;
        char c3 = 65535;
        if (Util.SDK_INT <= 28) {
            String str = Util.DEVICE;
            switch (str.hashCode()) {
                case -1339091551:
                    if (str.equals("dangal")) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                case -1220081023:
                    if (str.equals("dangalFHD")) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case -1220066608:
                    if (str.equals("dangalUHD")) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case -64886864:
                    if (str.equals("magnolia")) {
                        c = 3;
                        break;
                    }
                    c = 65535;
                    break;
                case 825323514:
                    if (str.equals("machuca")) {
                        c = 4;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            if (c == 0 || c == 1 || c == 2 || c == 3 || c == 4) {
                return true;
            }
        }
        if (Util.SDK_INT <= 27 && "HWEML".equals(Util.DEVICE)) {
            return true;
        }
        if (Util.SDK_INT <= 26) {
            String str2 = Util.DEVICE;
            switch (str2.hashCode()) {
                case -2144781245:
                    if (str2.equals("GIONEE_SWW1609")) {
                        c2 = '6';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2144781185:
                    if (str2.equals("GIONEE_SWW1627")) {
                        c2 = '7';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2144781160:
                    if (str2.equals("GIONEE_SWW1631")) {
                        c2 = '8';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2097309513:
                    if (str2.equals("K50a40")) {
                        c2 = 'J';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2022874474:
                    if (str2.equals("CP8676_I02")) {
                        c2 = 22;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1978993182:
                    if (str2.equals("NX541J")) {
                        c2 = 'Y';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1978990237:
                    if (str2.equals("NX573J")) {
                        c2 = 'Z';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1936688988:
                    if (str2.equals("PGN528")) {
                        c2 = 'e';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1936688066:
                    if (str2.equals("PGN610")) {
                        c2 = 'f';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1936688065:
                    if (str2.equals("PGN611")) {
                        c2 = 'g';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1931988508:
                    if (str2.equals("AquaPowerM")) {
                        c2 = '\r';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1885099851:
                    if (str2.equals("RAIJIN")) {
                        c2 = 't';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1696512866:
                    if (str2.equals("XT1663")) {
                        c2 = 137;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1680025915:
                    if (str2.equals("ComioS1")) {
                        c2 = 21;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1615810839:
                    if (str2.equals("Phantom6")) {
                        c2 = 'h';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1600724499:
                    if (str2.equals("pacificrim")) {
                        c2 = '_';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1554255044:
                    if (str2.equals("vernee_M5")) {
                        c2 = 130;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1481772737:
                    if (str2.equals("panell_dl")) {
                        c2 = 'a';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1481772730:
                    if (str2.equals("panell_ds")) {
                        c2 = 'b';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1481772729:
                    if (str2.equals("panell_dt")) {
                        c2 = 'c';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1320080169:
                    if (str2.equals("GiONEE_GBL7319")) {
                        c2 = '4';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1217592143:
                    if (str2.equals("BRAVIA_ATV2")) {
                        c2 = 18;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1180384755:
                    if (str2.equals("iris60")) {
                        c2 = 'F';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1139198265:
                    if (str2.equals("Slate_Pro")) {
                        c2 = 'v';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1052835013:
                    if (str2.equals("namath")) {
                        c2 = 'W';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -993250464:
                    if (str2.equals("A10-70F")) {
                        c2 = 5;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -993250458:
                    if (str2.equals("A10-70L")) {
                        c2 = 6;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -965403638:
                    if (str2.equals("s905x018")) {
                        c2 = 'x';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -958336948:
                    if (str2.equals("ELUGA_Ray_X")) {
                        c2 = Typography.quote;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -879245230:
                    if (str2.equals("tcl_eu")) {
                        c2 = '~';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -842500323:
                    if (str2.equals("nicklaus_f")) {
                        c2 = 'X';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -821392978:
                    if (str2.equals("A7000-a")) {
                        c2 = '\t';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -797483286:
                    if (str2.equals("SVP-DTV15")) {
                        c2 = 'w';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -794946968:
                    if (str2.equals("watson")) {
                        c2 = 131;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -788334647:
                    if (str2.equals("whyred")) {
                        c2 = 132;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -782144577:
                    if (str2.equals("OnePlus5T")) {
                        c2 = '[';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -575125681:
                    if (str2.equals("GiONEE_CBL7513")) {
                        c2 = '3';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -521118391:
                    if (str2.equals("GIONEE_GBL7360")) {
                        c2 = '5';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -430914369:
                    if (str2.equals("Pixi4-7_3G")) {
                        c2 = 'i';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -290434366:
                    if (str2.equals("taido_row")) {
                        c2 = 'y';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -282781963:
                    if (str2.equals("BLACK-1X")) {
                        c2 = 17;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -277133239:
                    if (str2.equals("Z12_PRO")) {
                        c2 = 138;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -173639913:
                    if (str2.equals("ELUGA_A3_Pro")) {
                        c2 = 31;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -56598463:
                    if (str2.equals("woods_fn")) {
                        c2 = 134;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2126:
                    if (str2.equals("C1")) {
                        c2 = 20;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2564:
                    if (str2.equals("Q5")) {
                        c2 = 'q';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2715:
                    if (str2.equals("V1")) {
                        c2 = Ascii.MAX;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2719:
                    if (str2.equals("V5")) {
                        c2 = 129;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3091:
                    if (str2.equals("b5")) {
                        c2 = 16;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3483:
                    if (str2.equals("mh")) {
                        c2 = 'T';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 73405:
                    if (str2.equals("JGZ")) {
                        c2 = 'I';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 75537:
                    if (str2.equals("M04")) {
                        c2 = 'O';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 75739:
                    if (str2.equals("M5c")) {
                        c2 = 'P';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 76779:
                    if (str2.equals("MX6")) {
                        c2 = 'V';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 78669:
                    if (str2.equals("P85")) {
                        c2 = '^';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 79305:
                    if (str2.equals("PLE")) {
                        c2 = 'k';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 80618:
                    if (str2.equals("QX1")) {
                        c2 = 's';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 88274:
                    if (str2.equals("Z80")) {
                        c2 = 139;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 98846:
                    if (str2.equals("cv1")) {
                        c2 = 26;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 98848:
                    if (str2.equals("cv3")) {
                        c2 = 27;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 99329:
                    break;
                case 101481:
                    if (str2.equals("flo")) {
                        c2 = '1';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1513190:
                    if (str2.equals("1601")) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1514184:
                    if (str2.equals("1713")) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1514185:
                    if (str2.equals("1714")) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133089:
                    if (str2.equals("F01H")) {
                        c2 = Typography.dollar;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133091:
                    if (str2.equals("F01J")) {
                        c2 = '%';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133120:
                    if (str2.equals("F02H")) {
                        c2 = Typography.amp;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133151:
                    if (str2.equals("F03H")) {
                        c2 = '\'';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133182:
                    if (str2.equals("F04H")) {
                        c2 = '(';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2133184:
                    if (str2.equals("F04J")) {
                        c2 = ')';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2436959:
                    if (str2.equals("P681")) {
                        c2 = ']';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2463773:
                    if (str2.equals("Q350")) {
                        c2 = 'm';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2464648:
                    if (str2.equals("Q427")) {
                        c2 = 'o';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2689555:
                    if (str2.equals("XE2X")) {
                        c2 = 136;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3154429:
                    if (str2.equals("fugu")) {
                        c2 = '2';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3284551:
                    if (str2.equals("kate")) {
                        c2 = 'K';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3351335:
                    if (str2.equals("mido")) {
                        c2 = 'U';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3386211:
                    if (str2.equals("p212")) {
                        c2 = '\\';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 41325051:
                    if (str2.equals("MEIZU_M5")) {
                        c2 = 'S';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 51349633:
                    if (str2.equals("601LV")) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 51350594:
                    if (str2.equals("602LV")) {
                        c2 = 4;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 55178625:
                    if (str2.equals("Aura_Note_2")) {
                        c2 = 15;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 61542055:
                    if (str2.equals("A1601")) {
                        c2 = 7;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 65355429:
                    if (str2.equals("E5643")) {
                        c2 = 30;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66214468:
                    if (str2.equals("F3111")) {
                        c2 = '*';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66214470:
                    if (str2.equals("F3113")) {
                        c2 = '+';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66214473:
                    if (str2.equals("F3116")) {
                        c2 = ',';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66215429:
                    if (str2.equals("F3211")) {
                        c2 = '-';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66215431:
                    if (str2.equals("F3213")) {
                        c2 = '.';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66215433:
                    if (str2.equals("F3215")) {
                        c2 = '/';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 66216390:
                    if (str2.equals("F3311")) {
                        c2 = '0';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 76402249:
                    if (str2.equals("PRO7S")) {
                        c2 = 'l';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 76404105:
                    if (str2.equals("Q4260")) {
                        c2 = 'n';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 76404911:
                    if (str2.equals("Q4310")) {
                        c2 = 'p';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 80963634:
                    if (str2.equals("V23GB")) {
                        c2 = 128;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 82882791:
                    if (str2.equals("X3_HK")) {
                        c2 = 135;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 98715550:
                    if (str2.equals("i9031")) {
                        c2 = 'C';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 101370885:
                    if (str2.equals("l5460")) {
                        c2 = 'L';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 102844228:
                    if (str2.equals("le_x6")) {
                        c2 = 'M';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 165221241:
                    if (str2.equals("A2016a40")) {
                        c2 = '\b';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 182191441:
                    if (str2.equals("CPY83_I00")) {
                        c2 = 25;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 245388979:
                    if (str2.equals("marino_f")) {
                        c2 = 'R';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 287431619:
                    if (str2.equals("griffin")) {
                        c2 = Typography.less;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 307593612:
                    if (str2.equals("A7010a48")) {
                        c2 = 11;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 308517133:
                    if (str2.equals("A7020a48")) {
                        c2 = '\f';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 316215098:
                    if (str2.equals("TB3-730F")) {
                        c2 = 'z';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 316215116:
                    if (str2.equals("TB3-730X")) {
                        c2 = '{';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 316246811:
                    if (str2.equals("TB3-850F")) {
                        c2 = '|';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 316246818:
                    if (str2.equals("TB3-850M")) {
                        c2 = '}';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 407160593:
                    if (str2.equals("Pixi5-10_4G")) {
                        c2 = 'j';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 507412548:
                    if (str2.equals("QM16XE_U")) {
                        c2 = 'r';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 793982701:
                    if (str2.equals("GIONEE_WBL5708")) {
                        c2 = '9';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 794038622:
                    if (str2.equals("GIONEE_WBL7365")) {
                        c2 = ':';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 794040393:
                    if (str2.equals("GIONEE_WBL7519")) {
                        c2 = ';';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 835649806:
                    if (str2.equals("manning")) {
                        c2 = 'Q';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 917340916:
                    if (str2.equals("A7000plus")) {
                        c2 = '\n';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 958008161:
                    if (str2.equals("j2xlteins")) {
                        c2 = 'H';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1060579533:
                    if (str2.equals("panell_d")) {
                        c2 = '`';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1150207623:
                    if (str2.equals("LS-5017")) {
                        c2 = 'N';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1176899427:
                    if (str2.equals("itel_S41")) {
                        c2 = 'G';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1280332038:
                    if (str2.equals("hwALE-H")) {
                        c2 = Typography.greater;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1306947716:
                    if (str2.equals("EverStar_S")) {
                        c2 = '#';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1349174697:
                    if (str2.equals("htc_e56ml_dtul")) {
                        c2 = '=';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1522194893:
                    if (str2.equals("woods_f")) {
                        c2 = 133;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1691543273:
                    if (str2.equals("CPH1609")) {
                        c2 = 23;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1691544261:
                    if (str2.equals("CPH1715")) {
                        c2 = 24;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1709443163:
                    if (str2.equals("iball8735_9806")) {
                        c2 = 'D';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1865889110:
                    if (str2.equals("santoni")) {
                        c2 = 'u';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1906253259:
                    if (str2.equals("PB2-670M")) {
                        c2 = 'd';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1977196784:
                    if (str2.equals("Infinix-X572")) {
                        c2 = 'E';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2006372676:
                    if (str2.equals("BRAVIA_ATV3_4K")) {
                        c2 = 19;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2019281702:
                    if (str2.equals("DM-01K")) {
                        c2 = 29;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2029784656:
                    if (str2.equals("HWBLN-H")) {
                        c2 = '?';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2030379515:
                    if (str2.equals("HWCAM-H")) {
                        c2 = '@';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2033393791:
                    if (str2.equals("ASUS_X00AD_2")) {
                        c2 = 14;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2047190025:
                    if (str2.equals("ELUGA_Note")) {
                        c2 = ' ';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2047252157:
                    if (str2.equals("ELUGA_Prim")) {
                        c2 = '!';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2048319463:
                    if (str2.equals("HWVNS-H")) {
                        c2 = 'A';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 2048855701:
                    if (str2.equals("HWWAS-H")) {
                        c2 = 'B';
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                case 1:
                case 2:
                case 3:
                case 4:
                case 5:
                case 6:
                case 7:
                case '\b':
                case '\t':
                case '\n':
                case 11:
                case '\f':
                case '\r':
                case 14:
                case 15:
                case 16:
                case 17:
                case 18:
                case 19:
                case 20:
                case 21:
                case 22:
                case 23:
                case 24:
                case 25:
                case 26:
                case 27:
                case 28:
                case 29:
                case 30:
                case 31:
                case ' ':
                case '!':
                case '\"':
                case '#':
                case '$':
                case '%':
                case '&':
                case '\'':
                case '(':
                case ')':
                case '*':
                case '+':
                case ',':
                case '-':
                case '.':
                case '/':
                case '0':
                case '1':
                case '2':
                case '3':
                case '4':
                case '5':
                case '6':
                case '7':
                case '8':
                case '9':
                case ':':
                case ';':
                case '<':
                case '=':
                case '>':
                case '?':
                case '@':
                case 'A':
                case 'B':
                case 'C':
                case 'D':
                case 'E':
                case 'F':
                case 'G':
                case 'H':
                case 'I':
                case 'J':
                case 'K':
                case 'L':
                case 'M':
                case 'N':
                case 'O':
                case 'P':
                case 'Q':
                case 'R':
                case 'S':
                case 'T':
                case 'U':
                case 'V':
                case 'W':
                case 'X':
                case 'Y':
                case 'Z':
                case '[':
                case '\\':
                case ']':
                case '^':
                case '_':
                case '`':
                case 'a':
                case 'b':
                case 'c':
                case 'd':
                case 'e':
                case 'f':
                case 'g':
                case 'h':
                case 'i':
                case 'j':
                case 'k':
                case 'l':
                case 'm':
                case 'n':
                case 'o':
                case 'p':
                case 'q':
                case 'r':
                case 's':
                case 't':
                case 'u':
                case 'v':
                case 'w':
                case 'x':
                case 'y':
                case 'z':
                case '{':
                case '|':
                case '}':
                case '~':
                case 127:
                case 128:
                case TsExtractor.TS_STREAM_TYPE_AC3:
                case TsExtractor.TS_STREAM_TYPE_HDMV_DTS:
                case 131:
                case 132:
                case 133:
                case TsExtractor.TS_STREAM_TYPE_SPLICE_INFO:
                case TsExtractor.TS_STREAM_TYPE_E_AC3:
                case 136:
                case 137:
                case TsExtractor.TS_STREAM_TYPE_DTS:
                case 139:
                    return true;
                default:
                    String str3 = Util.MODEL;
                    int hashCode = str3.hashCode();
                    if (hashCode != -594534941) {
                        if (hashCode != 2006354) {
                            if (hashCode == 2006367 && str3.equals("AFTN")) {
                                c3 = 1;
                            }
                        } else if (str3.equals("AFTA")) {
                            c3 = 0;
                        }
                    } else if (str3.equals("JSN-L21")) {
                        c3 = 2;
                    }
                    if (c3 == 0 || c3 == 1 || c3 == 2) {
                        return true;
                    }
            }
        }
        return false;
    }

    /* access modifiers changed from: private */
    public final class OnFrameRenderedListenerV23 implements MediaCodec.OnFrameRenderedListener, Handler.Callback {
        private static final int HANDLE_FRAME_RENDERED = 0;
        private final Handler handler = Util.createHandlerForCurrentLooper(this);

        public OnFrameRenderedListenerV23(MediaCodec mediaCodec) {
            mediaCodec.setOnFrameRenderedListener(this, this.handler);
        }

        public void onFrameRendered(MediaCodec mediaCodec, long j, long j2) {
            if (Util.SDK_INT < 30) {
                this.handler.sendMessageAtFrontOfQueue(Message.obtain(this.handler, 0, (int) (j >> 32), (int) j));
                return;
            }
            handleFrameRendered(j);
        }

        public boolean handleMessage(Message message) {
            if (message.what != 0) {
                return false;
            }
            handleFrameRendered(Util.toLong(message.arg1, message.arg2));
            return true;
        }

        private void handleFrameRendered(long j) {
            if (this == MediaCodecVideoRenderer.this.tunnelingOnFrameRenderedListener) {
                if (j == Long.MAX_VALUE) {
                    MediaCodecVideoRenderer.this.onProcessedTunneledEndOfStream();
                    return;
                }
                try {
                    MediaCodecVideoRenderer.this.onProcessedTunneledBuffer(j);
                } catch (ExoPlaybackException e) {
                    MediaCodecVideoRenderer.this.setPendingPlaybackException(e);
                }
            }
        }
    }
}
