package com.google.zxing.pdf417.encoder;

import com.google.android.exoplayer2.audio.AacUtil;
import com.google.zxing.WriterException;
import com.google.zxing.pdf417.PDF417Common;
import java.nio.charset.Charset;

public final class PDF417 {
    private static final int[][] CODEWORD_TABLE;
    private static final float DEFAULT_MODULE_WIDTH = 0.357f;
    private static final float HEIGHT = 2.0f;
    private static final float PREFERRED_RATIO = 3.0f;
    private static final int START_PATTERN = 130728;
    private static final int STOP_PATTERN = 260649;
    private BarcodeMatrix barcodeMatrix;
    private boolean compact;
    private Compaction compaction;
    private Charset encoding;
    private int maxCols;
    private int maxRows;
    private int minCols;
    private int minRows;

    private static int getNumberOfPadCodewords(int i, int i2, int i3, int i4) {
        int i5 = (i3 * i4) - i2;
        if (i5 > i + 1) {
            return (i5 - i) - 1;
        }
        return 0;
    }

    static {
        int[] iArr = new int[PDF417Common.NUMBER_OF_CODEWORDS];
        // fill-array-data instruction
        iArr[0] = 109536;
        iArr[1] = 120312;
        iArr[2] = 86976;
        iArr[3] = 109040;
        iArr[4] = 120060;
        iArr[5] = 86496;
        iArr[6] = 108792;
        iArr[7] = 119934;
        iArr[8] = 86256;
        iArr[9] = 108668;
        iArr[10] = 86136;
        iArr[11] = 129744;
        iArr[12] = 89056;
        iArr[13] = 110072;
        iArr[14] = 129736;
        iArr[15] = 88560;
        iArr[16] = 109820;
        iArr[17] = 129732;
        iArr[18] = 88312;
        iArr[19] = 109694;
        iArr[20] = 129730;
        iArr[21] = 88188;
        iArr[22] = 128464;
        iArr[23] = 129772;
        iArr[24] = 89592;
        iArr[25] = 128456;
        iArr[26] = 129766;
        iArr[27] = 89340;
        iArr[28] = 128452;
        iArr[29] = 89214;
        iArr[30] = 128450;
        iArr[31] = 125904;
        iArr[32] = 128492;
        iArr[33] = 125896;
        iArr[34] = 128486;
        iArr[35] = 125892;
        iArr[36] = 125890;
        iArr[37] = 120784;
        iArr[38] = 125932;
        iArr[39] = 120776;
        iArr[40] = 125926;
        iArr[41] = 120772;
        iArr[42] = 120770;
        iArr[43] = 110544;
        iArr[44] = 120812;
        iArr[45] = 110536;
        iArr[46] = 120806;
        iArr[47] = 110532;
        iArr[48] = 84928;
        iArr[49] = 108016;
        iArr[50] = 119548;
        iArr[51] = 84448;
        iArr[52] = 107768;
        iArr[53] = 119422;
        iArr[54] = 84208;
        iArr[55] = 107644;
        iArr[56] = 84088;
        iArr[57] = 107582;
        iArr[58] = 84028;
        iArr[59] = 129640;
        iArr[60] = 85488;
        iArr[61] = 108284;
        iArr[62] = 129636;
        iArr[63] = 85240;
        iArr[64] = 108158;
        iArr[65] = 129634;
        iArr[66] = 85116;
        iArr[67] = 85054;
        iArr[68] = 128232;
        iArr[69] = 129654;
        iArr[70] = 85756;
        iArr[71] = 128228;
        iArr[72] = 85630;
        iArr[73] = 128226;
        iArr[74] = 125416;
        iArr[75] = 128246;
        iArr[76] = 125412;
        iArr[77] = 125410;
        iArr[78] = 119784;
        iArr[79] = 125430;
        iArr[80] = 119780;
        iArr[81] = 119778;
        iArr[82] = 108520;
        iArr[83] = 119798;
        iArr[84] = 108516;
        iArr[85] = 108514;
        iArr[86] = 83424;
        iArr[87] = 107256;
        iArr[88] = 119166;
        iArr[89] = 83184;
        iArr[90] = 107132;
        iArr[91] = 83064;
        iArr[92] = 107070;
        iArr[93] = 83004;
        iArr[94] = 82974;
        iArr[95] = 129588;
        iArr[96] = 83704;
        iArr[97] = 107390;
        iArr[98] = 129586;
        iArr[99] = 83580;
        iArr[100] = 83518;
        iArr[101] = 128116;
        iArr[102] = 83838;
        iArr[103] = 128114;
        iArr[104] = 125172;
        iArr[105] = 125170;
        iArr[106] = 119284;
        iArr[107] = 119282;
        iArr[108] = 107508;
        iArr[109] = 107506;
        iArr[110] = 82672;
        iArr[111] = 106876;
        iArr[112] = 82552;
        iArr[113] = 106814;
        iArr[114] = 82492;
        iArr[115] = 82462;
        iArr[116] = 129562;
        iArr[117] = 82812;
        iArr[118] = 82750;
        iArr[119] = 128058;
        iArr[120] = 125050;
        iArr[121] = 119034;
        iArr[122] = 82296;
        iArr[123] = 106686;
        iArr[124] = 82236;
        iArr[125] = 82206;
        iArr[126] = 82366;
        iArr[127] = 82108;
        iArr[128] = 82078;
        iArr[129] = 76736;
        iArr[130] = 103920;
        iArr[131] = 117500;
        iArr[132] = 76256;
        iArr[133] = 103672;
        iArr[134] = 117374;
        iArr[135] = 76016;
        iArr[136] = 103548;
        iArr[137] = 75896;
        iArr[138] = 103486;
        iArr[139] = 75836;
        iArr[140] = 129384;
        iArr[141] = 77296;
        iArr[142] = 104188;
        iArr[143] = 129380;
        iArr[144] = 77048;
        iArr[145] = 104062;
        iArr[146] = 129378;
        iArr[147] = 76924;
        iArr[148] = 76862;
        iArr[149] = 127720;
        iArr[150] = 129398;
        iArr[151] = 77564;
        iArr[152] = 127716;
        iArr[153] = 77438;
        iArr[154] = 127714;
        iArr[155] = 124392;
        iArr[156] = 127734;
        iArr[157] = 124388;
        iArr[158] = 124386;
        iArr[159] = 117736;
        iArr[160] = 124406;
        iArr[161] = 117732;
        iArr[162] = 117730;
        iArr[163] = 104424;
        iArr[164] = 117750;
        iArr[165] = 104420;
        iArr[166] = 104418;
        iArr[167] = 112096;
        iArr[168] = 121592;
        iArr[169] = 126334;
        iArr[170] = 92608;
        iArr[171] = 111856;
        iArr[172] = 121468;
        iArr[173] = 92384;
        iArr[174] = 111736;
        iArr[175] = 121406;
        iArr[176] = 92272;
        iArr[177] = 111676;
        iArr[178] = 92216;
        iArr[179] = 111646;
        iArr[180] = 92188;
        iArr[181] = 75232;
        iArr[182] = 103160;
        iArr[183] = 117118;
        iArr[184] = 93664;
        iArr[185] = 74992;
        iArr[186] = 103036;
        iArr[187] = 93424;
        iArr[188] = 112252;
        iArr[189] = 102974;
        iArr[190] = 93304;
        iArr[191] = 74812;
        iArr[192] = 93244;
        iArr[193] = 74782;
        iArr[194] = 93214;
        iArr[195] = 129332;
        iArr[196] = 75512;
        iArr[197] = 103294;
        iArr[198] = 129908;
        iArr[199] = 129330;
        iArr[200] = 93944;
        iArr[201] = 75388;
        iArr[202] = 129906;
        iArr[203] = 93820;
        iArr[204] = 75326;
        iArr[205] = 93758;
        iArr[206] = 127604;
        iArr[207] = 75646;
        iArr[208] = 128756;
        iArr[209] = 127602;
        iArr[210] = 94078;
        iArr[211] = 128754;
        iArr[212] = 124148;
        iArr[213] = 126452;
        iArr[214] = 124146;
        iArr[215] = 126450;
        iArr[216] = 117236;
        iArr[217] = 121844;
        iArr[218] = 117234;
        iArr[219] = 121842;
        iArr[220] = 103412;
        iArr[221] = 103410;
        iArr[222] = 91584;
        iArr[223] = 111344;
        iArr[224] = 121212;
        iArr[225] = 91360;
        iArr[226] = 111224;
        iArr[227] = 121150;
        iArr[228] = 91248;
        iArr[229] = 111164;
        iArr[230] = 91192;
        iArr[231] = 111134;
        iArr[232] = 91164;
        iArr[233] = 91150;
        iArr[234] = 74480;
        iArr[235] = 102780;
        iArr[236] = 91888;
        iArr[237] = 74360;
        iArr[238] = 102718;
        iArr[239] = 91768;
        iArr[240] = 111422;
        iArr[241] = 91708;
        iArr[242] = 74270;
        iArr[243] = 91678;
        iArr[244] = 129306;
        iArr[245] = 74620;
        iArr[246] = 129850;
        iArr[247] = 92028;
        iArr[248] = 74558;
        iArr[249] = 91966;
        iArr[250] = 127546;
        iArr[251] = 128634;
        iArr[252] = 124026;
        iArr[253] = 126202;
        iArr[254] = 116986;
        iArr[255] = 121338;
        iArr[256] = 102906;
        iArr[257] = 90848;
        iArr[258] = 110968;
        iArr[259] = 121022;
        iArr[260] = 90736;
        iArr[261] = 110908;
        iArr[262] = 90680;
        iArr[263] = 110878;
        iArr[264] = 90652;
        iArr[265] = 90638;
        iArr[266] = 74104;
        iArr[267] = 102590;
        iArr[268] = 91000;
        iArr[269] = 74044;
        iArr[270] = 90940;
        iArr[271] = 74014;
        iArr[272] = 90910;
        iArr[273] = 74174;
        iArr[274] = 91070;
        iArr[275] = 90480;
        iArr[276] = 110780;
        iArr[277] = 90424;
        iArr[278] = 110750;
        iArr[279] = 90396;
        iArr[280] = 90382;
        iArr[281] = 73916;
        iArr[282] = 90556;
        iArr[283] = 73886;
        iArr[284] = 90526;
        iArr[285] = 90296;
        iArr[286] = 110686;
        iArr[287] = 90268;
        iArr[288] = 90254;
        iArr[289] = 73822;
        iArr[290] = 90334;
        iArr[291] = 90204;
        iArr[292] = 90190;
        iArr[293] = 71136;
        iArr[294] = 101112;
        iArr[295] = 116094;
        iArr[296] = 70896;
        iArr[297] = 100988;
        iArr[298] = 70776;
        iArr[299] = 100926;
        iArr[300] = 70716;
        iArr[301] = 70686;
        iArr[302] = 129204;
        iArr[303] = 71416;
        iArr[304] = 101246;
        iArr[305] = 129202;
        iArr[306] = 71292;
        iArr[307] = 71230;
        iArr[308] = 127348;
        iArr[309] = 71550;
        iArr[310] = 127346;
        iArr[311] = 123636;
        iArr[312] = 123634;
        iArr[313] = 116212;
        iArr[314] = 116210;
        iArr[315] = 101364;
        iArr[316] = 101362;
        iArr[317] = 79296;
        iArr[318] = 105200;
        iArr[319] = 118140;
        iArr[320] = 79072;
        iArr[321] = 105080;
        iArr[322] = 118078;
        iArr[323] = 78960;
        iArr[324] = 105020;
        iArr[325] = 78904;
        iArr[326] = 104990;
        iArr[327] = 78876;
        iArr[328] = 78862;
        iArr[329] = 70384;
        iArr[330] = 100732;
        iArr[331] = 79600;
        iArr[332] = 70264;
        iArr[333] = 100670;
        iArr[334] = 79480;
        iArr[335] = 105278;
        iArr[336] = 79420;
        iArr[337] = 70174;
        iArr[338] = 79390;
        iArr[339] = 129178;
        iArr[340] = 70524;
        iArr[341] = 129466;
        iArr[342] = 79740;
        iArr[343] = 70462;
        iArr[344] = 79678;
        iArr[345] = 127290;
        iArr[346] = 127866;
        iArr[347] = 123514;
        iArr[348] = 124666;
        iArr[349] = 115962;
        iArr[350] = 118266;
        iArr[351] = 100858;
        iArr[352] = 113376;
        iArr[353] = 122232;
        iArr[354] = 126654;
        iArr[355] = 95424;
        iArr[356] = 113264;
        iArr[357] = 122172;
        iArr[358] = 95328;
        iArr[359] = 113208;
        iArr[360] = 122142;
        iArr[361] = 95280;
        iArr[362] = 113180;
        iArr[363] = 95256;
        iArr[364] = 113166;
        iArr[365] = 95244;
        iArr[366] = 78560;
        iArr[367] = 104824;
        iArr[368] = 117950;
        iArr[369] = 95968;
        iArr[370] = 78448;
        iArr[371] = 104764;
        iArr[372] = 95856;
        iArr[373] = 113468;
        iArr[374] = 104734;
        iArr[375] = 95800;
        iArr[376] = 78364;
        iArr[377] = 95772;
        iArr[378] = 78350;
        iArr[379] = 95758;
        iArr[380] = 70008;
        iArr[381] = 100542;
        iArr[382] = 78712;
        iArr[383] = 69948;
        iArr[384] = 96120;
        iArr[385] = 78652;
        iArr[386] = 69918;
        iArr[387] = 96060;
        iArr[388] = 78622;
        iArr[389] = 96030;
        iArr[390] = 70078;
        iArr[391] = 78782;
        iArr[392] = 96190;
        iArr[393] = 94912;
        iArr[394] = 113008;
        iArr[395] = 122044;
        iArr[396] = 94816;
        iArr[397] = 112952;
        iArr[398] = 122014;
        iArr[399] = 94768;
        iArr[400] = 112924;
        iArr[401] = 94744;
        iArr[402] = 112910;
        iArr[403] = 94732;
        iArr[404] = 94726;
        iArr[405] = 78192;
        iArr[406] = 104636;
        iArr[407] = 95088;
        iArr[408] = 78136;
        iArr[409] = 104606;
        iArr[410] = 95032;
        iArr[411] = 113054;
        iArr[412] = 95004;
        iArr[413] = 78094;
        iArr[414] = 94990;
        iArr[415] = 69820;
        iArr[416] = 78268;
        iArr[417] = 69790;
        iArr[418] = 95164;
        iArr[419] = 78238;
        iArr[420] = 95134;
        iArr[421] = 94560;
        iArr[422] = 112824;
        iArr[423] = 121950;
        iArr[424] = 94512;
        iArr[425] = 112796;
        iArr[426] = 94488;
        iArr[427] = 112782;
        iArr[428] = 94476;
        iArr[429] = 94470;
        iArr[430] = 78008;
        iArr[431] = 104542;
        iArr[432] = 94648;
        iArr[433] = 77980;
        iArr[434] = 94620;
        iArr[435] = 77966;
        iArr[436] = 94606;
        iArr[437] = 69726;
        iArr[438] = 78046;
        iArr[439] = 94686;
        iArr[440] = 94384;
        iArr[441] = 112732;
        iArr[442] = 94360;
        iArr[443] = 112718;
        iArr[444] = 94348;
        iArr[445] = 94342;
        iArr[446] = 77916;
        iArr[447] = 94428;
        iArr[448] = 77902;
        iArr[449] = 94414;
        iArr[450] = 94296;
        iArr[451] = 112686;
        iArr[452] = 94284;
        iArr[453] = 94278;
        iArr[454] = 77870;
        iArr[455] = 94318;
        iArr[456] = 94252;
        iArr[457] = 94246;
        iArr[458] = 68336;
        iArr[459] = 99708;
        iArr[460] = 68216;
        iArr[461] = 99646;
        iArr[462] = 68156;
        iArr[463] = 68126;
        iArr[464] = 68476;
        iArr[465] = 68414;
        iArr[466] = 127162;
        iArr[467] = 123258;
        iArr[468] = 115450;
        iArr[469] = 99834;
        iArr[470] = 72416;
        iArr[471] = 101752;
        iArr[472] = 116414;
        iArr[473] = 72304;
        iArr[474] = 101692;
        iArr[475] = 72248;
        iArr[476] = 101662;
        iArr[477] = 72220;
        iArr[478] = 72206;
        iArr[479] = 67960;
        iArr[480] = 99518;
        iArr[481] = 72568;
        iArr[482] = 67900;
        iArr[483] = 72508;
        iArr[484] = 67870;
        iArr[485] = 72478;
        iArr[486] = 68030;
        iArr[487] = 72638;
        iArr[488] = 80576;
        iArr[489] = 105840;
        iArr[490] = 118460;
        iArr[491] = 80480;
        iArr[492] = 105784;
        iArr[493] = 118430;
        iArr[494] = 80432;
        iArr[495] = 105756;
        iArr[496] = 80408;
        iArr[497] = 105742;
        iArr[498] = 80396;
        iArr[499] = 80390;
        iArr[500] = 72048;
        iArr[501] = 101564;
        iArr[502] = 80752;
        iArr[503] = 71992;
        iArr[504] = 101534;
        iArr[505] = 80696;
        iArr[506] = 71964;
        iArr[507] = 80668;
        iArr[508] = 71950;
        iArr[509] = 80654;
        iArr[510] = 67772;
        iArr[511] = 72124;
        iArr[512] = 67742;
        iArr[513] = 80828;
        iArr[514] = 72094;
        iArr[515] = 80798;
        iArr[516] = 114016;
        iArr[517] = 122552;
        iArr[518] = 126814;
        iArr[519] = 96832;
        iArr[520] = 113968;
        iArr[521] = 122524;
        iArr[522] = 96800;
        iArr[523] = 113944;
        iArr[524] = 122510;
        iArr[525] = 96784;
        iArr[526] = 113932;
        iArr[527] = 96776;
        iArr[528] = 113926;
        iArr[529] = 96772;
        iArr[530] = 80224;
        iArr[531] = 105656;
        iArr[532] = 118366;
        iArr[533] = 97120;
        iArr[534] = 80176;
        iArr[535] = 105628;
        iArr[536] = 97072;
        iArr[537] = 114076;
        iArr[538] = 105614;
        iArr[539] = 97048;
        iArr[540] = 80140;
        iArr[541] = 97036;
        iArr[542] = 80134;
        iArr[543] = 97030;
        iArr[544] = 71864;
        iArr[545] = 101470;
        iArr[546] = 80312;
        iArr[547] = 71836;
        iArr[548] = 97208;
        iArr[549] = 80284;
        iArr[550] = 71822;
        iArr[551] = 97180;
        iArr[552] = 80270;
        iArr[553] = 97166;
        iArr[554] = 67678;
        iArr[555] = 71902;
        iArr[556] = 80350;
        iArr[557] = 97246;
        iArr[558] = 96576;
        iArr[559] = 113840;
        iArr[560] = 122460;
        iArr[561] = 96544;
        iArr[562] = 113816;
        iArr[563] = 122446;
        iArr[564] = 96528;
        iArr[565] = 113804;
        iArr[566] = 96520;
        iArr[567] = 113798;
        iArr[568] = 96516;
        iArr[569] = 96514;
        iArr[570] = 80048;
        iArr[571] = 105564;
        iArr[572] = 96688;
        iArr[573] = 80024;
        iArr[574] = 105550;
        iArr[575] = 96664;
        iArr[576] = 113870;
        iArr[577] = 96652;
        iArr[578] = 80006;
        iArr[579] = 96646;
        iArr[580] = 71772;
        iArr[581] = 80092;
        iArr[582] = 71758;
        iArr[583] = 96732;
        iArr[584] = 80078;
        iArr[585] = 96718;
        iArr[586] = 96416;
        iArr[587] = 113752;
        iArr[588] = 122414;
        iArr[589] = 96400;
        iArr[590] = 113740;
        iArr[591] = 96392;
        iArr[592] = 113734;
        iArr[593] = 96388;
        iArr[594] = 96386;
        iArr[595] = 79960;
        iArr[596] = 105518;
        iArr[597] = 96472;
        iArr[598] = 79948;
        iArr[599] = 96460;
        iArr[600] = 79942;
        iArr[601] = 96454;
        iArr[602] = 71726;
        iArr[603] = 79982;
        iArr[604] = 96494;
        iArr[605] = 96336;
        iArr[606] = 113708;
        iArr[607] = 96328;
        iArr[608] = 113702;
        iArr[609] = 96324;
        iArr[610] = 96322;
        iArr[611] = 79916;
        iArr[612] = 96364;
        iArr[613] = 79910;
        iArr[614] = 96358;
        iArr[615] = 96296;
        iArr[616] = 113686;
        iArr[617] = 96292;
        iArr[618] = 96290;
        iArr[619] = 79894;
        iArr[620] = 96310;
        iArr[621] = 66936;
        iArr[622] = 99006;
        iArr[623] = 66876;
        iArr[624] = 66846;
        iArr[625] = 67006;
        iArr[626] = 68976;
        iArr[627] = 100028;
        iArr[628] = 68920;
        iArr[629] = 99998;
        iArr[630] = 68892;
        iArr[631] = 68878;
        iArr[632] = 66748;
        iArr[633] = 69052;
        iArr[634] = 66718;
        iArr[635] = 69022;
        iArr[636] = 73056;
        iArr[637] = 102072;
        iArr[638] = 116574;
        iArr[639] = 73008;
        iArr[640] = 102044;
        iArr[641] = 72984;
        iArr[642] = 102030;
        iArr[643] = 72972;
        iArr[644] = 72966;
        iArr[645] = 68792;
        iArr[646] = 99934;
        iArr[647] = 73144;
        iArr[648] = 68764;
        iArr[649] = 73116;
        iArr[650] = 68750;
        iArr[651] = 73102;
        iArr[652] = 66654;
        iArr[653] = 68830;
        iArr[654] = 73182;
        iArr[655] = 81216;
        iArr[656] = 106160;
        iArr[657] = 118620;
        iArr[658] = 81184;
        iArr[659] = 106136;
        iArr[660] = 118606;
        iArr[661] = 81168;
        iArr[662] = 106124;
        iArr[663] = 81160;
        iArr[664] = 106118;
        iArr[665] = 81156;
        iArr[666] = 81154;
        iArr[667] = 72880;
        iArr[668] = 101980;
        iArr[669] = 81328;
        iArr[670] = 72856;
        iArr[671] = 101966;
        iArr[672] = 81304;
        iArr[673] = 106190;
        iArr[674] = 81292;
        iArr[675] = 72838;
        iArr[676] = 81286;
        iArr[677] = 68700;
        iArr[678] = 72924;
        iArr[679] = 68686;
        iArr[680] = 81372;
        iArr[681] = 72910;
        iArr[682] = 81358;
        iArr[683] = 114336;
        iArr[684] = 122712;
        iArr[685] = 126894;
        iArr[686] = 114320;
        iArr[687] = 122700;
        iArr[688] = 114312;
        iArr[689] = 122694;
        iArr[690] = 114308;
        iArr[691] = 114306;
        iArr[692] = 81056;
        iArr[693] = 106072;
        iArr[694] = 118574;
        iArr[695] = 97696;
        iArr[696] = 81040;
        iArr[697] = 106060;
        iArr[698] = 97680;
        iArr[699] = 114380;
        iArr[700] = 106054;
        iArr[701] = 97672;
        iArr[702] = 81028;
        iArr[703] = 97668;
        iArr[704] = 81026;
        iArr[705] = 97666;
        iArr[706] = 72792;
        iArr[707] = 101934;
        iArr[708] = 81112;
        iArr[709] = 72780;
        iArr[710] = 97752;
        iArr[711] = 81100;
        iArr[712] = 72774;
        iArr[713] = 97740;
        iArr[714] = 81094;
        iArr[715] = 97734;
        iArr[716] = 68654;
        iArr[717] = 72814;
        iArr[718] = 81134;
        iArr[719] = 97774;
        iArr[720] = 114256;
        iArr[721] = 122668;
        iArr[722] = 114248;
        iArr[723] = 122662;
        iArr[724] = 114244;
        iArr[725] = 114242;
        iArr[726] = 80976;
        iArr[727] = 106028;
        iArr[728] = 97488;
        iArr[729] = 80968;
        iArr[730] = 106022;
        iArr[731] = 97480;
        iArr[732] = 114278;
        iArr[733] = 97476;
        iArr[734] = 80962;
        iArr[735] = 97474;
        iArr[736] = 72748;
        iArr[737] = 81004;
        iArr[738] = 72742;
        iArr[739] = 97516;
        iArr[740] = 80998;
        iArr[741] = 97510;
        iArr[742] = 114216;
        iArr[743] = 122646;
        iArr[744] = 114212;
        iArr[745] = 114210;
        iArr[746] = 80936;
        iArr[747] = 106006;
        iArr[748] = 97384;
        iArr[749] = 80932;
        iArr[750] = 97380;
        iArr[751] = 80930;
        iArr[752] = 97378;
        iArr[753] = 72726;
        iArr[754] = 80950;
        iArr[755] = 97398;
        iArr[756] = 114196;
        iArr[757] = 114194;
        iArr[758] = 80916;
        iArr[759] = 97332;
        iArr[760] = 80914;
        iArr[761] = 97330;
        iArr[762] = 66236;
        iArr[763] = 66206;
        iArr[764] = 67256;
        iArr[765] = 99166;
        iArr[766] = 67228;
        iArr[767] = 67214;
        iArr[768] = 66142;
        iArr[769] = 67294;
        iArr[770] = 69296;
        iArr[771] = 100188;
        iArr[772] = 69272;
        iArr[773] = 100174;
        iArr[774] = 69260;
        iArr[775] = 69254;
        iArr[776] = 67164;
        iArr[777] = 69340;
        iArr[778] = 67150;
        iArr[779] = 69326;
        iArr[780] = 73376;
        iArr[781] = 102232;
        iArr[782] = 116654;
        iArr[783] = 73360;
        iArr[784] = 102220;
        iArr[785] = 73352;
        iArr[786] = 102214;
        iArr[787] = 73348;
        iArr[788] = 73346;
        iArr[789] = 69208;
        iArr[790] = 100142;
        iArr[791] = 73432;
        iArr[792] = 102254;
        iArr[793] = 73420;
        iArr[794] = 69190;
        iArr[795] = 73414;
        iArr[796] = 67118;
        iArr[797] = 69230;
        iArr[798] = 73454;
        iArr[799] = 106320;
        iArr[800] = 118700;
        iArr[801] = 106312;
        iArr[802] = 118694;
        iArr[803] = 106308;
        iArr[804] = 106306;
        iArr[805] = 73296;
        iArr[806] = 102188;
        iArr[807] = 81616;
        iArr[808] = 106348;
        iArr[809] = 102182;
        iArr[810] = 81608;
        iArr[811] = 73284;
        iArr[812] = 81604;
        iArr[813] = 73282;
        iArr[814] = 81602;
        iArr[815] = 69164;
        iArr[816] = 73324;
        iArr[817] = 69158;
        iArr[818] = 81644;
        iArr[819] = 73318;
        iArr[820] = 81638;
        iArr[821] = 122792;
        iArr[822] = 126934;
        iArr[823] = 122788;
        iArr[824] = 122786;
        iArr[825] = 106280;
        iArr[826] = 118678;
        iArr[827] = 114536;
        iArr[828] = 106276;
        iArr[829] = 114532;
        iArr[830] = 106274;
        iArr[831] = 114530;
        iArr[832] = 73256;
        iArr[833] = 102166;
        iArr[834] = 81512;
        iArr[835] = 73252;
        iArr[836] = 98024;
        iArr[837] = 81508;
        iArr[838] = 73250;
        iArr[839] = 98020;
        iArr[840] = 81506;
        iArr[841] = 98018;
        iArr[842] = 69142;
        iArr[843] = 73270;
        iArr[844] = 81526;
        iArr[845] = 98038;
        iArr[846] = 122772;
        iArr[847] = 122770;
        iArr[848] = 106260;
        iArr[849] = 114484;
        iArr[850] = 106258;
        iArr[851] = 114482;
        iArr[852] = 73236;
        iArr[853] = 81460;
        iArr[854] = 73234;
        iArr[855] = 97908;
        iArr[856] = 81458;
        iArr[857] = 97906;
        iArr[858] = 122762;
        iArr[859] = 106250;
        iArr[860] = 114458;
        iArr[861] = 73226;
        iArr[862] = 81434;
        iArr[863] = 97850;
        iArr[864] = 66396;
        iArr[865] = 66382;
        iArr[866] = 67416;
        iArr[867] = 99246;
        iArr[868] = 67404;
        iArr[869] = 67398;
        iArr[870] = 66350;
        iArr[871] = 67438;
        iArr[872] = 69456;
        iArr[873] = 100268;
        iArr[874] = 69448;
        iArr[875] = 100262;
        iArr[876] = 69444;
        iArr[877] = 69442;
        iArr[878] = 67372;
        iArr[879] = 69484;
        iArr[880] = 67366;
        iArr[881] = 69478;
        iArr[882] = 102312;
        iArr[883] = 116694;
        iArr[884] = 102308;
        iArr[885] = 102306;
        iArr[886] = 69416;
        iArr[887] = 100246;
        iArr[888] = 73576;
        iArr[889] = 102326;
        iArr[890] = 73572;
        iArr[891] = 69410;
        iArr[892] = 73570;
        iArr[893] = 67350;
        iArr[894] = 69430;
        iArr[895] = 73590;
        iArr[896] = 118740;
        iArr[897] = 118738;
        iArr[898] = 102292;
        iArr[899] = 106420;
        iArr[900] = 102290;
        iArr[901] = 106418;
        iArr[902] = 69396;
        iArr[903] = 73524;
        iArr[904] = 69394;
        iArr[905] = 81780;
        iArr[906] = 73522;
        iArr[907] = 81778;
        iArr[908] = 118730;
        iArr[909] = 102282;
        iArr[910] = 106394;
        iArr[911] = 69386;
        iArr[912] = 73498;
        iArr[913] = 81722;
        iArr[914] = 66476;
        iArr[915] = 66470;
        iArr[916] = 67496;
        iArr[917] = 99286;
        iArr[918] = 67492;
        iArr[919] = 67490;
        iArr[920] = 66454;
        iArr[921] = 67510;
        iArr[922] = 100308;
        iArr[923] = 100306;
        iArr[924] = 67476;
        iArr[925] = 69556;
        iArr[926] = 67474;
        iArr[927] = 69554;
        iArr[928] = 116714;
        CODEWORD_TABLE = new int[][]{new int[]{120256, 125680, 128380, 120032, 125560, 128318, 108736, 119920, 108640, 86080, 108592, 86048, 110016, 120560, 125820, 109792, 120440, 125758, 88256, 109680, 88160, 89536, 110320, 120700, 89312, 110200, 120638, 89200, 110140, 89840, 110460, 89720, 110398, 89980, 128506, 119520, 125304, 128190, 107712, 119408, 125244, 107616, 119352, 84032, 107568, 119324, 84000, 107544, 83984, 108256, 119672, 125374, 85184, 108144, 119612, 85088, 108088, 119582, 85040, 108060, 85728, 108408, 119742, 85616, 108348, 85560, 108318, 85880, 108478, 85820, 85790, 107200, 119152, 125116, 107104, 119096, 125086, 83008, 107056, 119068, 82976, 107032, 82960, 82952, 83648, 107376, 119228, 83552, 107320, 119198, 83504, 107292, 83480, 83468, 83824, 107452, 83768, 107422, 83740, 83900, 106848, 118968, 125022, 82496, 106800, 118940, 82464, 106776, 118926, 82448, 106764, 82440, 106758, 82784, 106936, 119006, 82736, 106908, 82712, 106894, 82700, 82694, 106974, 82830, 82240, 106672, 118876, 82208, 106648, 118862, 82192, 106636, 82184, 106630, 82180, 82352, 82328, 82316, 82080, 118830, 106572, 106566, 82050, 117472, 124280, 127678, 103616, 117360, 124220, 103520, 117304, 124190, 75840, 103472, 75808, 104160, 117624, 124350, 76992, 104048, 117564, 76896, 103992, 76848, 76824, 77536, 104312, 117694, 77424, 104252, 77368, 77340, 77688, 104382, 77628, 77758, 121536, 126320, 128700, 121440, 126264, 128670, 111680, 121392, 126236, 111648, 121368, 126222, 111632, 121356, 103104, 117104, 124092, 112320, 103008, 117048, 124062, 112224, 121656, 126366, 93248, 74784, 102936, 117006, 93216, 112152, 93200, 75456, 103280, 117180, 93888, 75360, 103224, 117150, 93792, 112440, 121758, 93744, 75288, 93720, 75632, 103356, 94064, 75576, 103326, 94008, 112542, 93980, 75708, 94140, 75678, 94110, 121184, 126136, 128606, 111168, 121136, 126108, 111136, 121112, 126094, 111120, 121100, 111112, 111108, 102752, 116920, 123998, 111456, 102704, 116892, 91712, 74272, 121244, 116878, 91680, 74256, 102668, 91664, 111372, 102662, 74244, 74592, 102840, 116958, 92000, 74544, 102812, 91952, 111516, 102798, 91928, 74508, 74502, 74680, 102878, 92088, 74652, 92060, 74638, 92046, 92126, 110912, 121008, 126044, 110880, 120984, 126030, 110864, 120972, 110856, 120966, 110852, 110850, 74048, 102576, 116828, 90944, 74016, 102552, 116814, 90912, 111000, 121038, 90896, 73992, 102534, 90888, 110982, 90884, 74160, 102620, 91056, 74136, 102606, 91032, 111054, 91020, 74118, 91014, 91100, 91086, 110752, 120920, 125998, 110736, 120908, 110728, 120902, 110724, 110722, 73888, 102488, 116782, 90528, 73872, 102476, 90512, 110796, 102470, 90504, 73860, 90500, 73858, 73944, 90584, 90572, 90566, 120876, 120870, 110658, 102444, 73800, 90312, 90308, 90306, 101056, 116080, 123580, 100960, 116024, 70720, 100912, 115996, 70688, 100888, 70672, 70664, 71360, 101232, 116156, 71264, 101176, 116126, 71216, 101148, 71192, 71180, 71536, 101308, 71480, 101278, 71452, 71612, 71582, 118112, 124600, 127838, 105024, 118064, 124572, 104992, 118040, 124558, 104976, 118028, 104968, 118022, 100704, 115896, 123486, 105312, 100656, 115868, 79424, 70176, 118172, 115854, 79392, 105240, 100620, 79376, 70152, 79368, 70496, 100792, 115934, 79712, 70448, 118238, 79664, 105372, 100750, 79640, 70412, 79628, 70584, 100830, 79800, 70556, 79772, 70542, 70622, 79838, 122176, 126640, 128860, 122144, 126616, 128846, 122128, 126604, 122120, 126598, 122116, 104768, 117936, 124508, 113472, 104736, 126684, 124494, 113440, 122264, 126670, 113424, 104712, 117894, 113416, 122246, 104706, 69952, 100528, 115804, 78656, 69920, 100504, 115790, 96064, 78624, 104856, 117966, 96032, 113560, 122318, 100486, 96016, 78600, 104838, 96008, 69890, 70064, 100572, 78768, 70040, 100558, 96176, 78744, 104910, 96152, 113614, 70022, 78726, 70108, 78812, 70094, 96220, 78798, 122016, 126552, 128814, 122000, 126540, 121992, 126534, 121988, 121986, 104608, 117848, 124462, 113056, 104592, 126574, 113040, 122060, 117830, 113032, 104580, 113028, 104578, 113026, 69792, 100440, 115758, 78240, 69776, 100428, 95136, 78224, 104652, 100422, 95120, 113100, 69764, 95112, 78212, 69762, 78210, 69848, 100462, 78296, 69836, 95192, 78284, 69830, 95180, 78278, 69870, 95214, 121936, 126508, 121928, 126502, 121924, 121922, 104528, 117804, 112848, 104520, 117798, 112840, 121958, 112836, 104514, 112834, 69712, 100396, 78032, 69704, 100390, 94672, 78024, 104550, 94664, 112870, 69698, 94660, 78018, 94658, 78060, 94700, 94694, 126486, 121890, 117782, 104484, 104482, 69672, 77928, 94440, 69666, 77922, 99680, 68160, 99632, 68128, 99608, 115342, 68112, 99596, 68104, 99590, 68448, 99768, 115422, 68400, 99740, 68376, 99726, 68364, 68358, 68536, 99806, 68508, 68494, 68574, 101696, 116400, 123740, 101664, 116376, 101648, 116364, 101640, 116358, 101636, 67904, 99504, 115292, 72512, 67872, 116444, 115278, 72480, 101784, 116430, 72464, 67848, 99462, 72456, 101766, 67842, 68016, 99548, 72624, 67992, 99534, 72600, 101838, 72588, 67974, 68060, 72668, 68046, 72654, 118432, 124760, 127918, 118416, 124748, 118408, 124742, 118404, 118402, 101536, 116312, 105888, 101520, 116300, 105872, 118476, 116294, 105864, 101508, 105860, 101506, 105858, 67744, 99416, 72096, 67728, 116334, 80800, 72080, 101580, 99398, 80784, 105932, 67716, 80776, 72068, 67714, 72066, 67800, 99438, 72152, 67788, 80856, 72140, 67782, 80844, 72134, 67822, 72174, 80878, 126800, 128940, 126792, 128934, 126788, 126786, 118352, 124716, 122576, 126828, 124710, 122568, 126822, 122564, 118338, 122562, 101456, 116268, 105680, 101448, 116262, 114128, 105672, 118374, 114120, 122598, 101442, 114116, 105666, 114114, 67664, 99372, 71888, 67656, 99366, 80336, 71880, 101478, 97232, 80328, 105702, 67650, 97224, 114150, 71874, 97220, 67692, 71916, 67686, 80364, 71910, 97260, 80358, 97254, 126760, 128918, 126756, 126754, 118312, 124694, 122472, 126774, 122468, 118306, 122466, 101416, 116246, 105576, 101412, 113896, 105572, 101410, 113892, 105570, 113890, 67624, 99350, 71784, 101430, 80104, 71780, 67618, 96744, 80100, 71778, 96740, 80098, 96738, 71798, 96758, 126738, 122420, 122418, 105524, 113780, 113778, 71732, 79988, 96500, 96498, 66880, 66848, 98968, 66832, 66824, 66820, 66992, 66968, 66956, 66950, 67036, 67022, AacUtil.AAC_LC_MAX_RATE_BYTES_PER_SECOND, 99984, 115532, 99976, 115526, 99972, 99970, 66720, 98904, 69024, 100056, 98892, 69008, 100044, 69000, 100038, 68996, 66690, 68994, 66776, 98926, 69080, 100078, 69068, 66758, 69062, 66798, 69102, 116560, 116552, 116548, 116546, 99920, 102096, 116588, 115494, 102088, 116582, 102084, 99906, 102082, 66640, 68816, 66632, 98854, 73168, 68808, 66628, 73160, 68804, 66626, 73156, 68802, 66668, 68844, 66662, 73196, 68838, 73190, 124840, 124836, 124834, 116520, 118632, 124854, 118628, 116514, 118626, 99880, 115478, 101992, 116534, 106216, 101988, 99874, 106212, 101986, 106210, 66600, 98838, 68712, 99894, 72936, 68708, 66594, 81384, 72932, 68706, 81380, 72930, 66614, 68726, 72950, 81398, 128980, 128978, 124820, 126900, 124818, 126898, 116500, 118580, 116498, 122740, 118578, 122738, 99860, 101940, 99858, 106100, 101938, 114420}, new int[]{128352, 129720, 125504, 128304, 129692, 125472, 128280, 129678, 125456, 128268, 125448, 128262, 125444, 125792, 128440, 129758, 120384, 125744, 128412, 120352, 125720, 128398, 120336, 125708, 120328, 125702, 120324, 120672, 125880, 128478, 110144, 120624, 125852, 110112, 120600, 125838, 110096, 120588, 110088, 120582, 110084, 110432, 120760, 125918, 89664, 110384, 120732, 89632, 110360, 120718, 89616, 110348, 89608, 110342, 89952, 110520, 120798, 89904, 110492, 89880, 110478, 89868, 90040, 110558, 90012, 89998, 125248, 128176, 129628, 125216, 128152, 129614, 125200, 128140, 125192, 128134, 125188, 125186, 119616, 125360, 128220, 119584, 125336, 128206, 119568, 125324, 119560, 125318, 119556, 119554, 108352, 119728, 125404, 108320, 119704, 125390, 108304, 119692, 108296, 119686, 108292, 108290, 85824, 108464, 119772, 85792, 108440, 119758, 85776, 108428, 85768, 108422, 85764, 85936, 108508, 85912, 108494, 85900, 85894, 85980, 85966, 125088, 128088, 129582, 125072, 128076, 125064, 128070, 125060, 125058, 119200, 125144, 128110, 119184, 125132, 119176, 125126, 119172, 119170, 107424, 119256, 125166, 107408, 119244, 107400, 119238, 107396, 107394, 83872, 107480, 119278, 83856, 107468, 83848, 107462, 83844, 83842, 83928, 107502, 83916, 83910, 83950, 125008, 128044, 125000, 128038, 124996, 124994, 118992, 125036, 118984, 125030, 118980, 118978, 106960, 119020, 106952, 119014, 106948, 106946, 82896, 106988, 82888, 106982, 82884, 82882, 82924, 82918, 124968, 128022, 124964, 124962, 118888, 124982, 118884, 118882, 106728, 118902, 106724, 106722, 82408, 106742, 82404, 82402, 124948, 124946, 118836, 118834, 106612, 106610, 124224, 127664, 129372, 124192, 127640, 129358, 124176, 127628, 124168, 127622, 124164, 124162, 117568, 124336, 127708, 117536, 124312, 127694, 117520, 124300, 117512, 124294, 117508, 117506, 104256, 117680, 124380, 104224, 117656, 124366, 104208, 117644, 104200, 117638, 104196, 104194, 77632, 104368, 117724, 77600, 104344, 117710, 77584, 104332, 77576, 104326, 77572, 77744, 104412, 77720, 104398, 77708, 77702, 77788, 77774, 128672, 129880, 93168, 128656, 129868, 92664, 128648, 129862, 92412, 128644, 128642, 124064, 127576, 129326, 126368, 124048, 129902, 126352, 128716, 127558, 126344, 124036, 126340, 124034, 126338, 117152, 124120, 127598, 121760, 117136, 124108, 121744, 126412, 124102, 121736, 117124, 121732, 117122, 121730, 103328, 117208, 124142, 112544, 103312, 117196, 112528, 121804, 117190, 112520, 103300, 112516, 103298, 112514, 75680, 103384, 117230, 94112, 75664, 103372, 94096, 112588, 103366, 94088, 75652, 94084, 75650, 75736, 103406, 94168, 75724, 94156, 75718, 94150, 75758, 128592, 129836, 91640, 128584, 129830, 91388, 128580, 91262, 128578, 123984, 127532, 126160, 123976, 127526, 126152, 128614, 126148, 123970, 126146, 116944, 124012, 121296, 116936, 124006, 121288, 126182, 121284, 116930, 121282, 102864, 116972, 111568, 102856, 116966, 111560, 121318, 111556, 102850, 111554, 74704, 102892, 92112, 74696, 102886, 92104, 111590, 92100, 74690, 92098, 74732, 92140, 74726, 92134, 128552, 129814, 90876, 128548, 90750, 128546, 123944, 127510, 126056, 128566, 126052, 123938, 126050, 116840, 123958, 121064, 116836, 121060, 116834, 121058, 102632, 116854, 111080, 121078, 111076, 102626, 111074, 74216, 102646, 91112, 74212, 91108, 74210, 91106, 74230, 91126, 128532, 90494, 128530, 123924, 126004, 123922, 126002, 116788, 120948, 116786, 120946, 102516, 110836, 102514, 110834, 73972, 90612, 73970, 90610, 128522, 123914, 125978, 116762, 120890, 102458, 110714, 123552, 127320, 129198, 123536, 127308, 123528, 127302, 123524, 123522, 116128, 123608, 127342, 116112, 123596, 116104, 123590, 116100, 116098, 101280, 116184, 123630, 101264, 116172, 101256, 116166, 101252, 101250, 71584, 101336, 116206, 71568, 101324, 71560, 101318, 71556, 71554, 71640, 101358, 71628, 71622, 71662, 127824, 129452, 79352, 127816, 129446, 79100, 127812, 78974, 127810, 123472, 127276, 124624, 123464, 127270, 124616, 127846, 124612, 123458, 124610, 115920, 123500, 118224, 115912, 123494, 118216, 124646, 118212, 115906, 118210, 100816, 115948, 105424, 100808, 115942, 105416, 118246, 105412, 100802, 105410, 70608, 100844, 79824, 70600, 100838, 79816, 105446, 79812, 70594, 79810, 70636, 79852, 70630, 79846, 129960, 95728, 113404, 129956, 95480, 113278, 129954, 95356, 95294, 127784, 129430, 78588, 128872, 129974, 95996, 78462, 128868, 127778, 95870, 128866, 123432, 127254, 124520, 123428, 126696, 128886, 123426, 126692, 124514, 126690, 115816, 123446, 117992, 115812, 122344, 117988, 115810, 122340, 117986, 122338, 100584, 115830, 104936, 100580, 113640, 104932, 100578, 113636, 104930, 113634, 70120, 100598, 78824, 70116, 96232, 78820, 70114, 96228, 78818, 96226, 70134, 78838, 129940, 94968, 113022, 129938, 94844, 94782, 127764, 78206, 128820, 127762, 95102, 128818, 123412, 124468, 123410, 126580, 124466, 126578, 115764, 117876, 115762, 122100, 117874, 122098, 100468, 104692, 100466, 113140, 104690, 113138, 69876, 78324, 69874, 95220, 78322, 95218, 129930, 94588, 94526, 127754, 128794, 123402, 124442, 126522, 115738, 117818, 121978, 100410, 104570, 112890, 69754, 78074, 94714, 94398, 123216, 127148, 123208, 127142, 123204, 123202, 115408, 123244, 115400, 123238, 115396, 115394, 99792, 115436, 99784, 115430, 99780, 99778, 68560, 99820, 68552, 99814, 68548, 68546, 68588, 68582, 127400, 129238, 72444, 127396, 72318, 127394, 123176, 127126, 123752, 123172, 123748, 123170, 123746, 115304, 123190, 116456, 115300, 116452, 115298, 116450, 99560, 115318, 101864, 99556, 101860, 99554, 101858, 68072, 99574, 72680, 68068, 72676, 68066, 72674, 68086, 72694, 129492, 80632, 105854, 129490, 80508, 80446, 127380, 72062, 127924, 127378, 80766, 127922, 123156, 123700, 123154, 124788, 123698, 124786, 115252, 116340, 115250, 118516, 116338, 118514, 99444, 101620, 99442, 105972, 101618, 105970, 67828, 72180, 67826, 80884, 72178, 80882, 97008, 114044, 96888, 113982, 96828, 96798, 129482, 80252, 130010, 97148, 80190, 97086, 127370, 127898, 128954, 123146, 123674, 124730, 126842, 115226, 116282, 118394, 122618, 99386, 101498, 105722, 114170, 67706, 71930, 80378, 96632, 113854, 96572, 96542, 80062, 96702, 96444, 96414, 96350, 123048, 123044, 123042, 115048, 123062, 115044, 115042, 99048, 115062, 99044, 99042, 67048, 99062, 67044, 67042, 67062, 127188, 68990, 127186, 123028, 123316, 123026, 123314, 114996, 115572, 114994, 115570, 98932, 100084, 98930, 100082, 66804, 69108, 66802, 69106, 129258, 73084, 73022, 127178, 127450, 123018, 123290, 123834, 114970, 115514, 116602, 98874, 99962, 102138, 66682, 68858, 73210, 81272, 106174, 81212, 81182, 72894, 81342, 97648, 114364, 97592, 114334, 97564, 97550, 81084, 97724, 81054, 97694, 97464, 114270, 97436, 97422, 80990, 97502, 97372, 97358, 97326, 114868, 114866, 98676, 98674, 66292, 66290, 123098, 114842, 115130, 98618, 99194, 66170, 67322, 69310, 73404, 73374, 81592, 106334, 81564, 81550, 73310, 81630, 97968, 114524, 97944, 114510, 97932, 97926, 81500, 98012, 81486, 97998, 97880, 114478, 97868, 97862, 81454, 97902, 97836, 97830, 69470, 73564, 73550, 81752, 106414, 81740, 81734, 73518, 81774, 81708, 81702}, iArr};
    }

    public PDF417() {
        this(false);
    }

    public PDF417(boolean z) {
        this.compact = z;
        this.compaction = Compaction.AUTO;
        this.encoding = null;
        this.minCols = 2;
        this.maxCols = 30;
        this.maxRows = 30;
        this.minRows = 2;
    }

    public BarcodeMatrix getBarcodeMatrix() {
        return this.barcodeMatrix;
    }

    private static int calculateNumberOfRows(int i, int i2, int i3) {
        int i4 = i + 1 + i2;
        int i5 = (i4 / i3) + 1;
        return i3 * i5 >= i4 + i3 ? i5 - 1 : i5;
    }

    private static void encodeChar(int i, int i2, BarcodeRow barcodeRow) {
        int i3 = 1 << (i2 - 1);
        boolean z = (i & i3) != 0;
        int i4 = i3;
        int i5 = 0;
        for (int i6 = 0; i6 < i2; i6++) {
            boolean z2 = (i & i4) != 0;
            if (z == z2) {
                i5++;
            } else {
                barcodeRow.addBar(z, i5);
                z = z2;
                i5 = 1;
            }
            i4 >>= 1;
        }
        barcodeRow.addBar(z, i5);
    }

    private void encodeLowLevel(CharSequence charSequence, int i, int i2, int i3, BarcodeMatrix barcodeMatrix2) {
        int i4;
        int i5;
        int i6;
        int i7 = 0;
        int i8 = 0;
        while (i7 < i2) {
            int i9 = i7 % 3;
            barcodeMatrix2.startRow();
            encodeChar(START_PATTERN, 17, barcodeMatrix2.getCurrentRow());
            if (i9 == 0) {
                i5 = (i7 / 3) * 30;
                i4 = ((i2 - 1) / 3) + i5;
                i6 = i - 1;
            } else if (i9 == 1) {
                i5 = (i7 / 3) * 30;
                int i10 = i2 - 1;
                i4 = (i3 * 3) + i5 + (i10 % 3);
                i6 = i10 / 3;
            } else {
                int i11 = (i7 / 3) * 30;
                i4 = (i - 1) + i11;
                i5 = i11 + (i3 * 3);
                i6 = (i2 - 1) % 3;
            }
            int i12 = i5 + i6;
            encodeChar(CODEWORD_TABLE[i9][i4], 17, barcodeMatrix2.getCurrentRow());
            int i13 = i8;
            for (int i14 = 0; i14 < i; i14++) {
                encodeChar(CODEWORD_TABLE[i9][charSequence.charAt(i13)], 17, barcodeMatrix2.getCurrentRow());
                i13++;
            }
            if (this.compact) {
                encodeChar(STOP_PATTERN, 1, barcodeMatrix2.getCurrentRow());
            } else {
                encodeChar(CODEWORD_TABLE[i9][i12], 17, barcodeMatrix2.getCurrentRow());
                encodeChar(STOP_PATTERN, 18, barcodeMatrix2.getCurrentRow());
            }
            i7++;
            i8 = i13;
        }
    }

    public void generateBarcodeLogic(String str, int i) throws WriterException {
        int errorCorrectionCodewordCount = PDF417ErrorCorrection.getErrorCorrectionCodewordCount(i);
        String encodeHighLevel = PDF417HighLevelEncoder.encodeHighLevel(str, this.compaction, this.encoding);
        int length = encodeHighLevel.length();
        int[] determineDimensions = determineDimensions(length, errorCorrectionCodewordCount);
        int i2 = determineDimensions[0];
        int i3 = determineDimensions[1];
        int numberOfPadCodewords = getNumberOfPadCodewords(length, errorCorrectionCodewordCount, i2, i3);
        if (errorCorrectionCodewordCount + length + 1 <= 929) {
            int i4 = length + numberOfPadCodewords + 1;
            StringBuilder sb = new StringBuilder(i4);
            sb.append((char) i4);
            sb.append(encodeHighLevel);
            for (int i5 = 0; i5 < numberOfPadCodewords; i5++) {
                sb.append((char) 900);
            }
            String sb2 = sb.toString();
            String generateErrorCorrection = PDF417ErrorCorrection.generateErrorCorrection(sb2, i);
            this.barcodeMatrix = new BarcodeMatrix(i3, i2);
            encodeLowLevel(sb2 + generateErrorCorrection, i2, i3, i, this.barcodeMatrix);
            return;
        }
        throw new WriterException("Encoded message contains too many code words, message too big (" + str.length() + " bytes)");
    }

    private int[] determineDimensions(int i, int i2) throws WriterException {
        int i3;
        int calculateNumberOfRows;
        int i4 = this.minCols;
        float f = 0.0f;
        int[] iArr = null;
        while (i4 <= this.maxCols && (calculateNumberOfRows = calculateNumberOfRows(i, i2, i4)) >= this.minRows) {
            if (calculateNumberOfRows <= this.maxRows) {
                float f2 = (((float) ((i4 * 17) + 69)) * DEFAULT_MODULE_WIDTH) / (((float) calculateNumberOfRows) * HEIGHT);
                if (iArr == null || Math.abs(f2 - 3.0f) <= Math.abs(f - 3.0f)) {
                    iArr = new int[]{i4, calculateNumberOfRows};
                    f = f2;
                }
            }
            i4++;
        }
        if (iArr == null && calculateNumberOfRows(i, i2, this.minCols) < (i3 = this.minRows)) {
            iArr = new int[]{this.minCols, i3};
        }
        if (iArr != null) {
            return iArr;
        }
        throw new WriterException("Unable to fit message in columns");
    }

    public void setDimensions(int i, int i2, int i3, int i4) {
        this.maxCols = i;
        this.minCols = i2;
        this.maxRows = i3;
        this.minRows = i4;
    }

    public void setCompaction(Compaction compaction2) {
        this.compaction = compaction2;
    }

    public void setCompact(boolean z) {
        this.compact = z;
    }

    public void setEncoding(Charset charset) {
        this.encoding = charset;
    }
}
