package io.flutter.embedding.android;

import android.util.Log;
import android.view.KeyCharacterMap;
import android.view.KeyEvent;
import android.view.View;
import io.flutter.embedding.engine.systemchannels.KeyEventChannel;
import io.flutter.plugin.editing.TextInputPlugin;
import java.util.AbstractMap;
import java.util.ArrayDeque;
import java.util.Deque;
import java.util.Map;

public class AndroidKeyProcessor {
    private static final String TAG = "AndroidKeyProcessor";
    private static long eventIdSerial;
    private int combiningCharacter;
    private EventResponder eventResponder;
    private final KeyEventChannel keyEventChannel;
    private final TextInputPlugin textInputPlugin;

    public AndroidKeyProcessor(View view, KeyEventChannel keyEventChannel2, TextInputPlugin textInputPlugin2) {
        this.keyEventChannel = keyEventChannel2;
        this.textInputPlugin = textInputPlugin2;
        this.eventResponder = new EventResponder(view);
        this.keyEventChannel.setEventResponseHandler(this.eventResponder);
    }

    public void destroy() {
        this.keyEventChannel.setEventResponseHandler(null);
    }

    public boolean onKeyUp(KeyEvent keyEvent) {
        if (this.eventResponder.dispatchingKeyEvent) {
            return false;
        }
        Character applyCombiningCharacterToBaseCharacter = applyCombiningCharacterToBaseCharacter(keyEvent.getUnicodeChar());
        long j = eventIdSerial;
        eventIdSerial = 1 + j;
        KeyEventChannel.FlutterKeyEvent flutterKeyEvent = new KeyEventChannel.FlutterKeyEvent(keyEvent, applyCombiningCharacterToBaseCharacter, j);
        this.keyEventChannel.keyUp(flutterKeyEvent);
        this.eventResponder.addEvent(flutterKeyEvent.eventId, keyEvent);
        return true;
    }

    public boolean onKeyDown(KeyEvent keyEvent) {
        if (this.eventResponder.dispatchingKeyEvent) {
            return false;
        }
        if (this.textInputPlugin.getLastInputConnection() != null && this.textInputPlugin.getInputMethodManager().isAcceptingText() && this.textInputPlugin.getLastInputConnection().sendKeyEvent(keyEvent)) {
            return true;
        }
        Character applyCombiningCharacterToBaseCharacter = applyCombiningCharacterToBaseCharacter(keyEvent.getUnicodeChar());
        long j = eventIdSerial;
        eventIdSerial = 1 + j;
        KeyEventChannel.FlutterKeyEvent flutterKeyEvent = new KeyEventChannel.FlutterKeyEvent(keyEvent, applyCombiningCharacterToBaseCharacter, j);
        this.keyEventChannel.keyDown(flutterKeyEvent);
        this.eventResponder.addEvent(flutterKeyEvent.eventId, keyEvent);
        return true;
    }

    private Character applyCombiningCharacterToBaseCharacter(int i) {
        if (i == 0) {
            return null;
        }
        char c = (char) i;
        if ((Integer.MIN_VALUE & i) != 0) {
            int i2 = i & Integer.MAX_VALUE;
            int i3 = this.combiningCharacter;
            if (i3 != 0) {
                this.combiningCharacter = KeyCharacterMap.getDeadChar(i3, i2);
            } else {
                this.combiningCharacter = i2;
            }
        } else {
            int i4 = this.combiningCharacter;
            if (i4 != 0) {
                int deadChar = KeyCharacterMap.getDeadChar(i4, i);
                if (deadChar > 0) {
                    c = (char) deadChar;
                }
                this.combiningCharacter = 0;
            }
        }
        return Character.valueOf(c);
    }

    /* access modifiers changed from: private */
    public static class EventResponder implements KeyEventChannel.EventResponseHandler {
        private static final long MAX_PENDING_EVENTS = 1000;
        boolean dispatchingKeyEvent = false;
        final Deque<Map.Entry<Long, KeyEvent>> pendingEvents = new ArrayDeque();
        private final View view;

        public EventResponder(View view2) {
            this.view = view2;
        }

        private KeyEvent removePendingEvent(long j) {
            if (this.pendingEvents.getFirst().getKey().longValue() == j) {
                return this.pendingEvents.removeFirst().getValue();
            }
            throw new AssertionError("Event response received out of order. Should have seen event " + this.pendingEvents.getFirst().getKey() + " first. Instead, received " + j);
        }

        @Override // io.flutter.embedding.engine.systemchannels.KeyEventChannel.EventResponseHandler
        public void onKeyEventHandled(long j) {
            removePendingEvent(j);
        }

        @Override // io.flutter.embedding.engine.systemchannels.KeyEventChannel.EventResponseHandler
        public void onKeyEventNotHandled(long j) {
            dispatchKeyEvent(removePendingEvent(j));
        }

        public void addEvent(long j, KeyEvent keyEvent) {
            if (this.pendingEvents.size() <= 0 || this.pendingEvents.getFirst().getKey().longValue() < j) {
                this.pendingEvents.addLast(new AbstractMap.SimpleImmutableEntry(Long.valueOf(j), keyEvent));
                if (((long) this.pendingEvents.size()) > 1000) {
                    Log.e(AndroidKeyProcessor.TAG, "There are " + this.pendingEvents.size() + " keyboard events that have not yet received a response. Are responses being sent?");
                    return;
                }
                return;
            }
            throw new AssertionError("New events must have ids greater than the most recent pending event. New id " + j + " is less than or equal to the last event id of " + this.pendingEvents.getFirst().getKey());
        }

        public void dispatchKeyEvent(KeyEvent keyEvent) {
            View view2 = this.view;
            if (view2 != null) {
                this.dispatchingKeyEvent = true;
                view2.getRootView().dispatchKeyEvent(keyEvent);
                this.dispatchingKeyEvent = false;
            }
        }
    }
}
