package io.flutter.plugins.imagepicker;

import android.app.Activity;
import android.content.Intent;
import android.content.pm.ResolveInfo;
import android.media.MediaScannerConnection;
import android.net.Uri;
import android.os.Build;
import androidx.core.app.ActivityCompat;
import androidx.core.content.FileProvider;
import com.luck.picture.lib.config.PictureConfig;
import com.luck.picture.lib.tools.PictureFileUtils;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.PluginRegistry;
import java.io.File;
import java.io.IOException;
import java.util.Map;
import java.util.UUID;

public class ImagePickerDelegate implements PluginRegistry.ActivityResultListener, PluginRegistry.RequestPermissionsResultListener {
    static final int REQUEST_CAMERA_IMAGE_PERMISSION = 2345;
    static final int REQUEST_CAMERA_VIDEO_PERMISSION = 2355;
    static final int REQUEST_CODE_CHOOSE_IMAGE_FROM_GALLERY = 2342;
    static final int REQUEST_CODE_CHOOSE_VIDEO_FROM_GALLERY = 2352;
    static final int REQUEST_CODE_TAKE_IMAGE_WITH_CAMERA = 2343;
    static final int REQUEST_CODE_TAKE_VIDEO_WITH_CAMERA = 2353;
    static final int REQUEST_EXTERNAL_IMAGE_STORAGE_PERMISSION = 2344;
    static final int REQUEST_EXTERNAL_VIDEO_STORAGE_PERMISSION = 2354;
    private final Activity activity;
    private final ImagePickerCache cache;
    private CameraDevice cameraDevice;
    private final File externalFilesDirectory;
    final String fileProviderName;
    private final FileUriResolver fileUriResolver;
    private final FileUtils fileUtils;
    private final ImageResizer imageResizer;
    private final IntentResolver intentResolver;
    private MethodCall methodCall;
    private Uri pendingCameraMediaUri;
    private MethodChannel.Result pendingResult;
    private final PermissionManager permissionManager;

    /* access modifiers changed from: package-private */
    public interface FileUriResolver {
        void getFullImagePath(Uri uri, OnPathReadyListener onPathReadyListener);

        Uri resolveFileProviderUriForFile(String str, File file);
    }

    /* access modifiers changed from: package-private */
    public interface IntentResolver {
        boolean resolveActivity(Intent intent);
    }

    /* access modifiers changed from: package-private */
    public interface OnPathReadyListener {
        void onPathReady(String str);
    }

    /* access modifiers changed from: package-private */
    public interface PermissionManager {
        void askForPermission(String str, int i);

        boolean isPermissionGranted(String str);

        boolean needRequestCameraPermission();
    }

    public ImagePickerDelegate(final Activity activity2, File file, ImageResizer imageResizer2, ImagePickerCache imagePickerCache) {
        this(activity2, file, imageResizer2, null, null, imagePickerCache, new PermissionManager() {
            /* class io.flutter.plugins.imagepicker.ImagePickerDelegate.AnonymousClass1 */

            @Override // io.flutter.plugins.imagepicker.ImagePickerDelegate.PermissionManager
            public boolean isPermissionGranted(String str) {
                return ActivityCompat.checkSelfPermission(activity2, str) == 0;
            }

            @Override // io.flutter.plugins.imagepicker.ImagePickerDelegate.PermissionManager
            public void askForPermission(String str, int i) {
                ActivityCompat.requestPermissions(activity2, new String[]{str}, i);
            }

            @Override // io.flutter.plugins.imagepicker.ImagePickerDelegate.PermissionManager
            public boolean needRequestCameraPermission() {
                return ImagePickerUtils.needRequestCameraPermission(activity2);
            }
        }, new IntentResolver() {
            /* class io.flutter.plugins.imagepicker.ImagePickerDelegate.AnonymousClass2 */

            @Override // io.flutter.plugins.imagepicker.ImagePickerDelegate.IntentResolver
            public boolean resolveActivity(Intent intent) {
                return intent.resolveActivity(activity2.getPackageManager()) != null;
            }
        }, new FileUriResolver() {
            /* class io.flutter.plugins.imagepicker.ImagePickerDelegate.AnonymousClass3 */

            @Override // io.flutter.plugins.imagepicker.ImagePickerDelegate.FileUriResolver
            public Uri resolveFileProviderUriForFile(String str, File file) {
                return FileProvider.getUriForFile(activity2, str, file);
            }

            @Override // io.flutter.plugins.imagepicker.ImagePickerDelegate.FileUriResolver
            public void getFullImagePath(Uri uri, final OnPathReadyListener onPathReadyListener) {
                Activity activity = activity2;
                String[] strArr = new String[1];
                strArr[0] = uri != null ? uri.getPath() : "";
                MediaScannerConnection.scanFile(activity, strArr, null, new MediaScannerConnection.OnScanCompletedListener() {
                    /* class io.flutter.plugins.imagepicker.ImagePickerDelegate.AnonymousClass3.AnonymousClass1 */

                    public void onScanCompleted(String str, Uri uri) {
                        onPathReadyListener.onPathReady(str);
                    }
                });
            }
        }, new FileUtils());
    }

    ImagePickerDelegate(Activity activity2, File file, ImageResizer imageResizer2, MethodChannel.Result result, MethodCall methodCall2, ImagePickerCache imagePickerCache, PermissionManager permissionManager2, IntentResolver intentResolver2, FileUriResolver fileUriResolver2, FileUtils fileUtils2) {
        this.activity = activity2;
        this.externalFilesDirectory = file;
        this.imageResizer = imageResizer2;
        this.fileProviderName = activity2.getPackageName() + ".flutter.image_provider";
        this.pendingResult = result;
        this.methodCall = methodCall2;
        this.permissionManager = permissionManager2;
        this.intentResolver = intentResolver2;
        this.fileUriResolver = fileUriResolver2;
        this.fileUtils = fileUtils2;
        this.cache = imagePickerCache;
    }

    /* access modifiers changed from: package-private */
    public void setCameraDevice(CameraDevice cameraDevice2) {
        this.cameraDevice = cameraDevice2;
    }

    /* access modifiers changed from: package-private */
    public CameraDevice getCameraDevice() {
        return this.cameraDevice;
    }

    /* access modifiers changed from: package-private */
    public void saveStateBeforeResult() {
        MethodCall methodCall2 = this.methodCall;
        if (methodCall2 != null) {
            this.cache.saveTypeWithMethodCallName(methodCall2.method);
            this.cache.saveDimensionWithMethodCall(this.methodCall);
            Uri uri = this.pendingCameraMediaUri;
            if (uri != null) {
                this.cache.savePendingCameraMediaUriPath(uri);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void retrieveLostImage(MethodChannel.Result result) {
        int i;
        Map<String, Object> cacheMap = this.cache.getCacheMap();
        ImagePickerCache imagePickerCache = this.cache;
        String str = (String) cacheMap.get("path");
        if (str != null) {
            ImagePickerCache imagePickerCache2 = this.cache;
            Double d = (Double) cacheMap.get("maxWidth");
            ImagePickerCache imagePickerCache3 = this.cache;
            Double d2 = (Double) cacheMap.get("maxHeight");
            ImagePickerCache imagePickerCache4 = this.cache;
            if (cacheMap.get("imageQuality") == null) {
                i = 100;
            } else {
                ImagePickerCache imagePickerCache5 = this.cache;
                i = ((Integer) cacheMap.get("imageQuality")).intValue();
            }
            String resizeImageIfNeeded = this.imageResizer.resizeImageIfNeeded(str, d, d2, Integer.valueOf(i));
            ImagePickerCache imagePickerCache6 = this.cache;
            cacheMap.put("path", resizeImageIfNeeded);
        }
        if (cacheMap.isEmpty()) {
            result.success(null);
        } else {
            result.success(cacheMap);
        }
        this.cache.clear();
    }

    public void chooseVideoFromGallery(MethodCall methodCall2, MethodChannel.Result result) {
        if (!setPendingMethodCallAndResult(methodCall2, result)) {
            finishWithAlreadyActiveError(result);
        } else if (!this.permissionManager.isPermissionGranted("android.permission.READ_EXTERNAL_STORAGE")) {
            this.permissionManager.askForPermission("android.permission.READ_EXTERNAL_STORAGE", REQUEST_EXTERNAL_VIDEO_STORAGE_PERMISSION);
        } else {
            launchPickVideoFromGalleryIntent();
        }
    }

    private void launchPickVideoFromGalleryIntent() {
        Intent intent = new Intent("android.intent.action.GET_CONTENT");
        intent.setType("video/*");
        this.activity.startActivityForResult(intent, REQUEST_CODE_CHOOSE_VIDEO_FROM_GALLERY);
    }

    public void takeVideoWithCamera(MethodCall methodCall2, MethodChannel.Result result) {
        if (!setPendingMethodCallAndResult(methodCall2, result)) {
            finishWithAlreadyActiveError(result);
        } else if (!needRequestCameraPermission() || this.permissionManager.isPermissionGranted("android.permission.CAMERA")) {
            launchTakeVideoWithCameraIntent();
        } else {
            this.permissionManager.askForPermission("android.permission.CAMERA", REQUEST_CAMERA_VIDEO_PERMISSION);
        }
    }

    private void launchTakeVideoWithCameraIntent() {
        Intent intent = new Intent("android.media.action.VIDEO_CAPTURE");
        MethodCall methodCall2 = this.methodCall;
        if (!(methodCall2 == null || methodCall2.argument("maxDuration") == null)) {
            intent.putExtra("android.intent.extra.durationLimit", ((Integer) this.methodCall.argument("maxDuration")).intValue());
        }
        if (this.cameraDevice == CameraDevice.FRONT) {
            useFrontCamera(intent);
        }
        if (!this.intentResolver.resolveActivity(intent)) {
            finishWithError("no_available_camera", "No cameras available for taking pictures.");
            return;
        }
        File createTemporaryWritableVideoFile = createTemporaryWritableVideoFile();
        this.pendingCameraMediaUri = Uri.parse("file:" + createTemporaryWritableVideoFile.getAbsolutePath());
        Uri resolveFileProviderUriForFile = this.fileUriResolver.resolveFileProviderUriForFile(this.fileProviderName, createTemporaryWritableVideoFile);
        intent.putExtra("output", resolveFileProviderUriForFile);
        grantUriPermissions(intent, resolveFileProviderUriForFile);
        this.activity.startActivityForResult(intent, REQUEST_CODE_TAKE_VIDEO_WITH_CAMERA);
    }

    public void chooseImageFromGallery(MethodCall methodCall2, MethodChannel.Result result) {
        if (!setPendingMethodCallAndResult(methodCall2, result)) {
            finishWithAlreadyActiveError(result);
        } else if (!this.permissionManager.isPermissionGranted("android.permission.READ_EXTERNAL_STORAGE")) {
            this.permissionManager.askForPermission("android.permission.READ_EXTERNAL_STORAGE", REQUEST_EXTERNAL_IMAGE_STORAGE_PERMISSION);
        } else {
            launchPickImageFromGalleryIntent();
        }
    }

    private void launchPickImageFromGalleryIntent() {
        Intent intent = new Intent("android.intent.action.GET_CONTENT");
        intent.setType("image/*");
        this.activity.startActivityForResult(intent, REQUEST_CODE_CHOOSE_IMAGE_FROM_GALLERY);
    }

    public void takeImageWithCamera(MethodCall methodCall2, MethodChannel.Result result) {
        if (!setPendingMethodCallAndResult(methodCall2, result)) {
            finishWithAlreadyActiveError(result);
        } else if (!needRequestCameraPermission() || this.permissionManager.isPermissionGranted("android.permission.CAMERA")) {
            launchTakeImageWithCameraIntent();
        } else {
            this.permissionManager.askForPermission("android.permission.CAMERA", REQUEST_CAMERA_IMAGE_PERMISSION);
        }
    }

    private boolean needRequestCameraPermission() {
        PermissionManager permissionManager2 = this.permissionManager;
        if (permissionManager2 == null) {
            return false;
        }
        return permissionManager2.needRequestCameraPermission();
    }

    private void launchTakeImageWithCameraIntent() {
        Intent intent = new Intent("android.media.action.IMAGE_CAPTURE");
        if (this.cameraDevice == CameraDevice.FRONT) {
            useFrontCamera(intent);
        }
        if (!this.intentResolver.resolveActivity(intent)) {
            finishWithError("no_available_camera", "No cameras available for taking pictures.");
            return;
        }
        File createTemporaryWritableImageFile = createTemporaryWritableImageFile();
        this.pendingCameraMediaUri = Uri.parse("file:" + createTemporaryWritableImageFile.getAbsolutePath());
        Uri resolveFileProviderUriForFile = this.fileUriResolver.resolveFileProviderUriForFile(this.fileProviderName, createTemporaryWritableImageFile);
        intent.putExtra("output", resolveFileProviderUriForFile);
        grantUriPermissions(intent, resolveFileProviderUriForFile);
        this.activity.startActivityForResult(intent, REQUEST_CODE_TAKE_IMAGE_WITH_CAMERA);
    }

    private File createTemporaryWritableImageFile() {
        return createTemporaryWritableFile(".jpg");
    }

    private File createTemporaryWritableVideoFile() {
        return createTemporaryWritableFile(PictureFileUtils.POST_VIDEO);
    }

    private File createTemporaryWritableFile(String str) {
        try {
            return File.createTempFile(UUID.randomUUID().toString(), str, this.externalFilesDirectory);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    private void grantUriPermissions(Intent intent, Uri uri) {
        for (ResolveInfo resolveInfo : this.activity.getPackageManager().queryIntentActivities(intent, 65536)) {
            this.activity.grantUriPermission(resolveInfo.activityInfo.packageName, uri, 3);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:24:0x003c, code lost:
        if (r6 != io.flutter.plugins.imagepicker.ImagePickerDelegate.REQUEST_CAMERA_VIDEO_PERMISSION) goto L_0x004e;
     */
    @Override // io.flutter.plugin.common.PluginRegistry.RequestPermissionsResultListener
    public boolean onRequestPermissionsResult(int i, String[] strArr, int[] iArr) {
        boolean z = iArr.length > 0 && iArr[0] == 0;
        if (i != REQUEST_EXTERNAL_IMAGE_STORAGE_PERMISSION) {
            if (i != REQUEST_CAMERA_IMAGE_PERMISSION) {
                if (i != REQUEST_EXTERNAL_VIDEO_STORAGE_PERMISSION) {
                    if (i != REQUEST_CAMERA_VIDEO_PERMISSION) {
                        return false;
                    }
                    if (z) {
                        launchTakeVideoWithCameraIntent();
                    }
                } else if (z) {
                    launchPickVideoFromGalleryIntent();
                }
            } else if (z) {
                launchTakeImageWithCameraIntent();
            }
        } else if (z) {
            launchPickImageFromGalleryIntent();
        }
        if (!z) {
            if (i != REQUEST_EXTERNAL_IMAGE_STORAGE_PERMISSION) {
                if (i != REQUEST_CAMERA_IMAGE_PERMISSION) {
                    if (i != REQUEST_EXTERNAL_VIDEO_STORAGE_PERMISSION) {
                    }
                }
                finishWithError("camera_access_denied", "The user did not allow camera access.");
            }
            finishWithError("photo_access_denied", "The user did not allow photo access.");
        }
        return true;
    }

    @Override // io.flutter.plugin.common.PluginRegistry.ActivityResultListener
    public boolean onActivityResult(int i, int i2, Intent intent) {
        if (i == REQUEST_CODE_CHOOSE_IMAGE_FROM_GALLERY) {
            handleChooseImageResult(i2, intent);
            return true;
        } else if (i == REQUEST_CODE_TAKE_IMAGE_WITH_CAMERA) {
            handleCaptureImageResult(i2);
            return true;
        } else if (i == REQUEST_CODE_CHOOSE_VIDEO_FROM_GALLERY) {
            handleChooseVideoResult(i2, intent);
            return true;
        } else if (i != REQUEST_CODE_TAKE_VIDEO_WITH_CAMERA) {
            return false;
        } else {
            handleCaptureVideoResult(i2);
            return true;
        }
    }

    private void handleChooseImageResult(int i, Intent intent) {
        if (i != -1 || intent == null) {
            finishWithSuccess(null);
        } else {
            handleImageResult(this.fileUtils.getPathFromUri(this.activity, intent.getData()), false);
        }
    }

    private void handleChooseVideoResult(int i, Intent intent) {
        if (i != -1 || intent == null) {
            finishWithSuccess(null);
        } else {
            handleVideoResult(this.fileUtils.getPathFromUri(this.activity, intent.getData()));
        }
    }

    private void handleCaptureImageResult(int i) {
        if (i == -1) {
            FileUriResolver fileUriResolver2 = this.fileUriResolver;
            Uri uri = this.pendingCameraMediaUri;
            if (uri == null) {
                uri = Uri.parse(this.cache.retrievePendingCameraMediaUriPath());
            }
            fileUriResolver2.getFullImagePath(uri, new OnPathReadyListener() {
                /* class io.flutter.plugins.imagepicker.ImagePickerDelegate.AnonymousClass4 */

                @Override // io.flutter.plugins.imagepicker.ImagePickerDelegate.OnPathReadyListener
                public void onPathReady(String str) {
                    ImagePickerDelegate.this.handleImageResult(str, true);
                }
            });
            return;
        }
        finishWithSuccess(null);
    }

    private void handleCaptureVideoResult(int i) {
        if (i == -1) {
            FileUriResolver fileUriResolver2 = this.fileUriResolver;
            Uri uri = this.pendingCameraMediaUri;
            if (uri == null) {
                uri = Uri.parse(this.cache.retrievePendingCameraMediaUriPath());
            }
            fileUriResolver2.getFullImagePath(uri, new OnPathReadyListener() {
                /* class io.flutter.plugins.imagepicker.ImagePickerDelegate.AnonymousClass5 */

                @Override // io.flutter.plugins.imagepicker.ImagePickerDelegate.OnPathReadyListener
                public void onPathReady(String str) {
                    ImagePickerDelegate.this.handleVideoResult(str);
                }
            });
            return;
        }
        finishWithSuccess(null);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleImageResult(String str, boolean z) {
        MethodCall methodCall2 = this.methodCall;
        if (methodCall2 != null) {
            String resizeImageIfNeeded = this.imageResizer.resizeImageIfNeeded(str, (Double) methodCall2.argument("maxWidth"), (Double) this.methodCall.argument("maxHeight"), (Integer) this.methodCall.argument("imageQuality"));
            finishWithSuccess(resizeImageIfNeeded);
            if (resizeImageIfNeeded != null && !resizeImageIfNeeded.equals(str) && z) {
                new File(str).delete();
                return;
            }
            return;
        }
        finishWithSuccess(str);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void handleVideoResult(String str) {
        finishWithSuccess(str);
    }

    private boolean setPendingMethodCallAndResult(MethodCall methodCall2, MethodChannel.Result result) {
        if (this.pendingResult != null) {
            return false;
        }
        this.methodCall = methodCall2;
        this.pendingResult = result;
        this.cache.clear();
        return true;
    }

    private void finishWithSuccess(String str) {
        MethodChannel.Result result = this.pendingResult;
        if (result == null) {
            this.cache.saveResult(str, null, null);
            return;
        }
        result.success(str);
        clearMethodCallAndResult();
    }

    private void finishWithAlreadyActiveError(MethodChannel.Result result) {
        result.error("already_active", "Image picker is already active", null);
    }

    private void finishWithError(String str, String str2) {
        MethodChannel.Result result = this.pendingResult;
        if (result == null) {
            this.cache.saveResult(null, str, str2);
            return;
        }
        result.error(str, str2, null);
        clearMethodCallAndResult();
    }

    private void clearMethodCallAndResult() {
        this.methodCall = null;
        this.pendingResult = null;
    }

    private void useFrontCamera(Intent intent) {
        if (Build.VERSION.SDK_INT >= 22) {
            intent.putExtra(PictureConfig.CAMERA_FACING, 0);
            if (Build.VERSION.SDK_INT >= 26) {
                intent.putExtra("android.intent.extra.USE_FRONT_CAMERA", true);
                return;
            }
            return;
        }
        intent.putExtra(PictureConfig.CAMERA_FACING, 1);
    }
}
